/* SettingsUrisView.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from SettingsUrisView.vala, do not modify */

/*
 * Copyright 2011-2023 elementary, Inc. (https://elementary.io)
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */

#include "granite-7.h"
#include <glib-object.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gi18n-lib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_DEMO_PAGE (demo_page_get_type ())
#define DEMO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DEMO_PAGE, DemoPage))
#define DEMO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DEMO_PAGE, DemoPageClass))
#define IS_DEMO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DEMO_PAGE))
#define IS_DEMO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DEMO_PAGE))
#define DEMO_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DEMO_PAGE, DemoPageClass))

typedef struct _DemoPage DemoPage;
typedef struct _DemoPageClass DemoPageClass;
typedef struct _DemoPagePrivate DemoPagePrivate;

#define TYPE_SETTINGS_URIS_VIEW (settings_uris_view_get_type ())
#define SETTINGS_URIS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SETTINGS_URIS_VIEW, SettingsUrisView))
#define SETTINGS_URIS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SETTINGS_URIS_VIEW, SettingsUrisViewClass))
#define IS_SETTINGS_URIS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SETTINGS_URIS_VIEW))
#define IS_SETTINGS_URIS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SETTINGS_URIS_VIEW))
#define SETTINGS_URIS_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SETTINGS_URIS_VIEW, SettingsUrisViewClass))

typedef struct _SettingsUrisView SettingsUrisView;
typedef struct _SettingsUrisViewClass SettingsUrisViewClass;
typedef struct _SettingsUrisViewPrivate SettingsUrisViewPrivate;
enum  {
	SETTINGS_URIS_VIEW_0_PROPERTY,
	SETTINGS_URIS_VIEW_NUM_PROPERTIES
};
static GParamSpec* settings_uris_view_properties[SETTINGS_URIS_VIEW_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _DemoPage {
	GraniteToolBox parent_instance;
	DemoPagePrivate * priv;
};

struct _DemoPageClass {
	GraniteToolBoxClass parent_class;
};

struct _SettingsUrisView {
	DemoPage parent_instance;
	SettingsUrisViewPrivate * priv;
};

struct _SettingsUrisViewClass {
	DemoPageClass parent_class;
};

static gpointer settings_uris_view_parent_class = NULL;

VALA_EXTERN GType demo_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DemoPage, g_object_unref)
VALA_EXTERN GType settings_uris_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SettingsUrisView, g_object_unref)
VALA_EXTERN SettingsUrisView* settings_uris_view_new (void);
VALA_EXTERN SettingsUrisView* settings_uris_view_construct (GType object_type);
VALA_EXTERN DemoPage* demo_page_new (void);
VALA_EXTERN DemoPage* demo_page_construct (GType object_type);
static GObject * settings_uris_view_constructor (GType type,
                                          guint n_construct_properties,
                                          GObjectConstructParam * construct_properties);
VALA_EXTERN void demo_page_set_child (DemoPage* self,
                          GtkWidget* value);
static GType settings_uris_view_get_type_once (void);

SettingsUrisView*
settings_uris_view_construct (GType object_type)
{
	SettingsUrisView * self = NULL;
	self = (SettingsUrisView*) demo_page_construct (object_type);
	return self;
}

SettingsUrisView*
settings_uris_view_new (void)
{
	return settings_uris_view_construct (TYPE_SETTINGS_URIS_VIEW);
}

static GObject *
settings_uris_view_constructor (GType type,
                                guint n_construct_properties,
                                GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	SettingsUrisView * self;
	GraniteBox* column = NULL;
	GraniteBox* _tmp0_ = NULL;
	GraniteBox* _tmp1_;
	GtkLinkButton* _tmp2_;
	GtkLinkButton* _tmp3_;
	GraniteBox* _tmp4_;
	GtkLinkButton* _tmp5_;
	GtkLinkButton* _tmp6_;
	GraniteBox* _tmp7_;
	GtkLinkButton* _tmp8_;
	GtkLinkButton* _tmp9_;
	GraniteBox* _tmp10_;
	GtkLinkButton* _tmp11_;
	GtkLinkButton* _tmp12_;
	GraniteBox* _tmp13_;
	GtkLinkButton* _tmp14_;
	GtkLinkButton* _tmp15_;
	GraniteBox* _tmp16_;
	GtkLinkButton* _tmp17_;
	GtkLinkButton* _tmp18_;
	GraniteBox* _tmp19_;
	GtkLinkButton* _tmp20_;
	GtkLinkButton* _tmp21_;
	GraniteBox* _tmp22_;
	parent_class = G_OBJECT_CLASS (settings_uris_view_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SETTINGS_URIS_VIEW, SettingsUrisView);
	_tmp0_ = granite_box_new (GTK_ORIENTATION_VERTICAL, GRANITE_BOX_SPACING_SINGLE);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp0_, 24);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp0_, 24);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp0_, 24);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp0_, 24);
	gtk_widget_set_halign ((GtkWidget*) _tmp0_, GTK_ALIGN_CENTER);
	gtk_widget_set_valign ((GtkWidget*) _tmp0_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp0_);
	column = _tmp0_;
	_tmp1_ = column;
	_tmp2_ = (GtkLinkButton*) gtk_link_button_new_with_label (GRANITE_SETTINGS_URI_LOCATION, _ ("Security & Privacy → Location Services"));
	g_object_ref_sink (_tmp2_);
	_tmp3_ = _tmp2_;
	gtk_box_append ((GtkBox*) _tmp1_, (GtkWidget*) _tmp3_);
	_g_object_unref0 (_tmp3_);
	_tmp4_ = column;
	_tmp5_ = (GtkLinkButton*) gtk_link_button_new_with_label (GRANITE_SETTINGS_URI_ONLINE_ACCOUNTS, _ ("Online Accounts"));
	g_object_ref_sink (_tmp5_);
	_tmp6_ = _tmp5_;
	gtk_box_append ((GtkBox*) _tmp4_, (GtkWidget*) _tmp6_);
	_g_object_unref0 (_tmp6_);
	_tmp7_ = column;
	_tmp8_ = (GtkLinkButton*) gtk_link_button_new_with_label (GRANITE_SETTINGS_URI_NETWORK, _ ("Network"));
	g_object_ref_sink (_tmp8_);
	_tmp9_ = _tmp8_;
	gtk_box_append ((GtkBox*) _tmp7_, (GtkWidget*) _tmp9_);
	_g_object_unref0 (_tmp9_);
	_tmp10_ = column;
	_tmp11_ = (GtkLinkButton*) gtk_link_button_new_with_label (GRANITE_SETTINGS_URI_PERMISSIONS, _ ("Applications → Permissions"));
	g_object_ref_sink (_tmp11_);
	_tmp12_ = _tmp11_;
	gtk_box_append ((GtkBox*) _tmp10_, (GtkWidget*) _tmp12_);
	_g_object_unref0 (_tmp12_);
	_tmp13_ = column;
	_tmp14_ = (GtkLinkButton*) gtk_link_button_new_with_label (GRANITE_SETTINGS_URI_NOTIFICATIONS, _ ("Notifications"));
	g_object_ref_sink (_tmp14_);
	_tmp15_ = _tmp14_;
	gtk_box_append ((GtkBox*) _tmp13_, (GtkWidget*) _tmp15_);
	_g_object_unref0 (_tmp15_);
	_tmp16_ = column;
	_tmp17_ = (GtkLinkButton*) gtk_link_button_new_with_label (GRANITE_SETTINGS_URI_SOUND_INPUT, _ ("Sound → Input"));
	g_object_ref_sink (_tmp17_);
	_tmp18_ = _tmp17_;
	gtk_box_append ((GtkBox*) _tmp16_, (GtkWidget*) _tmp18_);
	_g_object_unref0 (_tmp18_);
	_tmp19_ = column;
	_tmp20_ = (GtkLinkButton*) gtk_link_button_new_with_label (GRANITE_SETTINGS_URI_SHORTCUTS, _ ("Keyboard → Shortcuts → Custom"));
	g_object_ref_sink (_tmp20_);
	_tmp21_ = _tmp20_;
	gtk_box_append ((GtkBox*) _tmp19_, (GtkWidget*) _tmp21_);
	_g_object_unref0 (_tmp21_);
	_tmp22_ = column;
	demo_page_set_child ((DemoPage*) self, (GtkWidget*) _tmp22_);
	_g_object_unref0 (column);
	return obj;
}

static void
settings_uris_view_class_init (SettingsUrisViewClass * klass,
                               gpointer klass_data)
{
	settings_uris_view_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->constructor = settings_uris_view_constructor;
}

static void
settings_uris_view_instance_init (SettingsUrisView * self,
                                  gpointer klass)
{
}

static GType
settings_uris_view_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (SettingsUrisViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) settings_uris_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SettingsUrisView), 0, (GInstanceInitFunc) settings_uris_view_instance_init, NULL };
	GType settings_uris_view_type_id;
	settings_uris_view_type_id = g_type_register_static (TYPE_DEMO_PAGE, "SettingsUrisView", &g_define_type_info, 0);
	return settings_uris_view_type_id;
}

GType
settings_uris_view_get_type (void)
{
	static volatile gsize settings_uris_view_type_id__once = 0;
	if (g_once_init_enter (&settings_uris_view_type_id__once)) {
		GType settings_uris_view_type_id;
		settings_uris_view_type_id = settings_uris_view_get_type_once ();
		g_once_init_leave (&settings_uris_view_type_id__once, settings_uris_view_type_id);
	}
	return settings_uris_view_type_id__once;
}

