/* ApplicationView.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from ApplicationView.vala, do not modify */

/*
 * Copyright 2019 elementary, Inc. (https://elementary.io)
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */

#include "granite-7.h"
#include <glib-object.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <float.h>
#include <math.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_DEMO_PAGE (demo_page_get_type ())
#define DEMO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DEMO_PAGE, DemoPage))
#define DEMO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DEMO_PAGE, DemoPageClass))
#define IS_DEMO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DEMO_PAGE))
#define IS_DEMO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DEMO_PAGE))
#define DEMO_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DEMO_PAGE, DemoPageClass))

typedef struct _DemoPage DemoPage;
typedef struct _DemoPageClass DemoPageClass;
typedef struct _DemoPagePrivate DemoPagePrivate;

#define TYPE_APPLICATION_VIEW (application_view_get_type ())
#define APPLICATION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APPLICATION_VIEW, ApplicationView))
#define APPLICATION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APPLICATION_VIEW, ApplicationViewClass))
#define IS_APPLICATION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APPLICATION_VIEW))
#define IS_APPLICATION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APPLICATION_VIEW))
#define APPLICATION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APPLICATION_VIEW, ApplicationViewClass))

typedef struct _ApplicationView ApplicationView;
typedef struct _ApplicationViewClass ApplicationViewClass;
typedef struct _ApplicationViewPrivate ApplicationViewPrivate;
enum  {
	APPLICATION_VIEW_0_PROPERTY,
	APPLICATION_VIEW_NUM_PROPERTIES
};
static GParamSpec* application_view_properties[APPLICATION_VIEW_NUM_PROPERTIES];
typedef struct _Block2Data Block2Data;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

struct _DemoPage {
	GraniteToolBox parent_instance;
	DemoPagePrivate * priv;
};

struct _DemoPageClass {
	GraniteToolBoxClass parent_class;
};

struct _ApplicationView {
	DemoPage parent_instance;
	ApplicationViewPrivate * priv;
};

struct _ApplicationViewClass {
	DemoPageClass parent_class;
};

struct _Block2Data {
	int _ref_count_;
	ApplicationView* self;
	GtkSwitch* progress_visible_switch;
	GtkScale* progress_scale;
	GtkSwitch* badge_visible_switch;
	GtkSpinButton* badge_spin;
};

static gpointer application_view_parent_class = NULL;

VALA_EXTERN GType demo_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DemoPage, g_object_unref)
VALA_EXTERN GType application_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ApplicationView, g_object_unref)
VALA_EXTERN ApplicationView* application_view_new (void);
VALA_EXTERN ApplicationView* application_view_construct (GType object_type);
VALA_EXTERN DemoPage* demo_page_new (void);
VALA_EXTERN DemoPage* demo_page_construct (GType object_type);
static GObject * application_view_constructor (GType type,
                                        guint n_construct_properties,
                                        GObjectConstructParam * construct_properties);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
VALA_EXTERN void demo_page_set_child (DemoPage* self,
                          GtkWidget* value);
static void _application_view___lambda20_ (Block2Data* _data2_);
static void __lambda21_ (ApplicationView* self,
                  GObject* obj,
                  GAsyncResult* res);
static void ___lambda21__gasync_ready_callback (GObject* source_object,
                                         GAsyncResult* res,
                                         gpointer self);
static void __application_view___lambda20__gtk_range_value_changed (GtkRange* _sender,
                                                             gpointer self);
static void _application_view___lambda22_ (Block2Data* _data2_);
static void __lambda23_ (ApplicationView* self,
                  GObject* obj,
                  GAsyncResult* res);
static void ___lambda23__gasync_ready_callback (GObject* source_object,
                                         GAsyncResult* res,
                                         gpointer self);
static void __application_view___lambda22__g_object_notify (GObject* _sender,
                                                     GParamSpec* pspec,
                                                     gpointer self);
static void _application_view___lambda24_ (Block2Data* _data2_);
static void __lambda25_ (ApplicationView* self,
                  GObject* obj,
                  GAsyncResult* res);
static void ___lambda25__gasync_ready_callback (GObject* source_object,
                                         GAsyncResult* res,
                                         gpointer self);
static void __application_view___lambda24__gtk_spin_button_value_changed (GtkSpinButton* _sender,
                                                                   gpointer self);
static void _application_view___lambda26_ (Block2Data* _data2_);
static void __lambda27_ (ApplicationView* self,
                  GObject* obj,
                  GAsyncResult* res);
static void ___lambda27__gasync_ready_callback (GObject* source_object,
                                         GAsyncResult* res,
                                         gpointer self);
static void __application_view___lambda26__g_object_notify (GObject* _sender,
                                                     GParamSpec* pspec,
                                                     gpointer self);
static GType application_view_get_type_once (void);

ApplicationView*
application_view_construct (GType object_type)
{
	ApplicationView * self = NULL;
	self = (ApplicationView*) demo_page_construct (object_type);
	return self;
}

ApplicationView*
application_view_new (void)
{
	return application_view_construct (TYPE_APPLICATION_VIEW);
}

static Block2Data*
block2_data_ref (Block2Data* _data2_)
{
	g_atomic_int_inc (&_data2_->_ref_count_);
	return _data2_;
}

static void
block2_data_unref (void * _userdata_)
{
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
		ApplicationView* self;
		self = _data2_->self;
		_g_object_unref0 (_data2_->badge_spin);
		_g_object_unref0 (_data2_->badge_visible_switch);
		_g_object_unref0 (_data2_->progress_scale);
		_g_object_unref0 (_data2_->progress_visible_switch);
		_g_object_unref0 (self);
		g_slice_free (Block2Data, _data2_);
	}
}

static void
__lambda21_ (ApplicationView* self,
             GObject* obj,
             GAsyncResult* res)
{
	GError* _inner_error0_ = NULL;
	g_return_if_fail (res != NULL);
	{
		granite_services_application_set_progress_finish (res, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp0_ = e;
		_tmp1_ = _tmp0_->message;
		g_critical ("ApplicationView.vala:45: %s", _tmp1_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
___lambda21__gasync_ready_callback (GObject* source_object,
                                    GAsyncResult* res,
                                    gpointer self)
{
	__lambda21_ ((ApplicationView*) self, source_object, res);
	g_object_unref (self);
}

static void
_application_view___lambda20_ (Block2Data* _data2_)
{
	ApplicationView* self;
	GtkScale* _tmp0_;
	self = _data2_->self;
	_tmp0_ = _data2_->progress_scale;
	granite_services_application_set_progress (gtk_range_get_value ((GtkRange*) _tmp0_), ___lambda21__gasync_ready_callback, g_object_ref (self));
}

static void
__application_view___lambda20__gtk_range_value_changed (GtkRange* _sender,
                                                        gpointer self)
{
	_application_view___lambda20_ (self);
}

static void
__lambda23_ (ApplicationView* self,
             GObject* obj,
             GAsyncResult* res)
{
	GError* _inner_error0_ = NULL;
	g_return_if_fail (res != NULL);
	{
		granite_services_application_set_progress_visible_finish (res, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp0_ = e;
		_tmp1_ = _tmp0_->message;
		g_critical ("ApplicationView.vala:55: %s", _tmp1_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
___lambda23__gasync_ready_callback (GObject* source_object,
                                    GAsyncResult* res,
                                    gpointer self)
{
	__lambda23_ ((ApplicationView*) self, source_object, res);
	g_object_unref (self);
}

static void
_application_view___lambda22_ (Block2Data* _data2_)
{
	ApplicationView* self;
	GtkSwitch* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	self = _data2_->self;
	_tmp0_ = _data2_->progress_visible_switch;
	_tmp1_ = gtk_switch_get_active (_tmp0_);
	_tmp2_ = _tmp1_;
	granite_services_application_set_progress_visible (_tmp2_, ___lambda23__gasync_ready_callback, g_object_ref (self));
}

static void
__application_view___lambda22__g_object_notify (GObject* _sender,
                                                GParamSpec* pspec,
                                                gpointer self)
{
	_application_view___lambda22_ (self);
}

static void
__lambda25_ (ApplicationView* self,
             GObject* obj,
             GAsyncResult* res)
{
	GError* _inner_error0_ = NULL;
	g_return_if_fail (res != NULL);
	{
		granite_services_application_set_badge_finish (res, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp0_ = e;
		_tmp1_ = _tmp0_->message;
		g_critical ("ApplicationView.vala:65: %s", _tmp1_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
___lambda25__gasync_ready_callback (GObject* source_object,
                                    GAsyncResult* res,
                                    gpointer self)
{
	__lambda25_ ((ApplicationView*) self, source_object, res);
	g_object_unref (self);
}

static void
_application_view___lambda24_ (Block2Data* _data2_)
{
	ApplicationView* self;
	GtkSpinButton* _tmp0_;
	gdouble _tmp1_;
	gdouble _tmp2_;
	self = _data2_->self;
	_tmp0_ = _data2_->badge_spin;
	_tmp1_ = gtk_spin_button_get_value (_tmp0_);
	_tmp2_ = _tmp1_;
	granite_services_application_set_badge ((gint64) _tmp2_, ___lambda25__gasync_ready_callback, g_object_ref (self));
}

static void
__application_view___lambda24__gtk_spin_button_value_changed (GtkSpinButton* _sender,
                                                              gpointer self)
{
	_application_view___lambda24_ (self);
}

static void
__lambda27_ (ApplicationView* self,
             GObject* obj,
             GAsyncResult* res)
{
	GError* _inner_error0_ = NULL;
	g_return_if_fail (res != NULL);
	{
		granite_services_application_set_badge_visible_finish (res, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp0_ = e;
		_tmp1_ = _tmp0_->message;
		g_critical ("ApplicationView.vala:75: %s", _tmp1_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
___lambda27__gasync_ready_callback (GObject* source_object,
                                    GAsyncResult* res,
                                    gpointer self)
{
	__lambda27_ ((ApplicationView*) self, source_object, res);
	g_object_unref (self);
}

static void
_application_view___lambda26_ (Block2Data* _data2_)
{
	ApplicationView* self;
	GtkSwitch* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	self = _data2_->self;
	_tmp0_ = _data2_->badge_visible_switch;
	_tmp1_ = gtk_switch_get_active (_tmp0_);
	_tmp2_ = _tmp1_;
	granite_services_application_set_badge_visible (_tmp2_, ___lambda27__gasync_ready_callback, g_object_ref (self));
}

static void
__application_view___lambda26__g_object_notify (GObject* _sender,
                                                GParamSpec* pspec,
                                                gpointer self)
{
	_application_view___lambda26_ (self);
}

static GObject *
application_view_constructor (GType type,
                              guint n_construct_properties,
                              GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	ApplicationView * self;
	Block2Data* _data2_;
	GtkLabel* progress_visible_label = NULL;
	GtkLabel* _tmp0_;
	GtkSwitch* _tmp1_;
	GtkSwitch* _tmp2_;
	GtkScale* _tmp3_;
	GtkLabel* badge_visible_label = NULL;
	GtkLabel* _tmp4_;
	GtkSwitch* _tmp5_;
	GtkSwitch* _tmp6_;
	GtkSpinButton* _tmp7_;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp8_ = NULL;
	GtkGrid* _tmp9_;
	GtkLabel* _tmp10_;
	GtkGrid* _tmp11_;
	GtkSwitch* _tmp12_;
	GtkGrid* _tmp13_;
	GtkScale* _tmp14_;
	GtkGrid* _tmp15_;
	GtkLabel* _tmp16_;
	GtkGrid* _tmp17_;
	GtkSwitch* _tmp18_;
	GtkGrid* _tmp19_;
	GtkSpinButton* _tmp20_;
	GtkGrid* _tmp21_;
	GtkSwitch* _tmp22_;
	GtkScale* _tmp23_;
	GtkSwitch* _tmp24_;
	GtkSpinButton* _tmp25_;
	GtkScale* _tmp26_;
	GtkSwitch* _tmp27_;
	GtkSpinButton* _tmp28_;
	GtkSwitch* _tmp29_;
	parent_class = G_OBJECT_CLASS (application_view_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_APPLICATION_VIEW, ApplicationView);
	_data2_ = g_slice_new0 (Block2Data);
	_data2_->_ref_count_ = 1;
	_data2_->self = g_object_ref (self);
	_tmp0_ = (GtkLabel*) gtk_label_new ("Show Progress:");
	g_object_ref_sink (_tmp0_);
	progress_visible_label = _tmp0_;
	_tmp1_ = (GtkSwitch*) gtk_switch_new ();
	g_object_ref_sink (_tmp1_);
	_data2_->progress_visible_switch = _tmp1_;
	_tmp2_ = _data2_->progress_visible_switch;
	gtk_widget_set_valign ((GtkWidget*) _tmp2_, GTK_ALIGN_CENTER);
	_tmp3_ = (GtkScale*) gtk_scale_new_with_range (GTK_ORIENTATION_HORIZONTAL, (gdouble) 0, (gdouble) 1, 0.05);
	g_object_ref_sink (_tmp3_);
	_data2_->progress_scale = _tmp3_;
	_tmp4_ = (GtkLabel*) gtk_label_new ("Show Badge:");
	g_object_ref_sink (_tmp4_);
	badge_visible_label = _tmp4_;
	_tmp5_ = (GtkSwitch*) gtk_switch_new ();
	g_object_ref_sink (_tmp5_);
	_data2_->badge_visible_switch = _tmp5_;
	_tmp6_ = _data2_->badge_visible_switch;
	gtk_widget_set_valign ((GtkWidget*) _tmp6_, GTK_ALIGN_CENTER);
	_tmp7_ = (GtkSpinButton*) gtk_spin_button_new_with_range ((gdouble) 0, (gdouble) G_MAXINT64, (gdouble) 1);
	g_object_ref_sink (_tmp7_);
	_data2_->badge_spin = _tmp7_;
	_tmp8_ = (GtkGrid*) gtk_grid_new ();
	gtk_grid_set_column_spacing (_tmp8_, 12);
	gtk_grid_set_row_spacing (_tmp8_, 6);
	gtk_widget_set_halign ((GtkWidget*) _tmp8_, GTK_ALIGN_CENTER);
	gtk_widget_set_valign ((GtkWidget*) _tmp8_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp8_);
	grid = _tmp8_;
	_tmp9_ = grid;
	_tmp10_ = progress_visible_label;
	gtk_grid_attach (_tmp9_, (GtkWidget*) _tmp10_, 0, 0, 1, 1);
	_tmp11_ = grid;
	_tmp12_ = _data2_->progress_visible_switch;
	gtk_grid_attach (_tmp11_, (GtkWidget*) _tmp12_, 1, 0, 1, 1);
	_tmp13_ = grid;
	_tmp14_ = _data2_->progress_scale;
	gtk_grid_attach (_tmp13_, (GtkWidget*) _tmp14_, 2, 0, 1, 1);
	_tmp15_ = grid;
	_tmp16_ = badge_visible_label;
	gtk_grid_attach (_tmp15_, (GtkWidget*) _tmp16_, 0, 1, 1, 1);
	_tmp17_ = grid;
	_tmp18_ = _data2_->badge_visible_switch;
	gtk_grid_attach (_tmp17_, (GtkWidget*) _tmp18_, 1, 1, 1, 1);
	_tmp19_ = grid;
	_tmp20_ = _data2_->badge_spin;
	gtk_grid_attach (_tmp19_, (GtkWidget*) _tmp20_, 2, 1, 1, 1);
	_tmp21_ = grid;
	demo_page_set_child ((DemoPage*) self, (GtkWidget*) _tmp21_);
	_tmp22_ = _data2_->progress_visible_switch;
	_tmp23_ = _data2_->progress_scale;
	g_object_bind_property_with_closures ((GObject*) _tmp22_, "active", (GObject*) _tmp23_, "sensitive", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp24_ = _data2_->badge_visible_switch;
	_tmp25_ = _data2_->badge_spin;
	g_object_bind_property_with_closures ((GObject*) _tmp24_, "active", (GObject*) _tmp25_, "sensitive", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp26_ = _data2_->progress_scale;
	g_signal_connect_data ((GtkRange*) _tmp26_, "value-changed", (GCallback) __application_view___lambda20__gtk_range_value_changed, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
	_tmp27_ = _data2_->progress_visible_switch;
	g_signal_connect_data ((GObject*) _tmp27_, "notify::active", (GCallback) __application_view___lambda22__g_object_notify, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
	_tmp28_ = _data2_->badge_spin;
	g_signal_connect_data (_tmp28_, "value-changed", (GCallback) __application_view___lambda24__gtk_spin_button_value_changed, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
	_tmp29_ = _data2_->badge_visible_switch;
	g_signal_connect_data ((GObject*) _tmp29_, "notify::active", (GCallback) __application_view___lambda26__g_object_notify, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
	_g_object_unref0 (grid);
	_g_object_unref0 (badge_visible_label);
	_g_object_unref0 (progress_visible_label);
	block2_data_unref (_data2_);
	_data2_ = NULL;
	return obj;
}

static void
application_view_class_init (ApplicationViewClass * klass,
                             gpointer klass_data)
{
	application_view_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->constructor = application_view_constructor;
}

static void
application_view_instance_init (ApplicationView * self,
                                gpointer klass)
{
}

static GType
application_view_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ApplicationViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) application_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ApplicationView), 0, (GInstanceInitFunc) application_view_instance_init, NULL };
	GType application_view_type_id;
	application_view_type_id = g_type_register_static (TYPE_DEMO_PAGE, "ApplicationView", &g_define_type_info, 0);
	return application_view_type_id;
}

GType
application_view_get_type (void)
{
	static volatile gsize application_view_type_id__once = 0;
	if (g_once_init_enter (&application_view_type_id__once)) {
		GType application_view_type_id;
		application_view_type_id = application_view_get_type_once ();
		g_once_init_leave (&application_view_type_id__once, application_view_type_id);
	}
	return application_view_type_id__once;
}

