/* ControlsView.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from ControlsView.vala, do not modify */

/*
 * Copyright 2011-2021 elementary, Inc. (https://elementary.io)
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */

#include "granite-7.h"
#include <glib-object.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <float.h>
#include <math.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_DEMO_PAGE (demo_page_get_type ())
#define DEMO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DEMO_PAGE, DemoPage))
#define DEMO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DEMO_PAGE, DemoPageClass))
#define IS_DEMO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DEMO_PAGE))
#define IS_DEMO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DEMO_PAGE))
#define DEMO_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DEMO_PAGE, DemoPageClass))

typedef struct _DemoPage DemoPage;
typedef struct _DemoPageClass DemoPageClass;
typedef struct _DemoPagePrivate DemoPagePrivate;

#define TYPE_CONTROLS_VIEW (controls_view_get_type ())
#define CONTROLS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONTROLS_VIEW, ControlsView))
#define CONTROLS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONTROLS_VIEW, ControlsViewClass))
#define IS_CONTROLS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONTROLS_VIEW))
#define IS_CONTROLS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONTROLS_VIEW))
#define CONTROLS_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONTROLS_VIEW, ControlsViewClass))

typedef struct _ControlsView ControlsView;
typedef struct _ControlsViewClass ControlsViewClass;
typedef struct _ControlsViewPrivate ControlsViewPrivate;
enum  {
	CONTROLS_VIEW_0_PROPERTY,
	CONTROLS_VIEW_NUM_PROPERTIES
};
static GParamSpec* controls_view_properties[CONTROLS_VIEW_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))

struct _DemoPage {
	GraniteToolBox parent_instance;
	DemoPagePrivate * priv;
};

struct _DemoPageClass {
	GraniteToolBoxClass parent_class;
};

struct _ControlsView {
	DemoPage parent_instance;
	ControlsViewPrivate * priv;
};

struct _ControlsViewClass {
	DemoPageClass parent_class;
};

static gpointer controls_view_parent_class = NULL;

VALA_EXTERN GType demo_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DemoPage, g_object_unref)
VALA_EXTERN GType controls_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ControlsView, g_object_unref)
VALA_EXTERN ControlsView* controls_view_new (void);
VALA_EXTERN ControlsView* controls_view_construct (GType object_type);
VALA_EXTERN DemoPage* demo_page_new (void);
VALA_EXTERN DemoPage* demo_page_construct (GType object_type);
static GObject * controls_view_constructor (GType type,
                                     guint n_construct_properties,
                                     GObjectConstructParam * construct_properties);
static GVariant* _variant_new3 (const gchar* value);
static GVariant* _variant_new4 (const gchar* value);
static GVariant* _variant_new5 (const gchar* value);
VALA_EXTERN void demo_page_set_child (DemoPage* self,
                          GtkWidget* value);
static GType controls_view_get_type_once (void);

ControlsView*
controls_view_construct (GType object_type)
{
	ControlsView * self = NULL;
	self = (ControlsView*) demo_page_construct (object_type);
	return self;
}

ControlsView*
controls_view_new (void)
{
	return controls_view_construct (TYPE_CONTROLS_VIEW);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static GVariant*
_variant_new3 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static GVariant*
_variant_new4 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static GVariant*
_variant_new5 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static GObject *
controls_view_constructor (GType type,
                           guint n_construct_properties,
                           GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	ControlsView * self;
	GraniteHeaderLabel* button_header = NULL;
	GraniteHeaderLabel* _tmp0_;
	GtkButton* textbutton = NULL;
	GtkButton* _tmp1_;
	GtkToggleButton* toggle_button = NULL;
	GtkToggleButton* _tmp2_ = NULL;
	GtkButton* imagebutton = NULL;
	gchar* _tmp3_;
	GtkButton* _tmp4_ = NULL;
	GtkToggleButton* toggle_imagebutton = NULL;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GtkToggleButton* _tmp7_ = NULL;
	GraniteBackButton* back_button = NULL;
	GraniteBackButton* _tmp8_ = NULL;
	GtkButton* destructive_button = NULL;
	GtkButton* _tmp9_;
	GtkButton* _tmp10_;
	GtkButton* suggested_button = NULL;
	GtkButton* _tmp11_;
	GtkButton* _tmp12_;
	GraniteBox* button_box = NULL;
	GraniteBox* _tmp13_;
	GraniteBox* _tmp14_;
	GtkButton* _tmp15_;
	GraniteBox* _tmp16_;
	GtkToggleButton* _tmp17_;
	GraniteBox* _tmp18_;
	GraniteBackButton* _tmp19_;
	GraniteBox* _tmp20_;
	GtkButton* _tmp21_;
	GraniteBox* _tmp22_;
	GtkButton* _tmp23_;
	GraniteBox* _tmp24_;
	GtkButton* _tmp25_;
	GraniteBox* _tmp26_;
	GtkToggleButton* _tmp27_;
	GraniteHeaderLabel* checkradio_header = NULL;
	GraniteHeaderLabel* _tmp28_;
	GtkCheckButton* checked_checkbutton = NULL;
	GtkCheckButton* _tmp29_ = NULL;
	GtkCheckButton* checkbutton = NULL;
	GtkCheckButton* _tmp30_;
	GtkCheckButton* inconsistent_checkbutton = NULL;
	GtkCheckButton* _tmp31_ = NULL;
	GraniteBox* checkbutton_box = NULL;
	GraniteBox* _tmp32_;
	GraniteBox* _tmp33_;
	GtkCheckButton* _tmp34_;
	GraniteBox* _tmp35_;
	GtkCheckButton* _tmp36_;
	GraniteBox* _tmp37_;
	GtkCheckButton* _tmp38_;
	GtkCheckButton* checked_radiobutton = NULL;
	GtkCheckButton* _tmp39_ = NULL;
	GtkCheckButton* radiobutton = NULL;
	GtkCheckButton* _tmp40_;
	GtkCheckButton* _tmp41_;
	GtkCheckButton* _tmp42_ = NULL;
	GtkCheckButton* inconsistent_radiobutton = NULL;
	GtkCheckButton* _tmp43_;
	GtkCheckButton* _tmp44_;
	GtkCheckButton* _tmp45_ = NULL;
	GraniteBox* radiobutton_box = NULL;
	GraniteBox* _tmp46_;
	GraniteBox* _tmp47_;
	GtkCheckButton* _tmp48_;
	GraniteBox* _tmp49_;
	GtkCheckButton* _tmp50_;
	GraniteBox* _tmp51_;
	GtkCheckButton* _tmp52_;
	GraniteBox* checkradio_box = NULL;
	GraniteBox* _tmp53_;
	GraniteBox* _tmp54_;
	GraniteBox* _tmp55_;
	GraniteBox* _tmp56_;
	GraniteBox* _tmp57_;
	GraniteHeaderLabel* mode_switch_label = NULL;
	GraniteHeaderLabel* _tmp58_;
	GraniteHeaderLabel* _tmp59_;
	GraniteModeSwitch* mode_switch = NULL;
	GraniteModeSwitch* _tmp60_;
	GraniteModeSwitch* _tmp61_;
	GraniteModeSwitch* _tmp62_;
	GraniteModeSwitch* _tmp63_;
	GraniteHeaderLabel* switchbutton_header = NULL;
	GraniteHeaderLabel* _tmp64_ = NULL;
	GraniteSwitchModelButton* header_switchmodelbutton = NULL;
	GraniteSwitchModelButton* _tmp65_;
	GraniteSwitchModelButton* _tmp66_;
	gchar* _tmp67_;
	gchar* _tmp68_;
	GraniteSwitchModelButton* switchmodelbutton = NULL;
	GraniteSwitchModelButton* _tmp69_;
	GraniteSwitchModelButton* description_switchmodelbutton = NULL;
	gchar* _tmp70_;
	GraniteSwitchModelButton* _tmp71_ = NULL;
	GMenuItem* header_item = NULL;
	GMenuItem* _tmp72_;
	GMenuItem* _tmp73_;
	GVariant* _tmp74_;
	GMenuItem* switch_item = NULL;
	GMenuItem* _tmp75_;
	GMenuItem* _tmp76_;
	GVariant* _tmp77_;
	GMenuItem* description_switch_item = NULL;
	GMenuItem* _tmp78_;
	GMenuItem* _tmp79_;
	GVariant* _tmp80_;
	GMenu* menu_model = NULL;
	GMenu* _tmp81_;
	GMenu* _tmp82_;
	GMenuItem* _tmp83_;
	GMenu* _tmp84_;
	GMenuItem* _tmp85_;
	GMenu* _tmp86_;
	GMenuItem* _tmp87_;
	GtkPopoverMenu* switchbutton_popover = NULL;
	GMenu* _tmp88_;
	GtkPopoverMenu* _tmp89_ = NULL;
	GtkPopoverMenu* _tmp90_;
	GraniteSwitchModelButton* _tmp91_;
	GtkPopoverMenu* _tmp92_;
	GraniteSwitchModelButton* _tmp93_;
	GtkPopoverMenu* _tmp94_;
	GraniteSwitchModelButton* _tmp95_;
	GtkMenuButton* popover_button = NULL;
	GtkMenuButton* _tmp96_ = NULL;
	GtkMenuButton* _tmp97_;
	GtkPopoverMenu* _tmp98_;
	GraniteHeaderLabel* scale_header = NULL;
	GraniteHeaderLabel* _tmp99_;
	GtkScale* hscale = NULL;
	GtkScale* _tmp100_ = NULL;
	GtkScale* _tmp101_;
	GtkAdjustment* _tmp102_;
	GtkAdjustment* _tmp103_;
	GtkProgressBar* hprogressbar = NULL;
	GtkProgressBar* _tmp104_;
	GtkScale* _tmp105_;
	GtkAdjustment* _tmp106_;
	GtkAdjustment* _tmp107_;
	GtkProgressBar* _tmp108_;
	GraniteBox* hcontrol_box = NULL;
	GraniteBox* _tmp109_;
	GraniteBox* _tmp110_;
	GtkScale* _tmp111_;
	GraniteBox* _tmp112_;
	GtkProgressBar* _tmp113_;
	GtkScale* vscale = NULL;
	GtkScale* _tmp114_ = NULL;
	GtkScale* _tmp115_;
	GtkAdjustment* _tmp116_;
	GtkAdjustment* _tmp117_;
	GtkProgressBar* vprogressbar = NULL;
	GtkProgressBar* _tmp118_ = NULL;
	GtkScale* _tmp119_;
	GtkAdjustment* _tmp120_;
	GtkAdjustment* _tmp121_;
	GtkProgressBar* _tmp122_;
	GraniteBox* vcontrol_box = NULL;
	GraniteBox* _tmp123_;
	GraniteBox* _tmp124_;
	GtkScale* _tmp125_;
	GraniteBox* _tmp126_;
	GtkProgressBar* _tmp127_;
	GraniteBox* scale_box = NULL;
	GraniteBox* _tmp128_;
	GraniteBox* _tmp129_;
	GraniteBox* _tmp130_;
	GraniteBox* _tmp131_;
	GraniteBox* _tmp132_;
	GraniteBox* box = NULL;
	GraniteBox* _tmp133_ = NULL;
	GraniteBox* _tmp134_;
	GraniteHeaderLabel* _tmp135_;
	GraniteBox* _tmp136_;
	GraniteBox* _tmp137_;
	GraniteBox* _tmp138_;
	GraniteHeaderLabel* _tmp139_;
	GraniteBox* _tmp140_;
	GraniteBox* _tmp141_;
	GraniteBox* _tmp142_;
	GraniteHeaderLabel* _tmp143_;
	GraniteBox* _tmp144_;
	GraniteModeSwitch* _tmp145_;
	GraniteBox* _tmp146_;
	GraniteHeaderLabel* _tmp147_;
	GraniteBox* _tmp148_;
	GtkMenuButton* _tmp149_;
	GraniteBox* _tmp150_;
	GraniteHeaderLabel* _tmp151_;
	GraniteBox* _tmp152_;
	GraniteBox* _tmp153_;
	GraniteBox* _tmp154_;
	parent_class = G_OBJECT_CLASS (controls_view_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_CONTROLS_VIEW, ControlsView);
	_tmp0_ = granite_header_label_new ("Buttons");
	g_object_ref_sink (_tmp0_);
	button_header = _tmp0_;
	_tmp1_ = (GtkButton*) gtk_button_new_with_label ("Gtk.Button.with_label ()");
	g_object_ref_sink (_tmp1_);
	textbutton = _tmp1_;
	_tmp2_ = (GtkToggleButton*) gtk_toggle_button_new_with_label ("Gtk.ToggleButton.with_label ()");
	gtk_toggle_button_set_active (_tmp2_, TRUE);
	g_object_ref_sink (_tmp2_);
	toggle_button = _tmp2_;
	_tmp3_ = g_strdup ("Gtk.Button.from_icon_name ()");
	_tmp4_ = (GtkButton*) gtk_button_new_from_icon_name ("folder-pictures-symbolic");
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp4_, _tmp3_);
	_g_free0 (_tmp3_);
	g_object_ref_sink (_tmp4_);
	imagebutton = _tmp4_;
	_tmp5_ = g_strdup ("eye-open-negative-filled-symbolic");
	_tmp6_ = g_strdup ("Gtk.ToggleButton.icon_name");
	_tmp7_ = (GtkToggleButton*) gtk_toggle_button_new ();
	gtk_toggle_button_set_active (_tmp7_, TRUE);
	gtk_button_set_icon_name ((GtkButton*) _tmp7_, _tmp5_);
	_g_free0 (_tmp5_);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp7_, _tmp6_);
	_g_free0 (_tmp6_);
	g_object_ref_sink (_tmp7_);
	toggle_imagebutton = _tmp7_;
	_tmp8_ = granite_back_button_new ("Granite.BackButton");
	gtk_widget_set_halign ((GtkWidget*) _tmp8_, GTK_ALIGN_START);
	g_object_ref_sink (_tmp8_);
	back_button = _tmp8_;
	_tmp9_ = (GtkButton*) gtk_button_new_with_label ("Granite.CssClass.DESTRUCTIVE");
	g_object_ref_sink (_tmp9_);
	destructive_button = _tmp9_;
	_tmp10_ = destructive_button;
	gtk_widget_add_css_class ((GtkWidget*) _tmp10_, GRANITE_CSS_CLASS_DESTRUCTIVE);
	_tmp11_ = (GtkButton*) gtk_button_new_with_label ("Granite.CssClass.SUGGESTED");
	g_object_ref_sink (_tmp11_);
	suggested_button = _tmp11_;
	_tmp12_ = suggested_button;
	gtk_widget_add_css_class ((GtkWidget*) _tmp12_, GRANITE_CSS_CLASS_SUGGESTED);
	_tmp13_ = granite_box_new (GTK_ORIENTATION_VERTICAL, GRANITE_BOX_SPACING_HALF);
	g_object_ref_sink (_tmp13_);
	button_box = _tmp13_;
	_tmp14_ = button_box;
	_tmp15_ = textbutton;
	gtk_box_append ((GtkBox*) _tmp14_, (GtkWidget*) _tmp15_);
	_tmp16_ = button_box;
	_tmp17_ = toggle_button;
	gtk_box_append ((GtkBox*) _tmp16_, (GtkWidget*) _tmp17_);
	_tmp18_ = button_box;
	_tmp19_ = back_button;
	gtk_box_append ((GtkBox*) _tmp18_, (GtkWidget*) _tmp19_);
	_tmp20_ = button_box;
	_tmp21_ = destructive_button;
	gtk_box_append ((GtkBox*) _tmp20_, (GtkWidget*) _tmp21_);
	_tmp22_ = button_box;
	_tmp23_ = suggested_button;
	gtk_box_append ((GtkBox*) _tmp22_, (GtkWidget*) _tmp23_);
	_tmp24_ = button_box;
	_tmp25_ = imagebutton;
	gtk_box_append ((GtkBox*) _tmp24_, (GtkWidget*) _tmp25_);
	_tmp26_ = button_box;
	_tmp27_ = toggle_imagebutton;
	gtk_box_append ((GtkBox*) _tmp26_, (GtkWidget*) _tmp27_);
	_tmp28_ = granite_header_label_new ("Check & Radio Buttons");
	g_object_ref_sink (_tmp28_);
	checkradio_header = _tmp28_;
	_tmp29_ = (GtkCheckButton*) gtk_check_button_new_with_label ("active");
	gtk_check_button_set_active (_tmp29_, TRUE);
	g_object_ref_sink (_tmp29_);
	checked_checkbutton = _tmp29_;
	_tmp30_ = (GtkCheckButton*) gtk_check_button_new_with_label ("inactive");
	g_object_ref_sink (_tmp30_);
	checkbutton = _tmp30_;
	_tmp31_ = (GtkCheckButton*) gtk_check_button_new_with_label ("inconsistent");
	gtk_check_button_set_inconsistent (_tmp31_, TRUE);
	g_object_ref_sink (_tmp31_);
	inconsistent_checkbutton = _tmp31_;
	_tmp32_ = granite_box_new (GTK_ORIENTATION_VERTICAL, GRANITE_BOX_SPACING_HALF);
	g_object_ref_sink (_tmp32_);
	checkbutton_box = _tmp32_;
	_tmp33_ = checkbutton_box;
	_tmp34_ = checked_checkbutton;
	gtk_box_append ((GtkBox*) _tmp33_, (GtkWidget*) _tmp34_);
	_tmp35_ = checkbutton_box;
	_tmp36_ = checkbutton;
	gtk_box_append ((GtkBox*) _tmp35_, (GtkWidget*) _tmp36_);
	_tmp37_ = checkbutton_box;
	_tmp38_ = inconsistent_checkbutton;
	gtk_box_append ((GtkBox*) _tmp37_, (GtkWidget*) _tmp38_);
	_tmp39_ = (GtkCheckButton*) gtk_check_button_new_with_label ("active");
	gtk_check_button_set_active (_tmp39_, TRUE);
	g_object_ref_sink (_tmp39_);
	checked_radiobutton = _tmp39_;
	_tmp40_ = checked_radiobutton;
	_tmp41_ = _g_object_ref0 (_tmp40_);
	_tmp42_ = (GtkCheckButton*) gtk_check_button_new_with_label ("inactive");
	gtk_check_button_set_group (_tmp42_, _tmp41_);
	_g_object_unref0 (_tmp41_);
	g_object_ref_sink (_tmp42_);
	radiobutton = _tmp42_;
	_tmp43_ = checked_radiobutton;
	_tmp44_ = _g_object_ref0 (_tmp43_);
	_tmp45_ = (GtkCheckButton*) gtk_check_button_new_with_label ("inconsistent");
	gtk_check_button_set_group (_tmp45_, _tmp44_);
	_g_object_unref0 (_tmp44_);
	gtk_check_button_set_inconsistent (_tmp45_, TRUE);
	g_object_ref_sink (_tmp45_);
	inconsistent_radiobutton = _tmp45_;
	_tmp46_ = granite_box_new (GTK_ORIENTATION_VERTICAL, GRANITE_BOX_SPACING_HALF);
	g_object_ref_sink (_tmp46_);
	radiobutton_box = _tmp46_;
	_tmp47_ = radiobutton_box;
	_tmp48_ = checked_radiobutton;
	gtk_box_append ((GtkBox*) _tmp47_, (GtkWidget*) _tmp48_);
	_tmp49_ = radiobutton_box;
	_tmp50_ = radiobutton;
	gtk_box_append ((GtkBox*) _tmp49_, (GtkWidget*) _tmp50_);
	_tmp51_ = radiobutton_box;
	_tmp52_ = inconsistent_radiobutton;
	gtk_box_append ((GtkBox*) _tmp51_, (GtkWidget*) _tmp52_);
	_tmp53_ = granite_box_new (GTK_ORIENTATION_HORIZONTAL, GRANITE_BOX_SPACING_SINGLE);
	g_object_ref_sink (_tmp53_);
	checkradio_box = _tmp53_;
	_tmp54_ = checkradio_box;
	_tmp55_ = checkbutton_box;
	gtk_box_append ((GtkBox*) _tmp54_, (GtkWidget*) _tmp55_);
	_tmp56_ = checkradio_box;
	_tmp57_ = radiobutton_box;
	gtk_box_append ((GtkBox*) _tmp56_, (GtkWidget*) _tmp57_);
	_tmp58_ = granite_header_label_new ("ModeSwitch");
	g_object_ref_sink (_tmp58_);
	mode_switch_label = _tmp58_;
	_tmp59_ = mode_switch_label;
	gtk_widget_set_margin_top ((GtkWidget*) _tmp59_, 12);
	_tmp60_ = granite_mode_switch_new_from_icon_name ("display-brightness-symbolic", "weather-clear-night-symbolic");
	g_object_ref_sink (_tmp60_);
	mode_switch = _tmp60_;
	_tmp61_ = mode_switch;
	granite_mode_switch_set_primary_icon_tooltip_text (_tmp61_, "Light background");
	_tmp62_ = mode_switch;
	granite_mode_switch_set_secondary_icon_tooltip_text (_tmp62_, "Dark background");
	_tmp63_ = mode_switch;
	gtk_widget_set_valign ((GtkWidget*) _tmp63_, GTK_ALIGN_CENTER);
	_tmp64_ = granite_header_label_new ("SwitchModelButton");
	gtk_widget_set_margin_top ((GtkWidget*) _tmp64_, 12);
	g_object_ref_sink (_tmp64_);
	switchbutton_header = _tmp64_;
	_tmp65_ = granite_switch_model_button_new ("Header");
	g_object_ref_sink (_tmp65_);
	header_switchmodelbutton = _tmp65_;
	_tmp66_ = header_switchmodelbutton;
	_tmp67_ = granite_header_label_size_to_string (GRANITE_HEADER_LABEL_SIZE_H4);
	_tmp68_ = _tmp67_;
	gtk_widget_add_css_class ((GtkWidget*) _tmp66_, _tmp68_);
	_g_free0 (_tmp68_);
	_tmp69_ = granite_switch_model_button_new ("Default");
	g_object_ref_sink (_tmp69_);
	switchmodelbutton = _tmp69_;
	_tmp70_ = g_strdup ("A description of additional affects related to the activation state of" \
" this switch");
	_tmp71_ = granite_switch_model_button_new ("A SwitchModelButton With A Description");
	gtk_toggle_button_set_active ((GtkToggleButton*) _tmp71_, TRUE);
	granite_switch_model_button_set_description (_tmp71_, _tmp70_);
	_g_free0 (_tmp70_);
	g_object_ref_sink (_tmp71_);
	description_switchmodelbutton = _tmp71_;
	_tmp72_ = g_menu_item_new (NULL, NULL);
	header_item = _tmp72_;
	_tmp73_ = header_item;
	_tmp74_ = _variant_new3 ("header");
	g_menu_item_set_attribute_value (_tmp73_, "custom", _tmp74_);
	_g_variant_unref0 (_tmp74_);
	_tmp75_ = g_menu_item_new (NULL, NULL);
	switch_item = _tmp75_;
	_tmp76_ = switch_item;
	_tmp77_ = _variant_new4 ("switch");
	g_menu_item_set_attribute_value (_tmp76_, "custom", _tmp77_);
	_g_variant_unref0 (_tmp77_);
	_tmp78_ = g_menu_item_new (NULL, NULL);
	description_switch_item = _tmp78_;
	_tmp79_ = description_switch_item;
	_tmp80_ = _variant_new5 ("description-switch");
	g_menu_item_set_attribute_value (_tmp79_, "custom", _tmp80_);
	_g_variant_unref0 (_tmp80_);
	_tmp81_ = g_menu_new ();
	menu_model = _tmp81_;
	_tmp82_ = menu_model;
	_tmp83_ = header_item;
	g_menu_append_item (_tmp82_, _tmp83_);
	_tmp84_ = menu_model;
	_tmp85_ = switch_item;
	g_menu_append_item (_tmp84_, _tmp85_);
	_tmp86_ = menu_model;
	_tmp87_ = description_switch_item;
	g_menu_append_item (_tmp86_, _tmp87_);
	_tmp88_ = menu_model;
	_tmp89_ = (GtkPopoverMenu*) gtk_popover_menu_new_from_model ((GMenuModel*) _tmp88_);
	gtk_popover_set_has_arrow ((GtkPopover*) _tmp89_, FALSE);
	g_object_ref_sink (_tmp89_);
	switchbutton_popover = _tmp89_;
	_tmp90_ = switchbutton_popover;
	_tmp91_ = header_switchmodelbutton;
	gtk_popover_menu_add_child (_tmp90_, (GtkWidget*) _tmp91_, "header");
	_tmp92_ = switchbutton_popover;
	_tmp93_ = switchmodelbutton;
	gtk_popover_menu_add_child (_tmp92_, (GtkWidget*) _tmp93_, "switch");
	_tmp94_ = switchbutton_popover;
	_tmp95_ = description_switchmodelbutton;
	gtk_popover_menu_add_child (_tmp94_, (GtkWidget*) _tmp95_, "description-switch");
	_tmp96_ = (GtkMenuButton*) gtk_menu_button_new ();
	gtk_menu_button_set_direction (_tmp96_, GTK_ARROW_UP);
	g_object_ref_sink (_tmp96_);
	popover_button = _tmp96_;
	_tmp97_ = popover_button;
	_tmp98_ = switchbutton_popover;
	gtk_menu_button_set_popover (_tmp97_, (GtkPopover*) _tmp98_);
	_tmp99_ = granite_header_label_new ("Scale");
	g_object_ref_sink (_tmp99_);
	scale_header = _tmp99_;
	_tmp100_ = (GtkScale*) gtk_scale_new_with_range (GTK_ORIENTATION_HORIZONTAL, (gdouble) 0, (gdouble) 1, 0.01);
	gtk_scale_set_draw_value (_tmp100_, TRUE);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp100_, TRUE);
	g_object_ref_sink (_tmp100_);
	hscale = _tmp100_;
	_tmp101_ = hscale;
	_tmp102_ = gtk_range_get_adjustment ((GtkRange*) _tmp101_);
	_tmp103_ = _tmp102_;
	gtk_adjustment_set_value (_tmp103_, 0.5);
	_tmp104_ = (GtkProgressBar*) gtk_progress_bar_new ();
	g_object_ref_sink (_tmp104_);
	hprogressbar = _tmp104_;
	_tmp105_ = hscale;
	_tmp106_ = gtk_range_get_adjustment ((GtkRange*) _tmp105_);
	_tmp107_ = _tmp106_;
	_tmp108_ = hprogressbar;
	g_object_bind_property_with_closures ((GObject*) _tmp107_, "value", (GObject*) _tmp108_, "fraction", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp109_ = granite_box_new (GTK_ORIENTATION_VERTICAL, GRANITE_BOX_SPACING_DOUBLE);
	g_object_ref_sink (_tmp109_);
	hcontrol_box = _tmp109_;
	_tmp110_ = hcontrol_box;
	_tmp111_ = hscale;
	gtk_box_append ((GtkBox*) _tmp110_, (GtkWidget*) _tmp111_);
	_tmp112_ = hcontrol_box;
	_tmp113_ = hprogressbar;
	gtk_box_append ((GtkBox*) _tmp112_, (GtkWidget*) _tmp113_);
	_tmp114_ = (GtkScale*) gtk_scale_new_with_range (GTK_ORIENTATION_VERTICAL, (gdouble) 0, (gdouble) 1, 0.01);
	g_object_set ((GtkWidget*) _tmp114_, "height-request", 128, NULL);
	gtk_scale_set_has_origin (_tmp114_, FALSE);
	g_object_ref_sink (_tmp114_);
	vscale = _tmp114_;
	_tmp115_ = vscale;
	_tmp116_ = gtk_range_get_adjustment ((GtkRange*) _tmp115_);
	_tmp117_ = _tmp116_;
	gtk_adjustment_set_value (_tmp117_, 0.5);
	_tmp118_ = (GtkProgressBar*) gtk_progress_bar_new ();
	gtk_progress_bar_set_inverted (_tmp118_, TRUE);
	gtk_orientable_set_orientation ((GtkOrientable*) _tmp118_, GTK_ORIENTATION_VERTICAL);
	g_object_ref_sink (_tmp118_);
	vprogressbar = _tmp118_;
	_tmp119_ = vscale;
	_tmp120_ = gtk_range_get_adjustment ((GtkRange*) _tmp119_);
	_tmp121_ = _tmp120_;
	_tmp122_ = vprogressbar;
	g_object_bind_property_with_closures ((GObject*) _tmp121_, "value", (GObject*) _tmp122_, "fraction", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp123_ = granite_box_new (GTK_ORIENTATION_HORIZONTAL, GRANITE_BOX_SPACING_DOUBLE);
	g_object_ref_sink (_tmp123_);
	vcontrol_box = _tmp123_;
	_tmp124_ = vcontrol_box;
	_tmp125_ = vscale;
	gtk_box_append ((GtkBox*) _tmp124_, (GtkWidget*) _tmp125_);
	_tmp126_ = vcontrol_box;
	_tmp127_ = vprogressbar;
	gtk_box_append ((GtkBox*) _tmp126_, (GtkWidget*) _tmp127_);
	_tmp128_ = granite_box_new (GTK_ORIENTATION_HORIZONTAL, GRANITE_BOX_SPACING_DOUBLE);
	g_object_ref_sink (_tmp128_);
	scale_box = _tmp128_;
	_tmp129_ = scale_box;
	_tmp130_ = hcontrol_box;
	gtk_box_append ((GtkBox*) _tmp129_, (GtkWidget*) _tmp130_);
	_tmp131_ = scale_box;
	_tmp132_ = vcontrol_box;
	gtk_box_append ((GtkBox*) _tmp131_, (GtkWidget*) _tmp132_);
	_tmp133_ = granite_box_new (GTK_ORIENTATION_VERTICAL, GRANITE_BOX_SPACING_NONE);
	gtk_widget_set_halign ((GtkWidget*) _tmp133_, GTK_ALIGN_CENTER);
	gtk_widget_set_valign ((GtkWidget*) _tmp133_, GTK_ALIGN_CENTER);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp133_, 12);
	g_object_ref_sink (_tmp133_);
	box = _tmp133_;
	_tmp134_ = box;
	_tmp135_ = button_header;
	gtk_box_append ((GtkBox*) _tmp134_, (GtkWidget*) _tmp135_);
	_tmp136_ = box;
	_tmp137_ = button_box;
	gtk_box_append ((GtkBox*) _tmp136_, (GtkWidget*) _tmp137_);
	_tmp138_ = box;
	_tmp139_ = checkradio_header;
	gtk_box_append ((GtkBox*) _tmp138_, (GtkWidget*) _tmp139_);
	_tmp140_ = box;
	_tmp141_ = checkradio_box;
	gtk_box_append ((GtkBox*) _tmp140_, (GtkWidget*) _tmp141_);
	_tmp142_ = box;
	_tmp143_ = mode_switch_label;
	gtk_box_append ((GtkBox*) _tmp142_, (GtkWidget*) _tmp143_);
	_tmp144_ = box;
	_tmp145_ = mode_switch;
	gtk_box_append ((GtkBox*) _tmp144_, (GtkWidget*) _tmp145_);
	_tmp146_ = box;
	_tmp147_ = switchbutton_header;
	gtk_box_append ((GtkBox*) _tmp146_, (GtkWidget*) _tmp147_);
	_tmp148_ = box;
	_tmp149_ = popover_button;
	gtk_box_append ((GtkBox*) _tmp148_, (GtkWidget*) _tmp149_);
	_tmp150_ = box;
	_tmp151_ = scale_header;
	gtk_box_append ((GtkBox*) _tmp150_, (GtkWidget*) _tmp151_);
	_tmp152_ = box;
	_tmp153_ = scale_box;
	gtk_box_append ((GtkBox*) _tmp152_, (GtkWidget*) _tmp153_);
	_tmp154_ = box;
	demo_page_set_child ((DemoPage*) self, (GtkWidget*) _tmp154_);
	_g_object_unref0 (box);
	_g_object_unref0 (scale_box);
	_g_object_unref0 (vcontrol_box);
	_g_object_unref0 (vprogressbar);
	_g_object_unref0 (vscale);
	_g_object_unref0 (hcontrol_box);
	_g_object_unref0 (hprogressbar);
	_g_object_unref0 (hscale);
	_g_object_unref0 (scale_header);
	_g_object_unref0 (popover_button);
	_g_object_unref0 (switchbutton_popover);
	_g_object_unref0 (menu_model);
	_g_object_unref0 (description_switch_item);
	_g_object_unref0 (switch_item);
	_g_object_unref0 (header_item);
	_g_object_unref0 (description_switchmodelbutton);
	_g_object_unref0 (switchmodelbutton);
	_g_object_unref0 (header_switchmodelbutton);
	_g_object_unref0 (switchbutton_header);
	_g_object_unref0 (mode_switch);
	_g_object_unref0 (mode_switch_label);
	_g_object_unref0 (checkradio_box);
	_g_object_unref0 (radiobutton_box);
	_g_object_unref0 (inconsistent_radiobutton);
	_g_object_unref0 (radiobutton);
	_g_object_unref0 (checked_radiobutton);
	_g_object_unref0 (checkbutton_box);
	_g_object_unref0 (inconsistent_checkbutton);
	_g_object_unref0 (checkbutton);
	_g_object_unref0 (checked_checkbutton);
	_g_object_unref0 (checkradio_header);
	_g_object_unref0 (button_box);
	_g_object_unref0 (suggested_button);
	_g_object_unref0 (destructive_button);
	_g_object_unref0 (back_button);
	_g_object_unref0 (toggle_imagebutton);
	_g_object_unref0 (imagebutton);
	_g_object_unref0 (toggle_button);
	_g_object_unref0 (textbutton);
	_g_object_unref0 (button_header);
	return obj;
}

static void
controls_view_class_init (ControlsViewClass * klass,
                          gpointer klass_data)
{
	controls_view_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->constructor = controls_view_constructor;
}

static void
controls_view_instance_init (ControlsView * self,
                             gpointer klass)
{
}

static GType
controls_view_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ControlsViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) controls_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ControlsView), 0, (GInstanceInitFunc) controls_view_instance_init, NULL };
	GType controls_view_type_id;
	controls_view_type_id = g_type_register_static (TYPE_DEMO_PAGE, "ControlsView", &g_define_type_info, 0);
	return controls_view_type_id;
}

GType
controls_view_get_type (void)
{
	static volatile gsize controls_view_type_id__once = 0;
	if (g_once_init_enter (&controls_view_type_id__once)) {
		GType controls_view_type_id;
		controls_view_type_id = controls_view_get_type_once ();
		g_once_init_leave (&controls_view_type_id__once, controls_view_type_id);
	}
	return controls_view_type_id__once;
}

