/* ListsView.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from ListsView.vala, do not modify */

/*
 * Copyright 2025 elementary, Inc. (https://elementary.io)
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */

#include "granite-7.h"
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gtk/gtk.h>
#include <gio/gio.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_DEMO_PAGE (demo_page_get_type ())
#define DEMO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DEMO_PAGE, DemoPage))
#define DEMO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DEMO_PAGE, DemoPageClass))
#define IS_DEMO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DEMO_PAGE))
#define IS_DEMO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DEMO_PAGE))
#define DEMO_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DEMO_PAGE, DemoPageClass))

typedef struct _DemoPage DemoPage;
typedef struct _DemoPageClass DemoPageClass;
typedef struct _DemoPagePrivate DemoPagePrivate;

#define TYPE_LISTS_VIEW (lists_view_get_type ())
#define LISTS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LISTS_VIEW, ListsView))
#define LISTS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LISTS_VIEW, ListsViewClass))
#define IS_LISTS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LISTS_VIEW))
#define IS_LISTS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LISTS_VIEW))
#define LISTS_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LISTS_VIEW, ListsViewClass))

typedef struct _ListsView ListsView;
typedef struct _ListsViewClass ListsViewClass;
typedef struct _ListsViewPrivate ListsViewPrivate;
enum  {
	LISTS_VIEW_0_PROPERTY,
	LISTS_VIEW_NUM_PROPERTIES
};
static GParamSpec* lists_view_properties[LISTS_VIEW_NUM_PROPERTIES];

#define LISTS_VIEW_TYPE_LIST_OBJECT (lists_view_list_object_get_type ())
#define LISTS_VIEW_LIST_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LISTS_VIEW_TYPE_LIST_OBJECT, ListsViewListObject))
#define LISTS_VIEW_LIST_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LISTS_VIEW_TYPE_LIST_OBJECT, ListsViewListObjectClass))
#define LISTS_VIEW_IS_LIST_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LISTS_VIEW_TYPE_LIST_OBJECT))
#define LISTS_VIEW_IS_LIST_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LISTS_VIEW_TYPE_LIST_OBJECT))
#define LISTS_VIEW_LIST_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LISTS_VIEW_TYPE_LIST_OBJECT, ListsViewListObjectClass))

typedef struct _ListsViewListObject ListsViewListObject;
typedef struct _ListsViewListObjectClass ListsViewListObjectClass;
typedef struct _ListsViewListObjectPrivate ListsViewListObjectPrivate;
enum  {
	LISTS_VIEW_LIST_OBJECT_0_PROPERTY,
	LISTS_VIEW_LIST_OBJECT_TEXT_PROPERTY,
	LISTS_VIEW_LIST_OBJECT_NUM_PROPERTIES
};
static GParamSpec* lists_view_list_object_properties[LISTS_VIEW_LIST_OBJECT_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

#define LISTS_VIEW_TYPE_GRID_OBJECT (lists_view_grid_object_get_type ())
#define LISTS_VIEW_GRID_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LISTS_VIEW_TYPE_GRID_OBJECT, ListsViewGridObject))
#define LISTS_VIEW_GRID_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LISTS_VIEW_TYPE_GRID_OBJECT, ListsViewGridObjectClass))
#define LISTS_VIEW_IS_GRID_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LISTS_VIEW_TYPE_GRID_OBJECT))
#define LISTS_VIEW_IS_GRID_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LISTS_VIEW_TYPE_GRID_OBJECT))
#define LISTS_VIEW_GRID_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LISTS_VIEW_TYPE_GRID_OBJECT, ListsViewGridObjectClass))

typedef struct _ListsViewGridObject ListsViewGridObject;
typedef struct _ListsViewGridObjectClass ListsViewGridObjectClass;
typedef struct _ListsViewGridObjectPrivate ListsViewGridObjectPrivate;
enum  {
	LISTS_VIEW_GRID_OBJECT_0_PROPERTY,
	LISTS_VIEW_GRID_OBJECT_TEXT_PROPERTY,
	LISTS_VIEW_GRID_OBJECT_ICON_NAME_PROPERTY,
	LISTS_VIEW_GRID_OBJECT_NUM_PROPERTIES
};
static GParamSpec* lists_view_grid_object_properties[LISTS_VIEW_GRID_OBJECT_NUM_PROPERTIES];

#define LISTS_VIEW_TYPE_GRID_ITEM (lists_view_grid_item_get_type ())
#define LISTS_VIEW_GRID_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LISTS_VIEW_TYPE_GRID_ITEM, ListsViewGridItem))
#define LISTS_VIEW_GRID_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LISTS_VIEW_TYPE_GRID_ITEM, ListsViewGridItemClass))
#define LISTS_VIEW_IS_GRID_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LISTS_VIEW_TYPE_GRID_ITEM))
#define LISTS_VIEW_IS_GRID_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LISTS_VIEW_TYPE_GRID_ITEM))
#define LISTS_VIEW_GRID_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LISTS_VIEW_TYPE_GRID_ITEM, ListsViewGridItemClass))

typedef struct _ListsViewGridItem ListsViewGridItem;
typedef struct _ListsViewGridItemClass ListsViewGridItemClass;
typedef struct _ListsViewGridItemPrivate ListsViewGridItemPrivate;
enum  {
	LISTS_VIEW_GRID_ITEM_0_PROPERTY,
	LISTS_VIEW_GRID_ITEM_TEXT_PROPERTY,
	LISTS_VIEW_GRID_ITEM_ICON_NAME_PROPERTY,
	LISTS_VIEW_GRID_ITEM_NUM_PROPERTIES
};
static GParamSpec* lists_view_grid_item_properties[LISTS_VIEW_GRID_ITEM_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block5Data Block5Data;
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))

struct _DemoPage {
	GraniteToolBox parent_instance;
	DemoPagePrivate * priv;
};

struct _DemoPageClass {
	GraniteToolBoxClass parent_class;
};

struct _ListsView {
	DemoPage parent_instance;
	ListsViewPrivate * priv;
};

struct _ListsViewClass {
	DemoPageClass parent_class;
};

struct _ListsViewListObject {
	GObject parent_instance;
	ListsViewListObjectPrivate * priv;
};

struct _ListsViewListObjectClass {
	GObjectClass parent_class;
};

struct _ListsViewListObjectPrivate {
	gchar* _text;
};

struct _ListsViewGridObject {
	GObject parent_instance;
	ListsViewGridObjectPrivate * priv;
};

struct _ListsViewGridObjectClass {
	GObjectClass parent_class;
};

struct _ListsViewGridObjectPrivate {
	gchar* _text;
	gchar* _icon_name;
};

struct _ListsViewGridItem {
	GraniteBox parent_instance;
	ListsViewGridItemPrivate * priv;
};

struct _ListsViewGridItemClass {
	GraniteBoxClass parent_class;
};

struct _ListsViewGridItemPrivate {
	gchar* _text;
	gchar* _icon_name;
};

struct _Block5Data {
	int _ref_count_;
	ListsView* self;
	GMenu* menu_model;
};

static gpointer lists_view_parent_class = NULL;
static gint ListsViewListObject_private_offset;
static gpointer lists_view_list_object_parent_class = NULL;
static gint ListsViewGridObject_private_offset;
static gpointer lists_view_grid_object_parent_class = NULL;
static gint ListsViewGridItem_private_offset;
static gpointer lists_view_grid_item_parent_class = NULL;

VALA_EXTERN GType demo_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DemoPage, g_object_unref)
VALA_EXTERN GType lists_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ListsView, g_object_unref)
VALA_EXTERN ListsView* lists_view_new (void);
VALA_EXTERN ListsView* lists_view_construct (GType object_type);
VALA_EXTERN DemoPage* demo_page_new (void);
VALA_EXTERN DemoPage* demo_page_construct (GType object_type);
static GType lists_view_list_object_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ListsViewListObject, g_object_unref)
static const gchar* lists_view_list_object_get_text (ListsViewListObject* self);
static void lists_view_list_object_set_text (ListsViewListObject* self,
                                      const gchar* value);
static ListsViewListObject* lists_view_list_object_new (void);
static ListsViewListObject* lists_view_list_object_construct (GType object_type);
static void lists_view_list_object_finalize (GObject * obj);
static GType lists_view_list_object_get_type_once (void);
static void _vala_lists_view_list_object_get_property (GObject * object,
                                                guint property_id,
                                                GValue * value,
                                                GParamSpec * pspec);
static void _vala_lists_view_list_object_set_property (GObject * object,
                                                guint property_id,
                                                const GValue * value,
                                                GParamSpec * pspec);
static GType lists_view_grid_object_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ListsViewGridObject, g_object_unref)
static const gchar* lists_view_grid_object_get_text (ListsViewGridObject* self);
static void lists_view_grid_object_set_text (ListsViewGridObject* self,
                                      const gchar* value);
static const gchar* lists_view_grid_object_get_icon_name (ListsViewGridObject* self);
static void lists_view_grid_object_set_icon_name (ListsViewGridObject* self,
                                           const gchar* value);
static ListsViewGridObject* lists_view_grid_object_new (void);
static ListsViewGridObject* lists_view_grid_object_construct (GType object_type);
static void lists_view_grid_object_finalize (GObject * obj);
static GType lists_view_grid_object_get_type_once (void);
static void _vala_lists_view_grid_object_get_property (GObject * object,
                                                guint property_id,
                                                GValue * value,
                                                GParamSpec * pspec);
static void _vala_lists_view_grid_object_set_property (GObject * object,
                                                guint property_id,
                                                const GValue * value,
                                                GParamSpec * pspec);
static GType lists_view_grid_item_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ListsViewGridItem, g_object_unref)
static const gchar* lists_view_grid_item_get_text (ListsViewGridItem* self);
static void lists_view_grid_item_set_text (ListsViewGridItem* self,
                                    const gchar* value);
static const gchar* lists_view_grid_item_get_icon_name (ListsViewGridItem* self);
static void lists_view_grid_item_set_icon_name (ListsViewGridItem* self,
                                         const gchar* value);
static ListsViewGridItem* lists_view_grid_item_new (void);
static ListsViewGridItem* lists_view_grid_item_construct (GType object_type);
static GObject * lists_view_grid_item_constructor (GType type,
                                            guint n_construct_properties,
                                            GObjectConstructParam * construct_properties);
static void lists_view_grid_item_finalize (GObject * obj);
static GType lists_view_grid_item_get_type_once (void);
static void _vala_lists_view_grid_item_get_property (GObject * object,
                                              guint property_id,
                                              GValue * value,
                                              GParamSpec * pspec);
static void _vala_lists_view_grid_item_set_property (GObject * object,
                                              guint property_id,
                                              const GValue * value,
                                              GParamSpec * pspec);
static GObject * lists_view_constructor (GType type,
                                  guint n_construct_properties,
                                  GObjectConstructParam * construct_properties);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (void * _userdata_);
VALA_EXTERN void demo_page_set_title (DemoPage* self,
                          const gchar* value);
static GVariant* _variant_new6 (const gchar* value);
static GVariant* _variant_new7 (const gchar* value);
static GVariant* _variant_new8 (const gchar* value);
static GVariant* _variant_new9 (const gchar* value);
static void _lists_view___lambda4_ (Block5Data* _data5_,
                             GObject* obj);
static void __lists_view___lambda4__gtk_signal_list_item_factory_setup (GtkSignalListItemFactory* _sender,
                                                                 GObject* object,
                                                                 gpointer self);
static void _lists_view___lambda5_ (ListsView* self,
                             GObject* obj);
static void __lists_view___lambda5__gtk_signal_list_item_factory_bind (GtkSignalListItemFactory* _sender,
                                                                GObject* object,
                                                                gpointer self);
static void _lists_view___lambda6_ (ListsView* self,
                             GObject* obj);
static void __lists_view___lambda6__gtk_signal_list_item_factory_setup (GtkSignalListItemFactory* _sender,
                                                                 GObject* object,
                                                                 gpointer self);
static void _lists_view___lambda7_ (ListsView* self,
                             GObject* obj);
static void __lists_view___lambda7__gtk_signal_list_item_factory_bind (GtkSignalListItemFactory* _sender,
                                                                GObject* object,
                                                                gpointer self);
VALA_EXTERN void demo_page_set_child (DemoPage* self,
                          GtkWidget* value);
static GType lists_view_get_type_once (void);

ListsView*
lists_view_construct (GType object_type)
{
	ListsView * self = NULL;
	self = (ListsView*) demo_page_construct (object_type);
	return self;
}

ListsView*
lists_view_new (void)
{
	return lists_view_construct (TYPE_LISTS_VIEW);
}

static inline gpointer
lists_view_list_object_get_instance_private (ListsViewListObject* self)
{
	return G_STRUCT_MEMBER_P (self, ListsViewListObject_private_offset);
}

static const gchar*
lists_view_list_object_get_text (ListsViewListObject* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_text;
	result = _tmp0_;
	return result;
}

static void
lists_view_list_object_set_text (ListsViewListObject* self,
                                 const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = lists_view_list_object_get_text (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_text);
		self->priv->_text = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, lists_view_list_object_properties[LISTS_VIEW_LIST_OBJECT_TEXT_PROPERTY]);
	}
}

static ListsViewListObject*
lists_view_list_object_construct (GType object_type)
{
	ListsViewListObject * self = NULL;
	self = (ListsViewListObject*) g_object_new (object_type, NULL);
	return self;
}

static ListsViewListObject*
lists_view_list_object_new (void)
{
	return lists_view_list_object_construct (LISTS_VIEW_TYPE_LIST_OBJECT);
}

static void
lists_view_list_object_class_init (ListsViewListObjectClass * klass,
                                   gpointer klass_data)
{
	lists_view_list_object_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &ListsViewListObject_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_lists_view_list_object_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_lists_view_list_object_set_property;
	G_OBJECT_CLASS (klass)->finalize = lists_view_list_object_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), LISTS_VIEW_LIST_OBJECT_TEXT_PROPERTY, lists_view_list_object_properties[LISTS_VIEW_LIST_OBJECT_TEXT_PROPERTY] = g_param_spec_string ("text", "text", "text", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
lists_view_list_object_instance_init (ListsViewListObject * self,
                                      gpointer klass)
{
	self->priv = lists_view_list_object_get_instance_private (self);
}

static void
lists_view_list_object_finalize (GObject * obj)
{
	ListsViewListObject * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LISTS_VIEW_TYPE_LIST_OBJECT, ListsViewListObject);
	_g_free0 (self->priv->_text);
	G_OBJECT_CLASS (lists_view_list_object_parent_class)->finalize (obj);
}

static GType
lists_view_list_object_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ListsViewListObjectClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) lists_view_list_object_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ListsViewListObject), 0, (GInstanceInitFunc) lists_view_list_object_instance_init, NULL };
	GType lists_view_list_object_type_id;
	lists_view_list_object_type_id = g_type_register_static (G_TYPE_OBJECT, "ListsViewListObject", &g_define_type_info, 0);
	ListsViewListObject_private_offset = g_type_add_instance_private (lists_view_list_object_type_id, sizeof (ListsViewListObjectPrivate));
	return lists_view_list_object_type_id;
}

static GType
lists_view_list_object_get_type (void)
{
	static volatile gsize lists_view_list_object_type_id__once = 0;
	if (g_once_init_enter (&lists_view_list_object_type_id__once)) {
		GType lists_view_list_object_type_id;
		lists_view_list_object_type_id = lists_view_list_object_get_type_once ();
		g_once_init_leave (&lists_view_list_object_type_id__once, lists_view_list_object_type_id);
	}
	return lists_view_list_object_type_id__once;
}

static void
_vala_lists_view_list_object_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec)
{
	ListsViewListObject * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, LISTS_VIEW_TYPE_LIST_OBJECT, ListsViewListObject);
	switch (property_id) {
		case LISTS_VIEW_LIST_OBJECT_TEXT_PROPERTY:
		g_value_set_string (value, lists_view_list_object_get_text (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_lists_view_list_object_set_property (GObject * object,
                                           guint property_id,
                                           const GValue * value,
                                           GParamSpec * pspec)
{
	ListsViewListObject * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, LISTS_VIEW_TYPE_LIST_OBJECT, ListsViewListObject);
	switch (property_id) {
		case LISTS_VIEW_LIST_OBJECT_TEXT_PROPERTY:
		lists_view_list_object_set_text (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
lists_view_grid_object_get_instance_private (ListsViewGridObject* self)
{
	return G_STRUCT_MEMBER_P (self, ListsViewGridObject_private_offset);
}

static const gchar*
lists_view_grid_object_get_text (ListsViewGridObject* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_text;
	result = _tmp0_;
	return result;
}

static void
lists_view_grid_object_set_text (ListsViewGridObject* self,
                                 const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = lists_view_grid_object_get_text (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_text);
		self->priv->_text = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, lists_view_grid_object_properties[LISTS_VIEW_GRID_OBJECT_TEXT_PROPERTY]);
	}
}

static const gchar*
lists_view_grid_object_get_icon_name (ListsViewGridObject* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_icon_name;
	result = _tmp0_;
	return result;
}

static void
lists_view_grid_object_set_icon_name (ListsViewGridObject* self,
                                      const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = lists_view_grid_object_get_icon_name (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_icon_name);
		self->priv->_icon_name = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, lists_view_grid_object_properties[LISTS_VIEW_GRID_OBJECT_ICON_NAME_PROPERTY]);
	}
}

static ListsViewGridObject*
lists_view_grid_object_construct (GType object_type)
{
	ListsViewGridObject * self = NULL;
	self = (ListsViewGridObject*) g_object_new (object_type, NULL);
	return self;
}

static ListsViewGridObject*
lists_view_grid_object_new (void)
{
	return lists_view_grid_object_construct (LISTS_VIEW_TYPE_GRID_OBJECT);
}

static void
lists_view_grid_object_class_init (ListsViewGridObjectClass * klass,
                                   gpointer klass_data)
{
	lists_view_grid_object_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &ListsViewGridObject_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_lists_view_grid_object_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_lists_view_grid_object_set_property;
	G_OBJECT_CLASS (klass)->finalize = lists_view_grid_object_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), LISTS_VIEW_GRID_OBJECT_TEXT_PROPERTY, lists_view_grid_object_properties[LISTS_VIEW_GRID_OBJECT_TEXT_PROPERTY] = g_param_spec_string ("text", "text", "text", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), LISTS_VIEW_GRID_OBJECT_ICON_NAME_PROPERTY, lists_view_grid_object_properties[LISTS_VIEW_GRID_OBJECT_ICON_NAME_PROPERTY] = g_param_spec_string ("icon-name", "icon-name", "icon-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
lists_view_grid_object_instance_init (ListsViewGridObject * self,
                                      gpointer klass)
{
	self->priv = lists_view_grid_object_get_instance_private (self);
}

static void
lists_view_grid_object_finalize (GObject * obj)
{
	ListsViewGridObject * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LISTS_VIEW_TYPE_GRID_OBJECT, ListsViewGridObject);
	_g_free0 (self->priv->_text);
	_g_free0 (self->priv->_icon_name);
	G_OBJECT_CLASS (lists_view_grid_object_parent_class)->finalize (obj);
}

static GType
lists_view_grid_object_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ListsViewGridObjectClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) lists_view_grid_object_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ListsViewGridObject), 0, (GInstanceInitFunc) lists_view_grid_object_instance_init, NULL };
	GType lists_view_grid_object_type_id;
	lists_view_grid_object_type_id = g_type_register_static (G_TYPE_OBJECT, "ListsViewGridObject", &g_define_type_info, 0);
	ListsViewGridObject_private_offset = g_type_add_instance_private (lists_view_grid_object_type_id, sizeof (ListsViewGridObjectPrivate));
	return lists_view_grid_object_type_id;
}

static GType
lists_view_grid_object_get_type (void)
{
	static volatile gsize lists_view_grid_object_type_id__once = 0;
	if (g_once_init_enter (&lists_view_grid_object_type_id__once)) {
		GType lists_view_grid_object_type_id;
		lists_view_grid_object_type_id = lists_view_grid_object_get_type_once ();
		g_once_init_leave (&lists_view_grid_object_type_id__once, lists_view_grid_object_type_id);
	}
	return lists_view_grid_object_type_id__once;
}

static void
_vala_lists_view_grid_object_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec)
{
	ListsViewGridObject * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, LISTS_VIEW_TYPE_GRID_OBJECT, ListsViewGridObject);
	switch (property_id) {
		case LISTS_VIEW_GRID_OBJECT_TEXT_PROPERTY:
		g_value_set_string (value, lists_view_grid_object_get_text (self));
		break;
		case LISTS_VIEW_GRID_OBJECT_ICON_NAME_PROPERTY:
		g_value_set_string (value, lists_view_grid_object_get_icon_name (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_lists_view_grid_object_set_property (GObject * object,
                                           guint property_id,
                                           const GValue * value,
                                           GParamSpec * pspec)
{
	ListsViewGridObject * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, LISTS_VIEW_TYPE_GRID_OBJECT, ListsViewGridObject);
	switch (property_id) {
		case LISTS_VIEW_GRID_OBJECT_TEXT_PROPERTY:
		lists_view_grid_object_set_text (self, g_value_get_string (value));
		break;
		case LISTS_VIEW_GRID_OBJECT_ICON_NAME_PROPERTY:
		lists_view_grid_object_set_icon_name (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
lists_view_grid_item_get_instance_private (ListsViewGridItem* self)
{
	return G_STRUCT_MEMBER_P (self, ListsViewGridItem_private_offset);
}

static const gchar*
lists_view_grid_item_get_text (ListsViewGridItem* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_text;
	result = _tmp0_;
	return result;
}

static void
lists_view_grid_item_set_text (ListsViewGridItem* self,
                               const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = lists_view_grid_item_get_text (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_text);
		self->priv->_text = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, lists_view_grid_item_properties[LISTS_VIEW_GRID_ITEM_TEXT_PROPERTY]);
	}
}

static const gchar*
lists_view_grid_item_get_icon_name (ListsViewGridItem* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_icon_name;
	result = _tmp0_;
	return result;
}

static void
lists_view_grid_item_set_icon_name (ListsViewGridItem* self,
                                    const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = lists_view_grid_item_get_icon_name (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_icon_name);
		self->priv->_icon_name = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, lists_view_grid_item_properties[LISTS_VIEW_GRID_ITEM_ICON_NAME_PROPERTY]);
	}
}

static ListsViewGridItem*
lists_view_grid_item_construct (GType object_type)
{
	ListsViewGridItem * self = NULL;
	self = (ListsViewGridItem*) g_object_new (object_type, "orientation", GTK_ORIENTATION_VERTICAL, NULL);
	return self;
}

static ListsViewGridItem*
lists_view_grid_item_new (void)
{
	return lists_view_grid_item_construct (LISTS_VIEW_TYPE_GRID_ITEM);
}

static GObject *
lists_view_grid_item_constructor (GType type,
                                  guint n_construct_properties,
                                  GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	ListsViewGridItem * self;
	GtkImage* image = NULL;
	const gchar* _tmp0_;
	GtkImage* _tmp1_ = NULL;
	GtkLabel* label = NULL;
	const gchar* _tmp2_;
	GtkLabel* _tmp3_;
	GtkImage* _tmp4_;
	GtkLabel* _tmp5_;
	GtkLabel* _tmp6_;
	GtkImage* _tmp7_;
	parent_class = G_OBJECT_CLASS (lists_view_grid_item_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LISTS_VIEW_TYPE_GRID_ITEM, ListsViewGridItem);
	_tmp0_ = self->priv->_icon_name;
	_tmp1_ = (GtkImage*) gtk_image_new_from_icon_name (_tmp0_);
	gtk_image_set_pixel_size (_tmp1_, 64);
	g_object_ref_sink (_tmp1_);
	image = _tmp1_;
	_tmp2_ = self->priv->_text;
	_tmp3_ = (GtkLabel*) gtk_label_new (_tmp2_);
	g_object_ref_sink (_tmp3_);
	label = _tmp3_;
	granite_box_set_child_spacing ((GraniteBox*) self, GRANITE_BOX_SPACING_HALF);
	_tmp4_ = image;
	gtk_box_append ((GtkBox*) self, (GtkWidget*) _tmp4_);
	_tmp5_ = label;
	gtk_box_append ((GtkBox*) self, (GtkWidget*) _tmp5_);
	_tmp6_ = label;
	g_object_bind_property_with_closures ((GObject*) self, "text", (GObject*) _tmp6_, "label", G_BINDING_DEFAULT, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp7_ = image;
	g_object_bind_property_with_closures ((GObject*) self, "icon-name", (GObject*) _tmp7_, "icon-name", G_BINDING_DEFAULT, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_g_object_unref0 (label);
	_g_object_unref0 (image);
	return obj;
}

static void
lists_view_grid_item_class_init (ListsViewGridItemClass * klass,
                                 gpointer klass_data)
{
	lists_view_grid_item_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &ListsViewGridItem_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_lists_view_grid_item_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_lists_view_grid_item_set_property;
	G_OBJECT_CLASS (klass)->constructor = lists_view_grid_item_constructor;
	G_OBJECT_CLASS (klass)->finalize = lists_view_grid_item_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), LISTS_VIEW_GRID_ITEM_TEXT_PROPERTY, lists_view_grid_item_properties[LISTS_VIEW_GRID_ITEM_TEXT_PROPERTY] = g_param_spec_string ("text", "text", "text", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), LISTS_VIEW_GRID_ITEM_ICON_NAME_PROPERTY, lists_view_grid_item_properties[LISTS_VIEW_GRID_ITEM_ICON_NAME_PROPERTY] = g_param_spec_string ("icon-name", "icon-name", "icon-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
lists_view_grid_item_instance_init (ListsViewGridItem * self,
                                    gpointer klass)
{
	self->priv = lists_view_grid_item_get_instance_private (self);
}

static void
lists_view_grid_item_finalize (GObject * obj)
{
	ListsViewGridItem * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LISTS_VIEW_TYPE_GRID_ITEM, ListsViewGridItem);
	_g_free0 (self->priv->_text);
	_g_free0 (self->priv->_icon_name);
	G_OBJECT_CLASS (lists_view_grid_item_parent_class)->finalize (obj);
}

static GType
lists_view_grid_item_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ListsViewGridItemClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) lists_view_grid_item_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ListsViewGridItem), 0, (GInstanceInitFunc) lists_view_grid_item_instance_init, NULL };
	GType lists_view_grid_item_type_id;
	lists_view_grid_item_type_id = g_type_register_static (GRANITE_TYPE_BOX, "ListsViewGridItem", &g_define_type_info, 0);
	ListsViewGridItem_private_offset = g_type_add_instance_private (lists_view_grid_item_type_id, sizeof (ListsViewGridItemPrivate));
	return lists_view_grid_item_type_id;
}

static GType
lists_view_grid_item_get_type (void)
{
	static volatile gsize lists_view_grid_item_type_id__once = 0;
	if (g_once_init_enter (&lists_view_grid_item_type_id__once)) {
		GType lists_view_grid_item_type_id;
		lists_view_grid_item_type_id = lists_view_grid_item_get_type_once ();
		g_once_init_leave (&lists_view_grid_item_type_id__once, lists_view_grid_item_type_id);
	}
	return lists_view_grid_item_type_id__once;
}

static void
_vala_lists_view_grid_item_get_property (GObject * object,
                                         guint property_id,
                                         GValue * value,
                                         GParamSpec * pspec)
{
	ListsViewGridItem * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, LISTS_VIEW_TYPE_GRID_ITEM, ListsViewGridItem);
	switch (property_id) {
		case LISTS_VIEW_GRID_ITEM_TEXT_PROPERTY:
		g_value_set_string (value, lists_view_grid_item_get_text (self));
		break;
		case LISTS_VIEW_GRID_ITEM_ICON_NAME_PROPERTY:
		g_value_set_string (value, lists_view_grid_item_get_icon_name (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_lists_view_grid_item_set_property (GObject * object,
                                         guint property_id,
                                         const GValue * value,
                                         GParamSpec * pspec)
{
	ListsViewGridItem * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, LISTS_VIEW_TYPE_GRID_ITEM, ListsViewGridItem);
	switch (property_id) {
		case LISTS_VIEW_GRID_ITEM_TEXT_PROPERTY:
		lists_view_grid_item_set_text (self, g_value_get_string (value));
		break;
		case LISTS_VIEW_GRID_ITEM_ICON_NAME_PROPERTY:
		lists_view_grid_item_set_icon_name (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static Block5Data*
block5_data_ref (Block5Data* _data5_)
{
	g_atomic_int_inc (&_data5_->_ref_count_);
	return _data5_;
}

static void
block5_data_unref (void * _userdata_)
{
	Block5Data* _data5_;
	_data5_ = (Block5Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
		ListsView* self;
		self = _data5_->self;
		_g_object_unref0 (_data5_->menu_model);
		_g_object_unref0 (self);
		g_slice_free (Block5Data, _data5_);
	}
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static GVariant*
_variant_new6 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static GVariant*
_variant_new7 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static GVariant*
_variant_new8 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static GVariant*
_variant_new9 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static void
_lists_view___lambda4_ (Block5Data* _data5_,
                        GObject* obj)
{
	ListsView* self;
	GtkListItem* list_item = NULL;
	GtkListItem* _tmp0_;
	GtkListItem* _tmp1_;
	GMenu* _tmp2_;
	GMenuModel* _tmp3_;
	GraniteListItem* _tmp4_ = NULL;
	GraniteListItem* _tmp5_;
	self = _data5_->self;
	g_return_if_fail (obj != NULL);
	_tmp0_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (obj, gtk_list_item_get_type (), GtkListItem));
	list_item = _tmp0_;
	_tmp1_ = list_item;
	_tmp2_ = _data5_->menu_model;
	_tmp3_ = _g_object_ref0 ((GMenuModel*) _tmp2_);
	_tmp4_ = granite_list_item_new ();
	granite_list_item_set_menu_model (_tmp4_, _tmp3_);
	_g_object_unref0 (_tmp3_);
	g_object_ref_sink (_tmp4_);
	_tmp5_ = _tmp4_;
	gtk_list_item_set_child (_tmp1_, (GtkWidget*) _tmp5_);
	_g_object_unref0 (_tmp5_);
	_g_object_unref0 (list_item);
}

static void
__lists_view___lambda4__gtk_signal_list_item_factory_setup (GtkSignalListItemFactory* _sender,
                                                            GObject* object,
                                                            gpointer self)
{
	_lists_view___lambda4_ (self, object);
}

static void
_lists_view___lambda5_ (ListsView* self,
                        GObject* obj)
{
	GtkListItem* list_item = NULL;
	GtkListItem* _tmp0_;
	ListsViewListObject* list_object = NULL;
	GtkListItem* _tmp1_;
	GObject* _tmp2_;
	GObject* _tmp3_;
	ListsViewListObject* _tmp4_;
	GraniteListItem* granite_list_item = NULL;
	GtkListItem* _tmp5_;
	GtkWidget* _tmp6_;
	GtkWidget* _tmp7_;
	GraniteListItem* _tmp8_;
	GraniteListItem* _tmp9_;
	ListsViewListObject* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	g_return_if_fail (obj != NULL);
	_tmp0_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (obj, gtk_list_item_get_type (), GtkListItem));
	list_item = _tmp0_;
	_tmp1_ = list_item;
	_tmp2_ = gtk_list_item_get_item (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, LISTS_VIEW_TYPE_LIST_OBJECT, ListsViewListObject));
	list_object = _tmp4_;
	_tmp5_ = list_item;
	_tmp6_ = gtk_list_item_get_child (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GRANITE_TYPE_LIST_ITEM, GraniteListItem));
	granite_list_item = _tmp8_;
	_tmp9_ = granite_list_item;
	_tmp10_ = list_object;
	_tmp11_ = lists_view_list_object_get_text (_tmp10_);
	_tmp12_ = _tmp11_;
	granite_list_item_set_text (_tmp9_, _tmp12_);
	_g_object_unref0 (granite_list_item);
	_g_object_unref0 (list_object);
	_g_object_unref0 (list_item);
}

static void
__lists_view___lambda5__gtk_signal_list_item_factory_bind (GtkSignalListItemFactory* _sender,
                                                           GObject* object,
                                                           gpointer self)
{
	_lists_view___lambda5_ ((ListsView*) self, object);
}

static void
_lists_view___lambda6_ (ListsView* self,
                        GObject* obj)
{
	GtkListItem* list_item = NULL;
	GtkListItem* _tmp0_;
	GtkListItem* _tmp1_;
	ListsViewGridItem* _tmp2_;
	ListsViewGridItem* _tmp3_;
	g_return_if_fail (obj != NULL);
	_tmp0_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (obj, gtk_list_item_get_type (), GtkListItem));
	list_item = _tmp0_;
	_tmp1_ = list_item;
	_tmp2_ = lists_view_grid_item_new ();
	g_object_ref_sink (_tmp2_);
	_tmp3_ = _tmp2_;
	gtk_list_item_set_child (_tmp1_, (GtkWidget*) _tmp3_);
	_g_object_unref0 (_tmp3_);
	_g_object_unref0 (list_item);
}

static void
__lists_view___lambda6__gtk_signal_list_item_factory_setup (GtkSignalListItemFactory* _sender,
                                                            GObject* object,
                                                            gpointer self)
{
	_lists_view___lambda6_ ((ListsView*) self, object);
}

static void
_lists_view___lambda7_ (ListsView* self,
                        GObject* obj)
{
	GtkListItem* list_item = NULL;
	GtkListItem* _tmp0_;
	ListsViewGridObject* grid_object = NULL;
	GtkListItem* _tmp1_;
	GObject* _tmp2_;
	GObject* _tmp3_;
	ListsViewGridObject* _tmp4_;
	ListsViewGridItem* grid_item = NULL;
	GtkListItem* _tmp5_;
	GtkWidget* _tmp6_;
	GtkWidget* _tmp7_;
	ListsViewGridItem* _tmp8_;
	ListsViewGridItem* _tmp9_;
	ListsViewGridObject* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	ListsViewGridItem* _tmp13_;
	ListsViewGridObject* _tmp14_;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	g_return_if_fail (obj != NULL);
	_tmp0_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (obj, gtk_list_item_get_type (), GtkListItem));
	list_item = _tmp0_;
	_tmp1_ = list_item;
	_tmp2_ = gtk_list_item_get_item (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, LISTS_VIEW_TYPE_GRID_OBJECT, ListsViewGridObject));
	grid_object = _tmp4_;
	_tmp5_ = list_item;
	_tmp6_ = gtk_list_item_get_child (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, LISTS_VIEW_TYPE_GRID_ITEM, ListsViewGridItem));
	grid_item = _tmp8_;
	_tmp9_ = grid_item;
	_tmp10_ = grid_object;
	_tmp11_ = lists_view_grid_object_get_text (_tmp10_);
	_tmp12_ = _tmp11_;
	lists_view_grid_item_set_text (_tmp9_, _tmp12_);
	_tmp13_ = grid_item;
	_tmp14_ = grid_object;
	_tmp15_ = lists_view_grid_object_get_icon_name (_tmp14_);
	_tmp16_ = _tmp15_;
	lists_view_grid_item_set_icon_name (_tmp13_, _tmp16_);
	_g_object_unref0 (grid_item);
	_g_object_unref0 (grid_object);
	_g_object_unref0 (list_item);
}

static void
__lists_view___lambda7__gtk_signal_list_item_factory_bind (GtkSignalListItemFactory* _sender,
                                                           GObject* object,
                                                           gpointer self)
{
	_lists_view___lambda7_ ((ListsView*) self, object);
}

static GObject *
lists_view_constructor (GType type,
                        guint n_construct_properties,
                        GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	ListsView * self;
	Block5Data* _data5_;
	GraniteHeaderLabel* card_title = NULL;
	gchar* _tmp0_;
	GraniteHeaderLabel* _tmp1_ = NULL;
	GraniteSwitchModelButton* separators_modelbutton = NULL;
	gchar* _tmp2_;
	GraniteSwitchModelButton* _tmp3_ = NULL;
	GtkListBox* list_box = NULL;
	GtkListBox* _tmp4_ = NULL;
	GtkListBox* _tmp5_;
	GtkListBox* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	GraniteListItem* _tmp9_ = NULL;
	GraniteListItem* _tmp10_;
	GtkListBox* _tmp11_;
	GraniteSwitchModelButton* _tmp12_;
	GtkWidget* _tmp13_;
	GraniteListItem* _tmp14_ = NULL;
	GraniteListItem* _tmp15_;
	GraniteHeaderLabel* list_title = NULL;
	gchar* _tmp16_;
	GraniteHeaderLabel* _tmp17_ = NULL;
	GMenuItem* reply_menuitem = NULL;
	GMenuItem* _tmp18_;
	GMenuItem* _tmp19_;
	GVariant* _tmp20_;
	GMenuItem* reply_all_menuitem = NULL;
	GMenuItem* _tmp21_;
	GMenuItem* _tmp22_;
	GVariant* _tmp23_;
	GMenuItem* forward_menuitem = NULL;
	GMenuItem* _tmp24_;
	GMenuItem* _tmp25_;
	GVariant* _tmp26_;
	GMenu* button_menu = NULL;
	GMenu* _tmp27_;
	GMenu* _tmp28_;
	GMenuItem* _tmp29_;
	GMenu* _tmp30_;
	GMenuItem* _tmp31_;
	GMenu* _tmp32_;
	GMenuItem* _tmp33_;
	GMenuItem* button_section = NULL;
	GMenu* _tmp34_;
	GMenuItem* _tmp35_;
	GMenuItem* _tmp36_;
	GVariant* _tmp37_;
	GMenu* _tmp38_;
	GMenu* _tmp39_;
	GMenuItem* _tmp40_;
	GMenu* _tmp41_;
	GMenu* _tmp42_;
	GListStore* list_store = NULL;
	GListStore* _tmp43_;
	GListStore* _tmp44_;
	gchar* _tmp45_;
	ListsViewListObject* _tmp46_ = NULL;
	ListsViewListObject* _tmp47_;
	GListStore* _tmp48_;
	gchar* _tmp49_;
	ListsViewListObject* _tmp50_ = NULL;
	ListsViewListObject* _tmp51_;
	GListStore* _tmp52_;
	gchar* _tmp53_;
	ListsViewListObject* _tmp54_ = NULL;
	ListsViewListObject* _tmp55_;
	GListStore* _tmp56_;
	gchar* _tmp57_;
	ListsViewListObject* _tmp58_ = NULL;
	ListsViewListObject* _tmp59_;
	GListStore* _tmp60_;
	gchar* _tmp61_;
	ListsViewListObject* _tmp62_ = NULL;
	ListsViewListObject* _tmp63_;
	GtkSingleSelection* list_selection = NULL;
	GListStore* _tmp64_;
	GListModel* _tmp65_;
	GtkSingleSelection* _tmp66_;
	GtkSignalListItemFactory* list_factory = NULL;
	GtkSignalListItemFactory* _tmp67_;
	GtkSignalListItemFactory* _tmp68_;
	GtkSignalListItemFactory* _tmp69_;
	GtkListView* list_view = NULL;
	GtkSingleSelection* _tmp70_;
	GtkSelectionModel* _tmp71_;
	GtkSignalListItemFactory* _tmp72_;
	GtkListItemFactory* _tmp73_;
	GtkListView* _tmp74_ = NULL;
	GtkScrolledWindow* list_scrolled = NULL;
	GtkListView* _tmp75_;
	GtkWidget* _tmp76_;
	GtkScrolledWindow* _tmp77_ = NULL;
	GraniteHeaderLabel* grid_title = NULL;
	GraniteHeaderLabel* _tmp78_;
	GListStore* grid_store = NULL;
	GListStore* _tmp79_;
	GListStore* _tmp80_;
	gchar* _tmp81_;
	gchar* _tmp82_;
	ListsViewGridObject* _tmp83_ = NULL;
	ListsViewGridObject* _tmp84_;
	GListStore* _tmp85_;
	gchar* _tmp86_;
	gchar* _tmp87_;
	ListsViewGridObject* _tmp88_ = NULL;
	ListsViewGridObject* _tmp89_;
	GListStore* _tmp90_;
	gchar* _tmp91_;
	gchar* _tmp92_;
	ListsViewGridObject* _tmp93_ = NULL;
	ListsViewGridObject* _tmp94_;
	GListStore* _tmp95_;
	gchar* _tmp96_;
	gchar* _tmp97_;
	ListsViewGridObject* _tmp98_ = NULL;
	ListsViewGridObject* _tmp99_;
	GListStore* _tmp100_;
	gchar* _tmp101_;
	gchar* _tmp102_;
	ListsViewGridObject* _tmp103_ = NULL;
	ListsViewGridObject* _tmp104_;
	GListStore* _tmp105_;
	gchar* _tmp106_;
	gchar* _tmp107_;
	ListsViewGridObject* _tmp108_ = NULL;
	ListsViewGridObject* _tmp109_;
	GListStore* _tmp110_;
	gchar* _tmp111_;
	gchar* _tmp112_;
	ListsViewGridObject* _tmp113_ = NULL;
	ListsViewGridObject* _tmp114_;
	GtkMultiSelection* grid_selection = NULL;
	GListStore* _tmp115_;
	GListModel* _tmp116_;
	GtkMultiSelection* _tmp117_;
	GtkSignalListItemFactory* grid_factory = NULL;
	GtkSignalListItemFactory* _tmp118_;
	GtkSignalListItemFactory* _tmp119_;
	GtkSignalListItemFactory* _tmp120_;
	GtkGridView* grid_view = NULL;
	GtkMultiSelection* _tmp121_;
	GtkSelectionModel* _tmp122_;
	GtkSignalListItemFactory* _tmp123_;
	GtkListItemFactory* _tmp124_;
	GtkGridView* _tmp125_ = NULL;
	GtkScrolledWindow* grid_scrolled = NULL;
	GtkGridView* _tmp126_;
	GtkWidget* _tmp127_;
	GtkScrolledWindow* _tmp128_ = NULL;
	GraniteBox* vbox = NULL;
	GraniteBox* _tmp129_ = NULL;
	GraniteBox* _tmp130_;
	GraniteHeaderLabel* _tmp131_;
	GraniteBox* _tmp132_;
	GtkListBox* _tmp133_;
	GraniteBox* _tmp134_;
	GraniteHeaderLabel* _tmp135_;
	GraniteBox* _tmp136_;
	GtkScrolledWindow* _tmp137_;
	GraniteBox* _tmp138_;
	GraniteHeaderLabel* _tmp139_;
	GraniteBox* _tmp140_;
	GtkScrolledWindow* _tmp141_;
	GraniteBox* _tmp142_;
	GraniteSwitchModelButton* _tmp143_;
	GtkListBox* _tmp144_;
	parent_class = G_OBJECT_CLASS (lists_view_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_LISTS_VIEW, ListsView);
	_data5_ = g_slice_new0 (Block5Data);
	_data5_->_ref_count_ = 1;
	_data5_->self = g_object_ref (self);
	demo_page_set_title ((DemoPage*) self, "Lists & Grids");
	_tmp0_ = g_strdup ("This ListBox has \"Granite.CssClass.CARD\"");
	_tmp1_ = granite_header_label_new ("Gtk.ListBox");
	granite_header_label_set_secondary_text (_tmp1_, _tmp0_);
	_g_free0 (_tmp0_);
	g_object_ref_sink (_tmp1_);
	card_title = _tmp1_;
	_tmp2_ = g_strdup ("\"show-separators = true\"");
	_tmp3_ = granite_switch_model_button_new ("Show Separators");
	gtk_toggle_button_set_active ((GtkToggleButton*) _tmp3_, TRUE);
	granite_switch_model_button_set_description (_tmp3_, _tmp2_);
	_g_free0 (_tmp2_);
	g_object_ref_sink (_tmp3_);
	separators_modelbutton = _tmp3_;
	_tmp4_ = (GtkListBox*) gtk_list_box_new ();
	gtk_list_box_set_show_separators (_tmp4_, TRUE);
	g_object_ref_sink (_tmp4_);
	list_box = _tmp4_;
	_tmp5_ = list_box;
	gtk_widget_add_css_class ((GtkWidget*) _tmp5_, GRANITE_CSS_CLASS_CARD);
	_tmp6_ = list_box;
	_tmp7_ = g_strdup ("This is a \"Granite.ListItem\"");
	_tmp8_ = g_strdup ("\"Granite.ListItem\" has a standardized row height and padding");
	_tmp9_ = granite_list_item_new ();
	granite_list_item_set_text (_tmp9_, _tmp7_);
	_g_free0 (_tmp7_);
	granite_list_item_set_description (_tmp9_, _tmp8_);
	_g_free0 (_tmp8_);
	g_object_ref_sink (_tmp9_);
	_tmp10_ = _tmp9_;
	gtk_list_box_append (_tmp6_, (GtkWidget*) _tmp10_);
	_g_object_unref0 (_tmp10_);
	_tmp11_ = list_box;
	_tmp12_ = separators_modelbutton;
	_tmp13_ = _g_object_ref0 ((GtkWidget*) _tmp12_);
	_tmp14_ = granite_list_item_new ();
	granite_list_item_set_child (_tmp14_, _tmp13_);
	_g_object_unref0 (_tmp13_);
	g_object_ref_sink (_tmp14_);
	_tmp15_ = _tmp14_;
	gtk_list_box_append (_tmp11_, (GtkWidget*) _tmp15_);
	_g_object_unref0 (_tmp15_);
	_tmp16_ = g_strdup ("ScrolledWindow with \"has-frame = true\" has a view level background c" \
"olor");
	_tmp17_ = granite_header_label_new ("Gtk.ListView");
	granite_header_label_set_secondary_text (_tmp17_, _tmp16_);
	_g_free0 (_tmp16_);
	g_object_ref_sink (_tmp17_);
	list_title = _tmp17_;
	_tmp18_ = g_menu_item_new ("Reply", NULL);
	reply_menuitem = _tmp18_;
	_tmp19_ = reply_menuitem;
	_tmp20_ = _variant_new6 ("mail-reply-sender-symbolic");
	g_menu_item_set_attribute_value (_tmp19_, "verb-icon", _tmp20_);
	_g_variant_unref0 (_tmp20_);
	_tmp21_ = g_menu_item_new ("Reply All", NULL);
	reply_all_menuitem = _tmp21_;
	_tmp22_ = reply_all_menuitem;
	_tmp23_ = _variant_new7 ("mail-reply-all-symbolic");
	g_menu_item_set_attribute_value (_tmp22_, "verb-icon", _tmp23_);
	_g_variant_unref0 (_tmp23_);
	_tmp24_ = g_menu_item_new ("Forward", NULL);
	forward_menuitem = _tmp24_;
	_tmp25_ = forward_menuitem;
	_tmp26_ = _variant_new8 ("mail-forward-symbolic");
	g_menu_item_set_attribute_value (_tmp25_, "verb-icon", _tmp26_);
	_g_variant_unref0 (_tmp26_);
	_tmp27_ = g_menu_new ();
	button_menu = _tmp27_;
	_tmp28_ = button_menu;
	_tmp29_ = reply_menuitem;
	g_menu_append_item (_tmp28_, _tmp29_);
	_tmp30_ = button_menu;
	_tmp31_ = reply_all_menuitem;
	g_menu_append_item (_tmp30_, _tmp31_);
	_tmp32_ = button_menu;
	_tmp33_ = forward_menuitem;
	g_menu_append_item (_tmp32_, _tmp33_);
	_tmp34_ = button_menu;
	_tmp35_ = g_menu_item_new_section (NULL, (GMenuModel*) _tmp34_);
	button_section = _tmp35_;
	_tmp36_ = button_section;
	_tmp37_ = _variant_new9 ("circular-buttons");
	g_menu_item_set_attribute_value (_tmp36_, "display-hint", _tmp37_);
	_g_variant_unref0 (_tmp37_);
	_tmp38_ = g_menu_new ();
	_data5_->menu_model = _tmp38_;
	_tmp39_ = _data5_->menu_model;
	_tmp40_ = button_section;
	g_menu_append_item (_tmp39_, _tmp40_);
	_tmp41_ = _data5_->menu_model;
	g_menu_append (_tmp41_, "Move", NULL);
	_tmp42_ = _data5_->menu_model;
	g_menu_append (_tmp42_, "Delete", NULL);
	_tmp43_ = g_list_store_new (LISTS_VIEW_TYPE_LIST_OBJECT);
	list_store = _tmp43_;
	_tmp44_ = list_store;
	_tmp45_ = g_strdup ("Row 1");
	_tmp46_ = lists_view_list_object_new ();
	lists_view_list_object_set_text (_tmp46_, _tmp45_);
	_g_free0 (_tmp45_);
	_tmp47_ = _tmp46_;
	g_list_store_append (_tmp44_, (GObject*) _tmp47_);
	_g_object_unref0 (_tmp47_);
	_tmp48_ = list_store;
	_tmp49_ = g_strdup ("Row 2");
	_tmp50_ = lists_view_list_object_new ();
	lists_view_list_object_set_text (_tmp50_, _tmp49_);
	_g_free0 (_tmp49_);
	_tmp51_ = _tmp50_;
	g_list_store_append (_tmp48_, (GObject*) _tmp51_);
	_g_object_unref0 (_tmp51_);
	_tmp52_ = list_store;
	_tmp53_ = g_strdup ("Row 3");
	_tmp54_ = lists_view_list_object_new ();
	lists_view_list_object_set_text (_tmp54_, _tmp53_);
	_g_free0 (_tmp53_);
	_tmp55_ = _tmp54_;
	g_list_store_append (_tmp52_, (GObject*) _tmp55_);
	_g_object_unref0 (_tmp55_);
	_tmp56_ = list_store;
	_tmp57_ = g_strdup ("Row 4");
	_tmp58_ = lists_view_list_object_new ();
	lists_view_list_object_set_text (_tmp58_, _tmp57_);
	_g_free0 (_tmp57_);
	_tmp59_ = _tmp58_;
	g_list_store_append (_tmp56_, (GObject*) _tmp59_);
	_g_object_unref0 (_tmp59_);
	_tmp60_ = list_store;
	_tmp61_ = g_strdup ("Row 5");
	_tmp62_ = lists_view_list_object_new ();
	lists_view_list_object_set_text (_tmp62_, _tmp61_);
	_g_free0 (_tmp61_);
	_tmp63_ = _tmp62_;
	g_list_store_append (_tmp60_, (GObject*) _tmp63_);
	_g_object_unref0 (_tmp63_);
	_tmp64_ = list_store;
	_tmp65_ = _g_object_ref0 ((GListModel*) _tmp64_);
	_tmp66_ = gtk_single_selection_new (_tmp65_);
	list_selection = _tmp66_;
	_tmp67_ = (GtkSignalListItemFactory*) gtk_signal_list_item_factory_new ();
	list_factory = _tmp67_;
	_tmp68_ = list_factory;
	g_signal_connect_data (_tmp68_, "setup", (GCallback) __lists_view___lambda4__gtk_signal_list_item_factory_setup, block5_data_ref (_data5_), (GClosureNotify) block5_data_unref, 0);
	_tmp69_ = list_factory;
	g_signal_connect_object (_tmp69_, "bind", (GCallback) __lists_view___lambda5__gtk_signal_list_item_factory_bind, self, 0);
	_tmp70_ = list_selection;
	_tmp71_ = _g_object_ref0 ((GtkSelectionModel*) _tmp70_);
	_tmp72_ = list_factory;
	_tmp73_ = _g_object_ref0 ((GtkListItemFactory*) _tmp72_);
	_tmp74_ = (GtkListView*) gtk_list_view_new (_tmp71_, _tmp73_);
	gtk_list_view_set_show_separators (_tmp74_, TRUE);
	g_object_ref_sink (_tmp74_);
	list_view = _tmp74_;
	_tmp75_ = list_view;
	_tmp76_ = _g_object_ref0 ((GtkWidget*) _tmp75_);
	_tmp77_ = (GtkScrolledWindow*) gtk_scrolled_window_new ();
	gtk_scrolled_window_set_child (_tmp77_, _tmp76_);
	_g_object_unref0 (_tmp76_);
	gtk_scrolled_window_set_has_frame (_tmp77_, TRUE);
	g_object_set (_tmp77_, "hscrollbar-policy", GTK_POLICY_NEVER, NULL);
	gtk_scrolled_window_set_min_content_height (_tmp77_, 128);
	g_object_ref_sink (_tmp77_);
	list_scrolled = _tmp77_;
	_tmp78_ = granite_header_label_new ("Gtk.GridView");
	g_object_ref_sink (_tmp78_);
	grid_title = _tmp78_;
	_tmp79_ = g_list_store_new (LISTS_VIEW_TYPE_GRID_OBJECT);
	grid_store = _tmp79_;
	_tmp80_ = grid_store;
	_tmp81_ = g_strdup ("folder-documents");
	_tmp82_ = g_strdup ("Documents");
	_tmp83_ = lists_view_grid_object_new ();
	lists_view_grid_object_set_icon_name (_tmp83_, _tmp81_);
	_g_free0 (_tmp81_);
	lists_view_grid_object_set_text (_tmp83_, _tmp82_);
	_g_free0 (_tmp82_);
	_tmp84_ = _tmp83_;
	g_list_store_append (_tmp80_, (GObject*) _tmp84_);
	_g_object_unref0 (_tmp84_);
	_tmp85_ = grid_store;
	_tmp86_ = g_strdup ("folder-download");
	_tmp87_ = g_strdup ("Downloads");
	_tmp88_ = lists_view_grid_object_new ();
	lists_view_grid_object_set_icon_name (_tmp88_, _tmp86_);
	_g_free0 (_tmp86_);
	lists_view_grid_object_set_text (_tmp88_, _tmp87_);
	_g_free0 (_tmp87_);
	_tmp89_ = _tmp88_;
	g_list_store_append (_tmp85_, (GObject*) _tmp89_);
	_g_object_unref0 (_tmp89_);
	_tmp90_ = grid_store;
	_tmp91_ = g_strdup ("folder-music");
	_tmp92_ = g_strdup ("Music");
	_tmp93_ = lists_view_grid_object_new ();
	lists_view_grid_object_set_icon_name (_tmp93_, _tmp91_);
	_g_free0 (_tmp91_);
	lists_view_grid_object_set_text (_tmp93_, _tmp92_);
	_g_free0 (_tmp92_);
	_tmp94_ = _tmp93_;
	g_list_store_append (_tmp90_, (GObject*) _tmp94_);
	_g_object_unref0 (_tmp94_);
	_tmp95_ = grid_store;
	_tmp96_ = g_strdup ("folder-pictures");
	_tmp97_ = g_strdup ("Pictures");
	_tmp98_ = lists_view_grid_object_new ();
	lists_view_grid_object_set_icon_name (_tmp98_, _tmp96_);
	_g_free0 (_tmp96_);
	lists_view_grid_object_set_text (_tmp98_, _tmp97_);
	_g_free0 (_tmp97_);
	_tmp99_ = _tmp98_;
	g_list_store_append (_tmp95_, (GObject*) _tmp99_);
	_g_object_unref0 (_tmp99_);
	_tmp100_ = grid_store;
	_tmp101_ = g_strdup ("folder-publicshare");
	_tmp102_ = g_strdup ("Public");
	_tmp103_ = lists_view_grid_object_new ();
	lists_view_grid_object_set_icon_name (_tmp103_, _tmp101_);
	_g_free0 (_tmp101_);
	lists_view_grid_object_set_text (_tmp103_, _tmp102_);
	_g_free0 (_tmp102_);
	_tmp104_ = _tmp103_;
	g_list_store_append (_tmp100_, (GObject*) _tmp104_);
	_g_object_unref0 (_tmp104_);
	_tmp105_ = grid_store;
	_tmp106_ = g_strdup ("folder-templates");
	_tmp107_ = g_strdup ("Templates");
	_tmp108_ = lists_view_grid_object_new ();
	lists_view_grid_object_set_icon_name (_tmp108_, _tmp106_);
	_g_free0 (_tmp106_);
	lists_view_grid_object_set_text (_tmp108_, _tmp107_);
	_g_free0 (_tmp107_);
	_tmp109_ = _tmp108_;
	g_list_store_append (_tmp105_, (GObject*) _tmp109_);
	_g_object_unref0 (_tmp109_);
	_tmp110_ = grid_store;
	_tmp111_ = g_strdup ("folder-videos");
	_tmp112_ = g_strdup ("Videos");
	_tmp113_ = lists_view_grid_object_new ();
	lists_view_grid_object_set_icon_name (_tmp113_, _tmp111_);
	_g_free0 (_tmp111_);
	lists_view_grid_object_set_text (_tmp113_, _tmp112_);
	_g_free0 (_tmp112_);
	_tmp114_ = _tmp113_;
	g_list_store_append (_tmp110_, (GObject*) _tmp114_);
	_g_object_unref0 (_tmp114_);
	_tmp115_ = grid_store;
	_tmp116_ = _g_object_ref0 ((GListModel*) _tmp115_);
	_tmp117_ = gtk_multi_selection_new (_tmp116_);
	grid_selection = _tmp117_;
	_tmp118_ = (GtkSignalListItemFactory*) gtk_signal_list_item_factory_new ();
	grid_factory = _tmp118_;
	_tmp119_ = grid_factory;
	g_signal_connect_object (_tmp119_, "setup", (GCallback) __lists_view___lambda6__gtk_signal_list_item_factory_setup, self, 0);
	_tmp120_ = grid_factory;
	g_signal_connect_object (_tmp120_, "bind", (GCallback) __lists_view___lambda7__gtk_signal_list_item_factory_bind, self, 0);
	_tmp121_ = grid_selection;
	_tmp122_ = _g_object_ref0 ((GtkSelectionModel*) _tmp121_);
	_tmp123_ = grid_factory;
	_tmp124_ = _g_object_ref0 ((GtkListItemFactory*) _tmp123_);
	_tmp125_ = (GtkGridView*) gtk_grid_view_new (_tmp122_, _tmp124_);
	gtk_grid_view_set_max_columns (_tmp125_, (guint) 4);
	gtk_grid_view_set_enable_rubberband (_tmp125_, TRUE);
	g_object_ref_sink (_tmp125_);
	grid_view = _tmp125_;
	_tmp126_ = grid_view;
	_tmp127_ = _g_object_ref0 ((GtkWidget*) _tmp126_);
	_tmp128_ = (GtkScrolledWindow*) gtk_scrolled_window_new ();
	gtk_scrolled_window_set_child (_tmp128_, _tmp127_);
	_g_object_unref0 (_tmp127_);
	gtk_scrolled_window_set_has_frame (_tmp128_, TRUE);
	g_object_set (_tmp128_, "hscrollbar-policy", GTK_POLICY_NEVER, NULL);
	gtk_scrolled_window_set_min_content_height (_tmp128_, 128);
	gtk_scrolled_window_set_propagate_natural_height (_tmp128_, TRUE);
	g_object_ref_sink (_tmp128_);
	grid_scrolled = _tmp128_;
	_tmp129_ = granite_box_new (GTK_ORIENTATION_VERTICAL, GRANITE_BOX_SPACING_HALF);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp129_, 12);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp129_, 12);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp129_, 12);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp129_, 12);
	g_object_ref_sink (_tmp129_);
	vbox = _tmp129_;
	_tmp130_ = vbox;
	_tmp131_ = card_title;
	gtk_box_append ((GtkBox*) _tmp130_, (GtkWidget*) _tmp131_);
	_tmp132_ = vbox;
	_tmp133_ = list_box;
	gtk_box_append ((GtkBox*) _tmp132_, (GtkWidget*) _tmp133_);
	_tmp134_ = vbox;
	_tmp135_ = list_title;
	gtk_box_append ((GtkBox*) _tmp134_, (GtkWidget*) _tmp135_);
	_tmp136_ = vbox;
	_tmp137_ = list_scrolled;
	gtk_box_append ((GtkBox*) _tmp136_, (GtkWidget*) _tmp137_);
	_tmp138_ = vbox;
	_tmp139_ = grid_title;
	gtk_box_append ((GtkBox*) _tmp138_, (GtkWidget*) _tmp139_);
	_tmp140_ = vbox;
	_tmp141_ = grid_scrolled;
	gtk_box_append ((GtkBox*) _tmp140_, (GtkWidget*) _tmp141_);
	_tmp142_ = vbox;
	demo_page_set_child ((DemoPage*) self, (GtkWidget*) _tmp142_);
	_tmp143_ = separators_modelbutton;
	_tmp144_ = list_box;
	g_object_bind_property_with_closures ((GObject*) _tmp143_, "active", (GObject*) _tmp144_, "show-separators", G_BINDING_SYNC_CREATE | G_BINDING_DEFAULT, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_g_object_unref0 (vbox);
	_g_object_unref0 (grid_scrolled);
	_g_object_unref0 (grid_view);
	_g_object_unref0 (grid_factory);
	_g_object_unref0 (grid_selection);
	_g_object_unref0 (grid_store);
	_g_object_unref0 (grid_title);
	_g_object_unref0 (list_scrolled);
	_g_object_unref0 (list_view);
	_g_object_unref0 (list_factory);
	_g_object_unref0 (list_selection);
	_g_object_unref0 (list_store);
	_g_object_unref0 (button_section);
	_g_object_unref0 (button_menu);
	_g_object_unref0 (forward_menuitem);
	_g_object_unref0 (reply_all_menuitem);
	_g_object_unref0 (reply_menuitem);
	_g_object_unref0 (list_title);
	_g_object_unref0 (list_box);
	_g_object_unref0 (separators_modelbutton);
	_g_object_unref0 (card_title);
	block5_data_unref (_data5_);
	_data5_ = NULL;
	return obj;
}

static void
lists_view_class_init (ListsViewClass * klass,
                       gpointer klass_data)
{
	lists_view_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->constructor = lists_view_constructor;
}

static void
lists_view_instance_init (ListsView * self,
                          gpointer klass)
{
}

static GType
lists_view_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ListsViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) lists_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ListsView), 0, (GInstanceInitFunc) lists_view_instance_init, NULL };
	GType lists_view_type_id;
	lists_view_type_id = g_type_register_static (TYPE_DEMO_PAGE, "ListsView", &g_define_type_info, 0);
	return lists_view_type_id;
}

GType
lists_view_get_type (void)
{
	static volatile gsize lists_view_type_id__once = 0;
	if (g_once_init_enter (&lists_view_type_id__once)) {
		GType lists_view_type_id;
		lists_view_type_id = lists_view_get_type_once ();
		g_once_init_leave (&lists_view_type_id__once, lists_view_type_id);
	}
	return lists_view_type_id__once;
}

