/* CSSView.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from CSSView.vala, do not modify */

/*
 * Copyright 2017–2021 elementary, Inc. (https://elementary.io)
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */

#include "granite-7.h"
#include <glib-object.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include <math.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_DEMO_PAGE (demo_page_get_type ())
#define DEMO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DEMO_PAGE, DemoPage))
#define DEMO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DEMO_PAGE, DemoPageClass))
#define IS_DEMO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DEMO_PAGE))
#define IS_DEMO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DEMO_PAGE))
#define DEMO_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DEMO_PAGE, DemoPageClass))

typedef struct _DemoPage DemoPage;
typedef struct _DemoPageClass DemoPageClass;
typedef struct _DemoPagePrivate DemoPagePrivate;

#define TYPE_CSS_VIEW (css_view_get_type ())
#define CSS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CSS_VIEW, CSSView))
#define CSS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CSS_VIEW, CSSViewClass))
#define IS_CSS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CSS_VIEW))
#define IS_CSS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CSS_VIEW))
#define CSS_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CSS_VIEW, CSSViewClass))

typedef struct _CSSView CSSView;
typedef struct _CSSViewClass CSSViewClass;
typedef struct _CSSViewPrivate CSSViewPrivate;
enum  {
	CSS_VIEW_0_PROPERTY,
	CSS_VIEW_WINDOW_PROPERTY,
	CSS_VIEW_NUM_PROPERTIES
};
static GParamSpec* css_view_properties[CSS_VIEW_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

struct _DemoPage {
	GraniteToolBox parent_instance;
	DemoPagePrivate * priv;
};

struct _DemoPageClass {
	GraniteToolBoxClass parent_class;
};

struct _CSSView {
	DemoPage parent_instance;
	CSSViewPrivate * priv;
};

struct _CSSViewClass {
	DemoPageClass parent_class;
};

struct _CSSViewPrivate {
	GtkWindow* _window;
};

static gint CSSView_private_offset;
static gpointer css_view_parent_class = NULL;

VALA_EXTERN GType demo_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DemoPage, g_object_unref)
VALA_EXTERN GType css_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CSSView, g_object_unref)
VALA_EXTERN GtkWindow* css_view_get_window (CSSView* self);
static void css_view_set_window (CSSView* self,
                          GtkWindow* value);
VALA_EXTERN CSSView* css_view_new (GtkWindow* window);
VALA_EXTERN CSSView* css_view_construct (GType object_type,
                             GtkWindow* window);
static GObject * css_view_constructor (GType type,
                                guint n_construct_properties,
                                GObjectConstructParam * construct_properties);
VALA_EXTERN void demo_page_set_child (DemoPage* self,
                          GtkWidget* value);
static void css_view_finalize (GObject * obj);
static GType css_view_get_type_once (void);
static void _vala_css_view_get_property (GObject * object,
                                  guint property_id,
                                  GValue * value,
                                  GParamSpec * pspec);
static void _vala_css_view_set_property (GObject * object,
                                  guint property_id,
                                  const GValue * value,
                                  GParamSpec * pspec);

static inline gpointer
css_view_get_instance_private (CSSView* self)
{
	return G_STRUCT_MEMBER_P (self, CSSView_private_offset);
}

GtkWindow*
css_view_get_window (CSSView* self)
{
	GtkWindow* result;
	GtkWindow* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_window;
	result = _tmp0_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
css_view_set_window (CSSView* self,
                     GtkWindow* value)
{
	GtkWindow* old_value;
	g_return_if_fail (self != NULL);
	old_value = css_view_get_window (self);
	if (old_value != value) {
		GtkWindow* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_window);
		self->priv->_window = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, css_view_properties[CSS_VIEW_WINDOW_PROPERTY]);
	}
}

CSSView*
css_view_construct (GType object_type,
                    GtkWindow* window)
{
	CSSView * self = NULL;
	g_return_val_if_fail (window != NULL, NULL);
	self = (CSSView*) g_object_new (object_type, "window", window, NULL);
	return self;
}

CSSView*
css_view_new (GtkWindow* window)
{
	return css_view_construct (TYPE_CSS_VIEW, window);
}

static GObject *
css_view_constructor (GType type,
                      guint n_construct_properties,
                      GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	CSSView * self;
	GraniteHeaderLabel* header1 = NULL;
	gchar* _tmp0_;
	GraniteHeaderLabel* _tmp1_ = NULL;
	GraniteHeaderLabel* header2 = NULL;
	gchar* _tmp2_;
	GraniteHeaderLabel* _tmp3_ = NULL;
	GraniteHeaderLabel* header3 = NULL;
	gchar* _tmp4_;
	GraniteHeaderLabel* _tmp5_ = NULL;
	GraniteHeaderLabel* header4 = NULL;
	gchar* _tmp6_;
	GraniteHeaderLabel* _tmp7_ = NULL;
	GtkLabel* numeric = NULL;
	GtkLabel* _tmp8_ = NULL;
	GtkLabel* _tmp9_;
	GtkLabel* small = NULL;
	GtkLabel* _tmp10_ = NULL;
	GtkLabel* _tmp11_;
	GtkLabel* mono = NULL;
	GtkLabel* _tmp12_ = NULL;
	GtkLabel* _tmp13_;
	GraniteHeaderLabel* card_header = NULL;
	gchar* _tmp14_;
	GraniteHeaderLabel* _tmp15_ = NULL;
	GtkBox* card = NULL;
	GtkBox* _tmp16_ = NULL;
	GtkBox* _tmp17_;
	GtkBox* _tmp18_;
	GraniteHeaderLabel* _tmp19_;
	GtkBox* _tmp20_;
	GraniteHeaderLabel* _tmp21_;
	GtkBox* _tmp22_;
	GraniteHeaderLabel* _tmp23_;
	GtkBox* _tmp24_;
	GraniteHeaderLabel* _tmp25_;
	GtkBox* _tmp26_;
	GtkLabel* _tmp27_;
	GtkBox* _tmp28_;
	GtkLabel* _tmp29_;
	GtkBox* _tmp30_;
	GtkLabel* _tmp31_;
	GraniteBin* card_checkered = NULL;
	GtkImage* _tmp32_ = NULL;
	GraniteBin* _tmp33_ = NULL;
	GraniteBin* _tmp34_;
	GraniteBin* _tmp35_;
	GtkBox* card_box = NULL;
	GtkBox* _tmp36_;
	GtkBox* _tmp37_;
	GtkBox* _tmp38_;
	GtkBox* _tmp39_;
	GraniteBin* _tmp40_;
	GraniteHeaderLabel* terminal_label = NULL;
	GraniteHeaderLabel* _tmp41_;
	GtkLabel* terminal = NULL;
	GtkLabel* _tmp42_ = NULL;
	GtkScrolledWindow* terminal_scroll = NULL;
	GtkLabel* _tmp43_;
	GtkWidget* _tmp44_;
	GtkScrolledWindow* _tmp45_ = NULL;
	GtkScrolledWindow* _tmp46_;
	GraniteHeaderLabel* accent_color_label = NULL;
	GraniteHeaderLabel* _tmp47_;
	GtkBox* accent_color_box = NULL;
	GtkBox* _tmp48_;
	GtkBox* _tmp49_;
	GtkImage* _tmp50_;
	GtkImage* _tmp51_;
	GtkBox* _tmp52_;
	GtkImage* _tmp53_;
	GtkImage* _tmp54_;
	GtkBox* _tmp55_;
	GtkLabel* _tmp56_;
	GtkLabel* _tmp57_;
	GtkBox* _tmp58_;
	GtkBox* success_color_box = NULL;
	GtkBox* _tmp59_;
	GtkBox* _tmp60_;
	GtkImage* _tmp61_;
	GtkImage* _tmp62_;
	GtkBox* _tmp63_;
	GtkImage* _tmp64_;
	GtkImage* _tmp65_;
	GtkBox* _tmp66_;
	GtkLabel* _tmp67_;
	GtkLabel* _tmp68_;
	GtkBox* _tmp69_;
	GtkBox* warning_color_box = NULL;
	GtkBox* _tmp70_;
	GtkBox* _tmp71_;
	GtkImage* _tmp72_;
	GtkImage* _tmp73_;
	GtkBox* _tmp74_;
	GtkImage* _tmp75_;
	GtkImage* _tmp76_;
	GtkBox* _tmp77_;
	GtkLabel* _tmp78_;
	GtkLabel* _tmp79_;
	GtkBox* _tmp80_;
	GtkBox* error_color_box = NULL;
	GtkBox* _tmp81_;
	GtkBox* _tmp82_;
	GtkImage* _tmp83_;
	GtkImage* _tmp84_;
	GtkBox* _tmp85_;
	GtkImage* _tmp86_;
	GtkImage* _tmp87_;
	GtkBox* _tmp88_;
	GtkLabel* _tmp89_;
	GtkLabel* _tmp90_;
	GtkBox* _tmp91_;
	GtkBox* dimmed_box = NULL;
	GtkBox* _tmp92_;
	GtkBox* _tmp93_;
	GtkImage* _tmp94_;
	GtkImage* _tmp95_;
	GtkBox* _tmp96_;
	GtkImage* _tmp97_;
	GtkImage* _tmp98_;
	GtkBox* _tmp99_;
	GtkLabel* _tmp100_;
	GtkLabel* _tmp101_;
	GtkBox* _tmp102_;
	GtkBox* box = NULL;
	GtkBox* _tmp103_ = NULL;
	GtkBox* _tmp104_;
	GraniteHeaderLabel* _tmp105_;
	GtkBox* _tmp106_;
	GtkBox* _tmp107_;
	GtkBox* _tmp108_;
	GraniteHeaderLabel* _tmp109_;
	GtkBox* _tmp110_;
	GtkScrolledWindow* _tmp111_;
	GtkBox* _tmp112_;
	GraniteHeaderLabel* _tmp113_;
	GtkBox* _tmp114_;
	GtkBox* _tmp115_;
	GtkBox* _tmp116_;
	GtkBox* _tmp117_;
	GtkBox* _tmp118_;
	GtkBox* _tmp119_;
	GtkBox* _tmp120_;
	GtkBox* _tmp121_;
	GtkBox* _tmp122_;
	GtkBox* _tmp123_;
	GtkBox* _tmp124_;
	parent_class = G_OBJECT_CLASS (css_view_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_CSS_VIEW, CSSView);
	_tmp0_ = g_strdup ("secondary text");
	_tmp1_ = granite_header_label_new ("H1 HeaderLabel");
	gtk_widget_set_margin_end ((GtkWidget*) _tmp1_, 12);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp1_, 12);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp1_, 12);
	granite_header_label_set_size (_tmp1_, GRANITE_HEADER_LABEL_SIZE_H1);
	granite_header_label_set_secondary_text (_tmp1_, _tmp0_);
	_g_free0 (_tmp0_);
	g_object_ref_sink (_tmp1_);
	header1 = _tmp1_;
	_tmp2_ = g_strdup ("secondary text");
	_tmp3_ = granite_header_label_new ("H2 HeaderLabel");
	gtk_widget_set_margin_end ((GtkWidget*) _tmp3_, 12);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp3_, 12);
	granite_header_label_set_size (_tmp3_, GRANITE_HEADER_LABEL_SIZE_H2);
	granite_header_label_set_secondary_text (_tmp3_, _tmp2_);
	_g_free0 (_tmp2_);
	g_object_ref_sink (_tmp3_);
	header2 = _tmp3_;
	_tmp4_ = g_strdup ("secondary text");
	_tmp5_ = granite_header_label_new ("H3 HeaderLabel");
	gtk_widget_set_margin_end ((GtkWidget*) _tmp5_, 12);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp5_, 12);
	granite_header_label_set_size (_tmp5_, GRANITE_HEADER_LABEL_SIZE_H3);
	granite_header_label_set_secondary_text (_tmp5_, _tmp4_);
	_g_free0 (_tmp4_);
	g_object_ref_sink (_tmp5_);
	header3 = _tmp5_;
	_tmp6_ = g_strdup ("secondary text");
	_tmp7_ = granite_header_label_new ("H4 HeaderLabel");
	gtk_widget_set_margin_end ((GtkWidget*) _tmp7_, 12);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp7_, 12);
	granite_header_label_set_secondary_text (_tmp7_, _tmp6_);
	_g_free0 (_tmp6_);
	g_object_ref_sink (_tmp7_);
	header4 = _tmp7_;
	_tmp8_ = (GtkLabel*) gtk_label_new ("\"Granite.CssClass.NUMERIC\" 123.4");
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp8_, 12);
	g_object_ref_sink (_tmp8_);
	numeric = _tmp8_;
	_tmp9_ = numeric;
	gtk_widget_add_css_class ((GtkWidget*) _tmp9_, GRANITE_CSS_CLASS_NUMERIC);
	_tmp10_ = (GtkLabel*) gtk_label_new ("\"Granite.CssClass.SMALL\"");
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp10_, 12);
	g_object_ref_sink (_tmp10_);
	small = _tmp10_;
	_tmp11_ = small;
	gtk_widget_add_css_class ((GtkWidget*) _tmp11_, GRANITE_CSS_CLASS_SMALL);
	_tmp12_ = (GtkLabel*) gtk_label_new ("\"Granite.CssClass.MONOSPACE\"");
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp12_, 12);
	g_object_ref_sink (_tmp12_);
	mono = _tmp12_;
	_tmp13_ = mono;
	gtk_widget_add_css_class ((GtkWidget*) _tmp13_, GRANITE_CSS_CLASS_MONOSPACE);
	_tmp14_ = g_strdup ("\"Granite.CssClass.CARD\" and \"Granite.CssClass.CHECKERBOARD\"");
	_tmp15_ = granite_header_label_new ("Cards and Headers");
	granite_header_label_set_secondary_text (_tmp15_, _tmp14_);
	_g_free0 (_tmp14_);
	g_object_ref_sink (_tmp15_);
	card_header = _tmp15_;
	_tmp16_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp16_, TRUE);
	g_object_ref_sink (_tmp16_);
	card = _tmp16_;
	_tmp17_ = card;
	gtk_widget_add_css_class ((GtkWidget*) _tmp17_, GRANITE_CSS_CLASS_CARD);
	_tmp18_ = card;
	_tmp19_ = header1;
	gtk_box_append (_tmp18_, (GtkWidget*) _tmp19_);
	_tmp20_ = card;
	_tmp21_ = header2;
	gtk_box_append (_tmp20_, (GtkWidget*) _tmp21_);
	_tmp22_ = card;
	_tmp23_ = header3;
	gtk_box_append (_tmp22_, (GtkWidget*) _tmp23_);
	_tmp24_ = card;
	_tmp25_ = header4;
	gtk_box_append (_tmp24_, (GtkWidget*) _tmp25_);
	_tmp26_ = card;
	_tmp27_ = numeric;
	gtk_box_append (_tmp26_, (GtkWidget*) _tmp27_);
	_tmp28_ = card;
	_tmp29_ = small;
	gtk_box_append (_tmp28_, (GtkWidget*) _tmp29_);
	_tmp30_ = card;
	_tmp31_ = mono;
	gtk_box_append (_tmp30_, (GtkWidget*) _tmp31_);
	_tmp32_ = (GtkImage*) gtk_image_new_from_icon_name ("battery-low");
	gtk_widget_set_halign ((GtkWidget*) _tmp32_, GTK_ALIGN_CENTER);
	gtk_image_set_icon_size (_tmp32_, GTK_ICON_SIZE_LARGE);
	g_object_ref_sink (_tmp32_);
	_tmp33_ = granite_bin_new ();
	granite_bin_set_child (_tmp33_, (GtkWidget*) _tmp32_);
	_g_object_unref0 (_tmp32_);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp33_, TRUE);
	g_object_ref_sink (_tmp33_);
	card_checkered = _tmp33_;
	_tmp34_ = card_checkered;
	gtk_widget_add_css_class ((GtkWidget*) _tmp34_, GRANITE_CSS_CLASS_CARD);
	_tmp35_ = card_checkered;
	gtk_widget_add_css_class ((GtkWidget*) _tmp35_, GRANITE_CSS_CLASS_CHECKERBOARD);
	_tmp36_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 24);
	g_object_ref_sink (_tmp36_);
	card_box = _tmp36_;
	_tmp37_ = card_box;
	_tmp38_ = card;
	gtk_box_append (_tmp37_, (GtkWidget*) _tmp38_);
	_tmp39_ = card_box;
	_tmp40_ = card_checkered;
	gtk_box_append (_tmp39_, (GtkWidget*) _tmp40_);
	_tmp41_ = granite_header_label_new ("\"terminal\" style class");
	g_object_ref_sink (_tmp41_);
	terminal_label = _tmp41_;
	_tmp42_ = (GtkLabel*) gtk_label_new ("[ 73%] Linking C executable granite-demo\n" \
"[100%] Built target granite-demo");
	gtk_label_set_selectable (_tmp42_, TRUE);
	gtk_label_set_wrap (_tmp42_, TRUE);
	gtk_label_set_xalign (_tmp42_, (gfloat) 0);
	gtk_label_set_yalign (_tmp42_, (gfloat) 0);
	g_object_ref_sink (_tmp42_);
	terminal = _tmp42_;
	_tmp43_ = terminal;
	_tmp44_ = _g_object_ref0 ((GtkWidget*) _tmp43_);
	_tmp45_ = (GtkScrolledWindow*) gtk_scrolled_window_new ();
	gtk_scrolled_window_set_min_content_height (_tmp45_, 70);
	gtk_scrolled_window_set_child (_tmp45_, _tmp44_);
	_g_object_unref0 (_tmp44_);
	g_object_ref_sink (_tmp45_);
	terminal_scroll = _tmp45_;
	_tmp46_ = terminal_scroll;
	gtk_widget_add_css_class ((GtkWidget*) _tmp46_, GRANITE_STYLE_CLASS_TERMINAL);
	_tmp47_ = granite_header_label_new ("Colored labels and icons");
	g_object_ref_sink (_tmp47_);
	accent_color_label = _tmp47_;
	_tmp48_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
	g_object_ref_sink (_tmp48_);
	accent_color_box = _tmp48_;
	_tmp49_ = accent_color_box;
	_tmp50_ = (GtkImage*) gtk_image_new_from_icon_name ("emoji-body-symbolic");
	g_object_ref_sink (_tmp50_);
	_tmp51_ = _tmp50_;
	gtk_box_append (_tmp49_, (GtkWidget*) _tmp51_);
	_g_object_unref0 (_tmp51_);
	_tmp52_ = accent_color_box;
	_tmp53_ = (GtkImage*) gtk_image_new_from_icon_name ("face-tired-symbolic");
	g_object_ref_sink (_tmp53_);
	_tmp54_ = _tmp53_;
	gtk_box_append (_tmp52_, (GtkWidget*) _tmp54_);
	_g_object_unref0 (_tmp54_);
	_tmp55_ = accent_color_box;
	_tmp56_ = (GtkLabel*) gtk_label_new ("Granite.CssClass.ACCENT");
	g_object_ref_sink (_tmp56_);
	_tmp57_ = _tmp56_;
	gtk_box_append (_tmp55_, (GtkWidget*) _tmp57_);
	_g_object_unref0 (_tmp57_);
	_tmp58_ = accent_color_box;
	gtk_widget_add_css_class ((GtkWidget*) _tmp58_, GRANITE_CSS_CLASS_ACCENT);
	_tmp59_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
	g_object_ref_sink (_tmp59_);
	success_color_box = _tmp59_;
	_tmp60_ = success_color_box;
	_tmp61_ = (GtkImage*) gtk_image_new_from_icon_name ("process-completed-symbolic");
	g_object_ref_sink (_tmp61_);
	_tmp62_ = _tmp61_;
	gtk_box_append (_tmp60_, (GtkWidget*) _tmp62_);
	_g_object_unref0 (_tmp62_);
	_tmp63_ = success_color_box;
	_tmp64_ = (GtkImage*) gtk_image_new_from_icon_name ("face-sick-symbolic");
	g_object_ref_sink (_tmp64_);
	_tmp65_ = _tmp64_;
	gtk_box_append (_tmp63_, (GtkWidget*) _tmp65_);
	_g_object_unref0 (_tmp65_);
	_tmp66_ = success_color_box;
	_tmp67_ = (GtkLabel*) gtk_label_new ("Granite.CssClass.SUCCESS");
	g_object_ref_sink (_tmp67_);
	_tmp68_ = _tmp67_;
	gtk_box_append (_tmp66_, (GtkWidget*) _tmp68_);
	_g_object_unref0 (_tmp68_);
	_tmp69_ = success_color_box;
	gtk_widget_add_css_class ((GtkWidget*) _tmp69_, GRANITE_CSS_CLASS_SUCCESS);
	_tmp70_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
	g_object_ref_sink (_tmp70_);
	warning_color_box = _tmp70_;
	_tmp71_ = warning_color_box;
	_tmp72_ = (GtkImage*) gtk_image_new_from_icon_name ("dialog-warning-symbolic");
	g_object_ref_sink (_tmp72_);
	_tmp73_ = _tmp72_;
	gtk_box_append (_tmp71_, (GtkWidget*) _tmp73_);
	_g_object_unref0 (_tmp73_);
	_tmp74_ = warning_color_box;
	_tmp75_ = (GtkImage*) gtk_image_new_from_icon_name ("face-laugh-symbolic");
	g_object_ref_sink (_tmp75_);
	_tmp76_ = _tmp75_;
	gtk_box_append (_tmp74_, (GtkWidget*) _tmp76_);
	_g_object_unref0 (_tmp76_);
	_tmp77_ = warning_color_box;
	_tmp78_ = (GtkLabel*) gtk_label_new ("Granite.CssClass.WARNING");
	g_object_ref_sink (_tmp78_);
	_tmp79_ = _tmp78_;
	gtk_box_append (_tmp77_, (GtkWidget*) _tmp79_);
	_g_object_unref0 (_tmp79_);
	_tmp80_ = warning_color_box;
	gtk_widget_add_css_class ((GtkWidget*) _tmp80_, GRANITE_CSS_CLASS_WARNING);
	_tmp81_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
	g_object_ref_sink (_tmp81_);
	error_color_box = _tmp81_;
	_tmp82_ = error_color_box;
	_tmp83_ = (GtkImage*) gtk_image_new_from_icon_name ("dialog-error-symbolic");
	g_object_ref_sink (_tmp83_);
	_tmp84_ = _tmp83_;
	gtk_box_append (_tmp82_, (GtkWidget*) _tmp84_);
	_g_object_unref0 (_tmp84_);
	_tmp85_ = error_color_box;
	_tmp86_ = (GtkImage*) gtk_image_new_from_icon_name ("face-angry-symbolic");
	g_object_ref_sink (_tmp86_);
	_tmp87_ = _tmp86_;
	gtk_box_append (_tmp85_, (GtkWidget*) _tmp87_);
	_g_object_unref0 (_tmp87_);
	_tmp88_ = error_color_box;
	_tmp89_ = (GtkLabel*) gtk_label_new ("Granite.CssClass.ERROR");
	g_object_ref_sink (_tmp89_);
	_tmp90_ = _tmp89_;
	gtk_box_append (_tmp88_, (GtkWidget*) _tmp90_);
	_g_object_unref0 (_tmp90_);
	_tmp91_ = error_color_box;
	gtk_widget_add_css_class ((GtkWidget*) _tmp91_, GRANITE_CSS_CLASS_ERROR);
	_tmp92_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
	g_object_ref_sink (_tmp92_);
	dimmed_box = _tmp92_;
	_tmp93_ = dimmed_box;
	_tmp94_ = (GtkImage*) gtk_image_new_from_icon_name ("adw-tab-icon-missing-symbolic");
	g_object_ref_sink (_tmp94_);
	_tmp95_ = _tmp94_;
	gtk_box_append (_tmp93_, (GtkWidget*) _tmp95_);
	_g_object_unref0 (_tmp95_);
	_tmp96_ = dimmed_box;
	_tmp97_ = (GtkImage*) gtk_image_new_from_icon_name ("face-plain-symbolic");
	g_object_ref_sink (_tmp97_);
	_tmp98_ = _tmp97_;
	gtk_box_append (_tmp96_, (GtkWidget*) _tmp98_);
	_g_object_unref0 (_tmp98_);
	_tmp99_ = dimmed_box;
	_tmp100_ = (GtkLabel*) gtk_label_new ("Granite.CssClass.DIM");
	g_object_ref_sink (_tmp100_);
	_tmp101_ = _tmp100_;
	gtk_box_append (_tmp99_, (GtkWidget*) _tmp101_);
	_g_object_unref0 (_tmp101_);
	_tmp102_ = dimmed_box;
	gtk_widget_add_css_class ((GtkWidget*) _tmp102_, GRANITE_CSS_CLASS_DIM);
	_tmp103_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp103_, 24);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp103_, 24);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp103_, 24);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp103_, 24);
	g_object_ref_sink (_tmp103_);
	box = _tmp103_;
	_tmp104_ = box;
	_tmp105_ = card_header;
	gtk_box_append (_tmp104_, (GtkWidget*) _tmp105_);
	_tmp106_ = box;
	_tmp107_ = card_box;
	gtk_box_append (_tmp106_, (GtkWidget*) _tmp107_);
	_tmp108_ = box;
	_tmp109_ = terminal_label;
	gtk_box_append (_tmp108_, (GtkWidget*) _tmp109_);
	_tmp110_ = box;
	_tmp111_ = terminal_scroll;
	gtk_box_append (_tmp110_, (GtkWidget*) _tmp111_);
	_tmp112_ = box;
	_tmp113_ = accent_color_label;
	gtk_box_append (_tmp112_, (GtkWidget*) _tmp113_);
	_tmp114_ = box;
	_tmp115_ = accent_color_box;
	gtk_box_append (_tmp114_, (GtkWidget*) _tmp115_);
	_tmp116_ = box;
	_tmp117_ = success_color_box;
	gtk_box_append (_tmp116_, (GtkWidget*) _tmp117_);
	_tmp118_ = box;
	_tmp119_ = warning_color_box;
	gtk_box_append (_tmp118_, (GtkWidget*) _tmp119_);
	_tmp120_ = box;
	_tmp121_ = error_color_box;
	gtk_box_append (_tmp120_, (GtkWidget*) _tmp121_);
	_tmp122_ = box;
	_tmp123_ = dimmed_box;
	gtk_box_append (_tmp122_, (GtkWidget*) _tmp123_);
	_tmp124_ = box;
	demo_page_set_child ((DemoPage*) self, (GtkWidget*) _tmp124_);
	_g_object_unref0 (box);
	_g_object_unref0 (dimmed_box);
	_g_object_unref0 (error_color_box);
	_g_object_unref0 (warning_color_box);
	_g_object_unref0 (success_color_box);
	_g_object_unref0 (accent_color_box);
	_g_object_unref0 (accent_color_label);
	_g_object_unref0 (terminal_scroll);
	_g_object_unref0 (terminal);
	_g_object_unref0 (terminal_label);
	_g_object_unref0 (card_box);
	_g_object_unref0 (card_checkered);
	_g_object_unref0 (card);
	_g_object_unref0 (card_header);
	_g_object_unref0 (mono);
	_g_object_unref0 (small);
	_g_object_unref0 (numeric);
	_g_object_unref0 (header4);
	_g_object_unref0 (header3);
	_g_object_unref0 (header2);
	_g_object_unref0 (header1);
	return obj;
}

static void
css_view_class_init (CSSViewClass * klass,
                     gpointer klass_data)
{
	css_view_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &CSSView_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_css_view_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_css_view_set_property;
	G_OBJECT_CLASS (klass)->constructor = css_view_constructor;
	G_OBJECT_CLASS (klass)->finalize = css_view_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), CSS_VIEW_WINDOW_PROPERTY, css_view_properties[CSS_VIEW_WINDOW_PROPERTY] = g_param_spec_object ("window", "window", "window", gtk_window_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
}

static void
css_view_instance_init (CSSView * self,
                        gpointer klass)
{
	self->priv = css_view_get_instance_private (self);
}

static void
css_view_finalize (GObject * obj)
{
	CSSView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_CSS_VIEW, CSSView);
	_g_object_unref0 (self->priv->_window);
	G_OBJECT_CLASS (css_view_parent_class)->finalize (obj);
}

static GType
css_view_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (CSSViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) css_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (CSSView), 0, (GInstanceInitFunc) css_view_instance_init, NULL };
	GType css_view_type_id;
	css_view_type_id = g_type_register_static (TYPE_DEMO_PAGE, "CSSView", &g_define_type_info, 0);
	CSSView_private_offset = g_type_add_instance_private (css_view_type_id, sizeof (CSSViewPrivate));
	return css_view_type_id;
}

GType
css_view_get_type (void)
{
	static volatile gsize css_view_type_id__once = 0;
	if (g_once_init_enter (&css_view_type_id__once)) {
		GType css_view_type_id;
		css_view_type_id = css_view_get_type_once ();
		g_once_init_leave (&css_view_type_id__once, css_view_type_id);
	}
	return css_view_type_id__once;
}

static void
_vala_css_view_get_property (GObject * object,
                             guint property_id,
                             GValue * value,
                             GParamSpec * pspec)
{
	CSSView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_CSS_VIEW, CSSView);
	switch (property_id) {
		case CSS_VIEW_WINDOW_PROPERTY:
		g_value_set_object (value, css_view_get_window (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_css_view_set_property (GObject * object,
                             guint property_id,
                             const GValue * value,
                             GParamSpec * pspec)
{
	CSSView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_CSS_VIEW, CSSView);
	switch (property_id) {
		case CSS_VIEW_WINDOW_PROPERTY:
		css_view_set_window (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

