/* WelcomeView.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from WelcomeView.vala, do not modify */

/*
 * Copyright 2017-2021 elementary, Inc. (https://elementary.io)
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */

#include "granite-7.h"
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gio/gio.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_DEMO_PAGE (demo_page_get_type ())
#define DEMO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DEMO_PAGE, DemoPage))
#define DEMO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DEMO_PAGE, DemoPageClass))
#define IS_DEMO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DEMO_PAGE))
#define IS_DEMO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DEMO_PAGE))
#define DEMO_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DEMO_PAGE, DemoPageClass))

typedef struct _DemoPage DemoPage;
typedef struct _DemoPageClass DemoPageClass;
typedef struct _DemoPagePrivate DemoPagePrivate;

#define TYPE_WELCOME_VIEW (welcome_view_get_type ())
#define WELCOME_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_WELCOME_VIEW, WelcomeView))
#define WELCOME_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_WELCOME_VIEW, WelcomeViewClass))
#define IS_WELCOME_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_WELCOME_VIEW))
#define IS_WELCOME_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_WELCOME_VIEW))
#define WELCOME_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_WELCOME_VIEW, WelcomeViewClass))

typedef struct _WelcomeView WelcomeView;
typedef struct _WelcomeViewClass WelcomeViewClass;
typedef struct _WelcomeViewPrivate WelcomeViewPrivate;
enum  {
	WELCOME_VIEW_0_PROPERTY,
	WELCOME_VIEW_NUM_PROPERTIES
};
static GParamSpec* welcome_view_properties[WELCOME_VIEW_NUM_PROPERTIES];
typedef struct _Block10Data Block10Data;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

struct _DemoPage {
	GraniteToolBox parent_instance;
	DemoPagePrivate * priv;
};

struct _DemoPageClass {
	GraniteToolBoxClass parent_class;
};

struct _WelcomeView {
	DemoPage parent_instance;
	WelcomeViewPrivate * priv;
};

struct _WelcomeViewClass {
	DemoPageClass parent_class;
};

struct _Block10Data {
	int _ref_count_;
	WelcomeView* self;
	GtkButton* alert_action;
};

static gpointer welcome_view_parent_class = NULL;

VALA_EXTERN GType demo_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DemoPage, g_object_unref)
VALA_EXTERN GType welcome_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WelcomeView, g_object_unref)
VALA_EXTERN WelcomeView* welcome_view_new (void);
VALA_EXTERN WelcomeView* welcome_view_construct (GType object_type);
VALA_EXTERN DemoPage* demo_page_new (void);
VALA_EXTERN DemoPage* demo_page_construct (GType object_type);
static GObject * welcome_view_constructor (GType type,
                                    guint n_construct_properties,
                                    GObjectConstructParam * construct_properties);
static Block10Data* block10_data_ref (Block10Data* _data10_);
static void block10_data_unref (void * _userdata_);
VALA_EXTERN void demo_page_set_child (DemoPage* self,
                          GtkWidget* value);
static void _welcome_view___lambda15_ (WelcomeView* self);
static void __welcome_view___lambda15__gtk_button_clicked (GtkButton* _sender,
                                                    gpointer self);
static void _welcome_view___lambda16_ (WelcomeView* self);
static void __welcome_view___lambda16__gtk_button_clicked (GtkButton* _sender,
                                                    gpointer self);
static void _welcome_view___lambda17_ (Block10Data* _data10_);
static void __welcome_view___lambda17__gtk_button_clicked (GtkButton* _sender,
                                                    gpointer self);
static GType welcome_view_get_type_once (void);

WelcomeView*
welcome_view_construct (GType object_type)
{
	WelcomeView * self = NULL;
	self = (WelcomeView*) demo_page_construct (object_type);
	return self;
}

WelcomeView*
welcome_view_new (void)
{
	return welcome_view_construct (TYPE_WELCOME_VIEW);
}

static Block10Data*
block10_data_ref (Block10Data* _data10_)
{
	g_atomic_int_inc (&_data10_->_ref_count_);
	return _data10_;
}

static void
block10_data_unref (void * _userdata_)
{
	Block10Data* _data10_;
	_data10_ = (Block10Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data10_->_ref_count_)) {
		WelcomeView* self;
		self = _data10_->self;
		_g_object_unref0 (_data10_->alert_action);
		_g_object_unref0 (self);
		g_slice_free (Block10Data, _data10_);
	}
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
_welcome_view___lambda15_ (WelcomeView* self)
{
	GtkUriLauncher* uri_launcher = NULL;
	GtkUriLauncher* _tmp0_;
	GtkUriLauncher* _tmp1_;
	GtkRoot* _tmp2_;
	_tmp0_ = gtk_uri_launcher_new ("https://valadoc.org/granite/Granite.html");
	uri_launcher = _tmp0_;
	_tmp1_ = uri_launcher;
	_tmp2_ = gtk_widget_get_root ((GtkWidget*) self);
	gtk_uri_launcher_launch (_tmp1_, G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_window_get_type (), GtkWindow), NULL, NULL, NULL);
	_g_object_unref0 (uri_launcher);
}

static void
__welcome_view___lambda15__gtk_button_clicked (GtkButton* _sender,
                                               gpointer self)
{
	_welcome_view___lambda15_ ((WelcomeView*) self);
}

static void
_welcome_view___lambda16_ (WelcomeView* self)
{
	GtkUriLauncher* uri_launcher = NULL;
	GtkUriLauncher* _tmp0_;
	GtkUriLauncher* _tmp1_;
	GtkRoot* _tmp2_;
	_tmp0_ = gtk_uri_launcher_new ("https://github.com/elementary/granite");
	uri_launcher = _tmp0_;
	_tmp1_ = uri_launcher;
	_tmp2_ = gtk_widget_get_root ((GtkWidget*) self);
	gtk_uri_launcher_launch (_tmp1_, G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_window_get_type (), GtkWindow), NULL, NULL, NULL);
	_g_object_unref0 (uri_launcher);
}

static void
__welcome_view___lambda16__gtk_button_clicked (GtkButton* _sender,
                                               gpointer self)
{
	_welcome_view___lambda16_ ((WelcomeView*) self);
}

static void
_welcome_view___lambda17_ (Block10Data* _data10_)
{
	WelcomeView* self;
	GtkButton* _tmp0_;
	self = _data10_->self;
	_tmp0_ = _data10_->alert_action;
	gtk_widget_hide ((GtkWidget*) _tmp0_);
}

static void
__welcome_view___lambda17__gtk_button_clicked (GtkButton* _sender,
                                               gpointer self)
{
	_welcome_view___lambda17_ (self);
}

static GObject *
welcome_view_constructor (GType type,
                          guint n_construct_properties,
                          GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	WelcomeView * self;
	Block10Data* _data10_;
	GranitePlaceholder* welcome = NULL;
	gchar* _tmp0_;
	GranitePlaceholder* _tmp1_ = NULL;
	GtkButton* vala_button = NULL;
	GranitePlaceholder* _tmp2_;
	GThemedIcon* _tmp3_;
	GThemedIcon* _tmp4_;
	GtkButton* _tmp5_;
	GtkButton* _tmp6_;
	GtkButton* source_button = NULL;
	GranitePlaceholder* _tmp7_;
	GThemedIcon* _tmp8_;
	GThemedIcon* _tmp9_;
	GtkButton* _tmp10_;
	GtkButton* _tmp11_;
	GranitePlaceholder* alert = NULL;
	gchar* _tmp12_;
	GThemedIcon* _tmp13_;
	GranitePlaceholder* _tmp14_ = NULL;
	GranitePlaceholder* _tmp15_;
	GranitePlaceholder* _tmp16_;
	GThemedIcon* _tmp17_;
	GThemedIcon* _tmp18_;
	GtkButton* _tmp19_;
	GtkButton* _tmp20_;
	GranitePlaceholder* search_placeholder = NULL;
	gchar* _tmp21_;
	GThemedIcon* _tmp22_;
	GranitePlaceholder* _tmp23_ = NULL;
	GtkListBox* listbox = NULL;
	GtkListBox* _tmp24_ = NULL;
	GtkListBox* _tmp25_;
	GranitePlaceholder* _tmp26_;
	GtkListBox* _tmp27_;
	GtkSearchEntry* search_entry = NULL;
	GtkSearchEntry* _tmp28_ = NULL;
	GranitePlaceholder* popover_placeholder = NULL;
	gchar* _tmp29_;
	GThemedIcon* _tmp30_;
	GranitePlaceholder* _tmp31_ = NULL;
	GtkListBox* popover_list = NULL;
	GtkListBox* _tmp32_;
	GtkListBox* _tmp33_;
	GranitePlaceholder* _tmp34_;
	GtkBox* box = NULL;
	GtkBox* _tmp35_;
	GtkBox* _tmp36_;
	GtkSearchEntry* _tmp37_;
	GtkBox* _tmp38_;
	GtkListBox* _tmp39_;
	GtkPopover* popover = NULL;
	GtkBox* _tmp40_;
	GtkWidget* _tmp41_;
	GtkPopover* _tmp42_ = NULL;
	GtkMenuButton* menubutton = NULL;
	gchar* _tmp43_;
	GtkPopover* _tmp44_;
	GtkPopover* _tmp45_;
	GtkMenuButton* _tmp46_ = NULL;
	GtkStack* stack = NULL;
	GtkStack* _tmp47_ = NULL;
	GtkStack* _tmp48_;
	GranitePlaceholder* _tmp49_;
	GtkStack* _tmp50_;
	GranitePlaceholder* _tmp51_;
	GtkStack* _tmp52_;
	GtkListBox* _tmp53_;
	GtkStack* _tmp54_;
	GtkMenuButton* _tmp55_;
	GtkStackSwitcher* stack_switcher = NULL;
	GtkStack* _tmp56_;
	GtkStack* _tmp57_;
	GtkStackSwitcher* _tmp58_ = NULL;
	GtkStackSwitcher* _tmp59_;
	GtkLayoutManager* _tmp60_;
	GtkLayoutManager* _tmp61_;
	GtkStack* _tmp62_;
	GtkStackSwitcher* _tmp63_;
	GtkButton* _tmp64_;
	GtkButton* _tmp65_;
	GtkButton* _tmp66_;
	parent_class = G_OBJECT_CLASS (welcome_view_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_WELCOME_VIEW, WelcomeView);
	_data10_ = g_slice_new0 (Block10Data);
	_data10_->_ref_count_ = 1;
	_data10_->self = g_object_ref (self);
	_tmp0_ = g_strdup ("This is a demo of the Granite library.");
	_tmp1_ = granite_placeholder_new ("Granite Demo");
	granite_placeholder_set_description (_tmp1_, _tmp0_);
	_g_free0 (_tmp0_);
	g_object_ref_sink (_tmp1_);
	welcome = _tmp1_;
	_tmp2_ = welcome;
	_tmp3_ = (GThemedIcon*) g_themed_icon_new ("valadoc");
	_tmp4_ = _tmp3_;
	_tmp5_ = granite_placeholder_append_button (_tmp2_, (GIcon*) _tmp4_, "Visit Valadoc", "The canonical source for Vala API references");
	_tmp6_ = _tmp5_;
	_g_object_unref0 (_tmp4_);
	vala_button = _tmp6_;
	_tmp7_ = welcome;
	_tmp8_ = (GThemedIcon*) g_themed_icon_new ("git");
	_tmp9_ = _tmp8_;
	_tmp10_ = granite_placeholder_append_button (_tmp7_, (GIcon*) _tmp9_, "Get Granite Source", "Granite's source code is hosted on GitHub");
	_tmp11_ = _tmp10_;
	_g_object_unref0 (_tmp9_);
	source_button = _tmp11_;
	_tmp12_ = g_strdup ("Maybe you can <b>do something</b> to hide it but <i>otherwise</i> it w" \
"ill stay here");
	_tmp13_ = (GThemedIcon*) g_themed_icon_new ("dialog-warning");
	_tmp14_ = granite_placeholder_new ("Panic! At the Button");
	granite_placeholder_set_description (_tmp14_, _tmp12_);
	_g_free0 (_tmp12_);
	granite_placeholder_set_icon (_tmp14_, (GIcon*) _tmp13_);
	_g_object_unref0 (_tmp13_);
	g_object_ref_sink (_tmp14_);
	alert = _tmp14_;
	_tmp15_ = alert;
	gtk_widget_add_css_class ((GtkWidget*) _tmp15_, GRANITE_CSS_CLASS_WARNING);
	_tmp16_ = alert;
	_tmp17_ = (GThemedIcon*) g_themed_icon_new ("edit-delete");
	_tmp18_ = _tmp17_;
	_tmp19_ = granite_placeholder_append_button (_tmp16_, (GIcon*) _tmp18_, "Hide This Button", "Click here to hide this");
	_tmp20_ = _tmp19_;
	_g_object_unref0 (_tmp18_);
	_data10_->alert_action = _tmp20_;
	_tmp21_ = g_strdup ("Try changing search terms. You can also sideload Flatpak apps e.g. fro" \
"m <a href='https://flathub.org'>Flathub</a>");
	_tmp22_ = (GThemedIcon*) g_themed_icon_new ("edit-find-symbolic");
	_tmp23_ = granite_placeholder_new ("No Apps Found");
	granite_placeholder_set_description (_tmp23_, _tmp21_);
	_g_free0 (_tmp21_);
	granite_placeholder_set_icon (_tmp23_, (GIcon*) _tmp22_);
	_g_object_unref0 (_tmp22_);
	g_object_ref_sink (_tmp23_);
	search_placeholder = _tmp23_;
	_tmp24_ = (GtkListBox*) gtk_list_box_new ();
	gtk_widget_set_margin_top ((GtkWidget*) _tmp24_, 12);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp24_, 12);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp24_, 12);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp24_, 12);
	g_object_ref_sink (_tmp24_);
	listbox = _tmp24_;
	_tmp25_ = listbox;
	_tmp26_ = search_placeholder;
	gtk_list_box_set_placeholder (_tmp25_, (GtkWidget*) _tmp26_);
	_tmp27_ = listbox;
	gtk_widget_add_css_class ((GtkWidget*) _tmp27_, GRANITE_CSS_CLASS_CARD);
	_tmp28_ = (GtkSearchEntry*) gtk_search_entry_new ();
	gtk_widget_set_margin_top ((GtkWidget*) _tmp28_, 12);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp28_, 9);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp28_, 12);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp28_, 12);
	g_object_ref_sink (_tmp28_);
	search_entry = _tmp28_;
	_tmp29_ = g_strdup ("Try changing search terms");
	_tmp30_ = (GThemedIcon*) g_themed_icon_new ("edit-find-symbolic");
	_tmp31_ = granite_placeholder_new ("No mailboxes found");
	granite_placeholder_set_description (_tmp31_, _tmp29_);
	_g_free0 (_tmp29_);
	gtk_widget_set_halign ((GtkWidget*) _tmp31_, GTK_ALIGN_FILL);
	granite_placeholder_set_icon (_tmp31_, (GIcon*) _tmp30_);
	_g_object_unref0 (_tmp30_);
	g_object_ref_sink (_tmp31_);
	popover_placeholder = _tmp31_;
	_tmp32_ = (GtkListBox*) gtk_list_box_new ();
	g_object_ref_sink (_tmp32_);
	popover_list = _tmp32_;
	_tmp33_ = popover_list;
	_tmp34_ = popover_placeholder;
	gtk_list_box_set_placeholder (_tmp33_, (GtkWidget*) _tmp34_);
	_tmp35_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
	g_object_ref_sink (_tmp35_);
	box = _tmp35_;
	_tmp36_ = box;
	_tmp37_ = search_entry;
	gtk_box_append (_tmp36_, (GtkWidget*) _tmp37_);
	_tmp38_ = box;
	_tmp39_ = popover_list;
	gtk_box_append (_tmp38_, (GtkWidget*) _tmp39_);
	_tmp40_ = box;
	_tmp41_ = _g_object_ref0 ((GtkWidget*) _tmp40_);
	_tmp42_ = (GtkPopover*) gtk_popover_new ();
	gtk_popover_set_autohide (_tmp42_, TRUE);
	gtk_popover_set_child (_tmp42_, _tmp41_);
	_g_object_unref0 (_tmp41_);
	g_object_ref_sink (_tmp42_);
	popover = _tmp42_;
	_tmp43_ = g_strdup ("Listbox in a Popover");
	_tmp44_ = popover;
	_tmp45_ = _g_object_ref0 (_tmp44_);
	_tmp46_ = (GtkMenuButton*) gtk_menu_button_new ();
	gtk_widget_set_halign ((GtkWidget*) _tmp46_, GTK_ALIGN_CENTER);
	gtk_widget_set_valign ((GtkWidget*) _tmp46_, GTK_ALIGN_CENTER);
	gtk_menu_button_set_label (_tmp46_, _tmp43_);
	_g_free0 (_tmp43_);
	gtk_menu_button_set_popover (_tmp46_, _tmp45_);
	_g_object_unref0 (_tmp45_);
	g_object_ref_sink (_tmp46_);
	menubutton = _tmp46_;
	_tmp47_ = (GtkStack*) gtk_stack_new ();
	gtk_widget_set_margin_top ((GtkWidget*) _tmp47_, 12);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp47_, 12);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp47_, 12);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp47_, 12);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp47_, TRUE);
	g_object_ref_sink (_tmp47_);
	stack = _tmp47_;
	_tmp48_ = stack;
	_tmp49_ = welcome;
	gtk_stack_add_titled (_tmp48_, (GtkWidget*) _tmp49_, "Welcome", "Welcome");
	_tmp50_ = stack;
	_tmp51_ = alert;
	gtk_stack_add_titled (_tmp50_, (GtkWidget*) _tmp51_, "Alert", "Alert");
	_tmp52_ = stack;
	_tmp53_ = listbox;
	gtk_stack_add_titled (_tmp52_, (GtkWidget*) _tmp53_, "ListBox", "ListBox");
	_tmp54_ = stack;
	_tmp55_ = menubutton;
	gtk_stack_add_titled (_tmp54_, (GtkWidget*) _tmp55_, "Popover", "Popover");
	_tmp56_ = stack;
	_tmp57_ = _g_object_ref0 (_tmp56_);
	_tmp58_ = (GtkStackSwitcher*) gtk_stack_switcher_new ();
	gtk_widget_set_halign ((GtkWidget*) _tmp58_, GTK_ALIGN_CENTER);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp58_, 12);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp58_, 12);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp58_, 12);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp58_, 12);
	gtk_stack_switcher_set_stack (_tmp58_, _tmp57_);
	_g_object_unref0 (_tmp57_);
	g_object_ref_sink (_tmp58_);
	stack_switcher = _tmp58_;
	_tmp59_ = stack_switcher;
	_tmp60_ = gtk_widget_get_layout_manager ((GtkWidget*) _tmp59_);
	_tmp61_ = _tmp60_;
	gtk_box_layout_set_homogeneous (G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, gtk_box_layout_get_type (), GtkBoxLayout), TRUE);
	_tmp62_ = stack;
	demo_page_set_child ((DemoPage*) self, (GtkWidget*) _tmp62_);
	_tmp63_ = stack_switcher;
	granite_tool_box_add_bottom_bar ((GraniteToolBox*) self, (GtkWidget*) _tmp63_);
	_tmp64_ = vala_button;
	g_signal_connect_object (_tmp64_, "clicked", (GCallback) __welcome_view___lambda15__gtk_button_clicked, self, 0);
	_tmp65_ = source_button;
	g_signal_connect_object (_tmp65_, "clicked", (GCallback) __welcome_view___lambda16__gtk_button_clicked, self, 0);
	_tmp66_ = _data10_->alert_action;
	g_signal_connect_data (_tmp66_, "clicked", (GCallback) __welcome_view___lambda17__gtk_button_clicked, block10_data_ref (_data10_), (GClosureNotify) block10_data_unref, 0);
	_g_object_unref0 (stack_switcher);
	_g_object_unref0 (stack);
	_g_object_unref0 (menubutton);
	_g_object_unref0 (popover);
	_g_object_unref0 (box);
	_g_object_unref0 (popover_list);
	_g_object_unref0 (popover_placeholder);
	_g_object_unref0 (search_entry);
	_g_object_unref0 (listbox);
	_g_object_unref0 (search_placeholder);
	_g_object_unref0 (alert);
	_g_object_unref0 (source_button);
	_g_object_unref0 (vala_button);
	_g_object_unref0 (welcome);
	block10_data_unref (_data10_);
	_data10_ = NULL;
	return obj;
}

static void
welcome_view_class_init (WelcomeViewClass * klass,
                         gpointer klass_data)
{
	welcome_view_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->constructor = welcome_view_constructor;
}

static void
welcome_view_instance_init (WelcomeView * self,
                            gpointer klass)
{
}

static GType
welcome_view_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (WelcomeViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) welcome_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (WelcomeView), 0, (GInstanceInitFunc) welcome_view_instance_init, NULL };
	GType welcome_view_type_id;
	welcome_view_type_id = g_type_register_static (TYPE_DEMO_PAGE, "WelcomeView", &g_define_type_info, 0);
	return welcome_view_type_id;
}

GType
welcome_view_get_type (void)
{
	static volatile gsize welcome_view_type_id__once = 0;
	if (g_once_init_enter (&welcome_view_type_id__once)) {
		GType welcome_view_type_id;
		welcome_view_type_id = welcome_view_get_type_once ();
		g_once_init_leave (&welcome_view_type_id__once, welcome_view_type_id);
	}
	return welcome_view_type_id__once;
}

