/* BoxView.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from BoxView.vala, do not modify */

/*
 * Copyright 2025 elementary, Inc. (https://elementary.io)
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */

#include "granite-7.h"
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gtk/gtk.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_DEMO_PAGE (demo_page_get_type ())
#define DEMO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DEMO_PAGE, DemoPage))
#define DEMO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DEMO_PAGE, DemoPageClass))
#define IS_DEMO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DEMO_PAGE))
#define IS_DEMO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DEMO_PAGE))
#define DEMO_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DEMO_PAGE, DemoPageClass))

typedef struct _DemoPage DemoPage;
typedef struct _DemoPageClass DemoPageClass;
typedef struct _DemoPagePrivate DemoPagePrivate;

#define TYPE_BOX_VIEW (box_view_get_type ())
#define BOX_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BOX_VIEW, BoxView))
#define BOX_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BOX_VIEW, BoxViewClass))
#define IS_BOX_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BOX_VIEW))
#define IS_BOX_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BOX_VIEW))
#define BOX_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BOX_VIEW, BoxViewClass))

typedef struct _BoxView BoxView;
typedef struct _BoxViewClass BoxViewClass;
typedef struct _BoxViewPrivate BoxViewPrivate;
enum  {
	BOX_VIEW_0_PROPERTY,
	BOX_VIEW_NUM_PROPERTIES
};
static GParamSpec* box_view_properties[BOX_VIEW_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _DemoPage {
	GraniteToolBox parent_instance;
	DemoPagePrivate * priv;
};

struct _DemoPageClass {
	GraniteToolBoxClass parent_class;
};

struct _BoxView {
	DemoPage parent_instance;
	BoxViewPrivate * priv;
};

struct _BoxViewClass {
	DemoPageClass parent_class;
};

static gpointer box_view_parent_class = NULL;

VALA_EXTERN GType demo_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DemoPage, g_object_unref)
VALA_EXTERN GType box_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BoxView, g_object_unref)
VALA_EXTERN BoxView* box_view_new (void);
VALA_EXTERN BoxView* box_view_construct (GType object_type);
VALA_EXTERN DemoPage* demo_page_new (void);
VALA_EXTERN DemoPage* demo_page_construct (GType object_type);
static GObject * box_view_constructor (GType type,
                                guint n_construct_properties,
                                GObjectConstructParam * construct_properties);
VALA_EXTERN void demo_page_set_title (DemoPage* self,
                          const gchar* value);
VALA_EXTERN void demo_page_set_child (DemoPage* self,
                          GtkWidget* value);
static GType box_view_get_type_once (void);

BoxView*
box_view_construct (GType object_type)
{
	BoxView * self = NULL;
	self = (BoxView*) demo_page_construct (object_type);
	return self;
}

BoxView*
box_view_new (void)
{
	return box_view_construct (TYPE_BOX_VIEW);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static GObject *
box_view_constructor (GType type,
                      guint n_construct_properties,
                      GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	BoxView * self;
	GraniteHeaderLabel* single_header = NULL;
	gchar* _tmp0_;
	GraniteHeaderLabel* _tmp1_ = NULL;
	GraniteBox* single_box = NULL;
	GraniteBox* _tmp2_;
	GraniteBox* _tmp3_;
	GtkImage* _tmp4_ = NULL;
	GtkImage* _tmp5_;
	GraniteBox* _tmp6_;
	GtkImage* _tmp7_ = NULL;
	GtkImage* _tmp8_;
	GraniteBox* single_container = NULL;
	GraniteBox* _tmp9_;
	GraniteBox* _tmp10_;
	GraniteHeaderLabel* _tmp11_;
	GraniteBox* _tmp12_;
	GraniteBox* _tmp13_;
	GraniteHeaderLabel* double_header = NULL;
	gchar* _tmp14_;
	GraniteHeaderLabel* _tmp15_ = NULL;
	GraniteBox* double_box = NULL;
	GraniteBox* _tmp16_;
	GraniteBox* _tmp17_;
	GtkImage* _tmp18_ = NULL;
	GtkImage* _tmp19_;
	GraniteBox* _tmp20_;
	GtkImage* _tmp21_ = NULL;
	GtkImage* _tmp22_;
	GraniteBox* double_container = NULL;
	GraniteBox* _tmp23_;
	GraniteBox* _tmp24_;
	GraniteHeaderLabel* _tmp25_;
	GraniteBox* _tmp26_;
	GraniteBox* _tmp27_;
	GraniteHeaderLabel* linked_header = NULL;
	gchar* _tmp28_;
	GraniteHeaderLabel* _tmp29_ = NULL;
	GtkToggleButton* column_button = NULL;
	gchar* _tmp30_;
	GtkToggleButton* _tmp31_ = NULL;
	GraniteBox* linked_image_buttons = NULL;
	GraniteBox* _tmp32_;
	GraniteBox* _tmp33_;
	GtkToggleButton* _tmp34_;
	GraniteBox* _tmp35_;
	GtkToggleButton* _tmp36_;
	GtkToggleButton* _tmp37_;
	gchar* _tmp38_;
	GtkToggleButton* _tmp39_ = NULL;
	GtkToggleButton* _tmp40_;
	GraniteBox* _tmp41_;
	GtkToggleButton* _tmp42_;
	GtkToggleButton* _tmp43_;
	gchar* _tmp44_;
	GtkToggleButton* _tmp45_ = NULL;
	GtkToggleButton* _tmp46_;
	GraniteBox* linked_text_buttons = NULL;
	GraniteBox* _tmp47_;
	GraniteBox* _tmp48_;
	GtkButton* _tmp49_ = NULL;
	GtkButton* _tmp50_;
	GraniteBox* _tmp51_;
	GtkButton* _tmp52_ = NULL;
	GtkButton* _tmp53_;
	GraniteBox* linked_buttons_box = NULL;
	GraniteBox* _tmp54_;
	GraniteBox* _tmp55_;
	GraniteBox* _tmp56_;
	GraniteBox* _tmp57_;
	GraniteBox* _tmp58_;
	GraniteBox* linked_entries_box = NULL;
	GraniteBox* _tmp59_;
	GraniteBox* _tmp60_;
	gchar* _tmp61_;
	GtkEntry* _tmp62_ = NULL;
	GtkEntry* _tmp63_;
	GraniteBox* _tmp64_;
	gchar* _tmp65_;
	GtkEntry* _tmp66_ = NULL;
	GtkEntry* _tmp67_;
	GraniteBox* linked_entry_imagebutton_box = NULL;
	GraniteBox* _tmp68_;
	GraniteBox* _tmp69_;
	gchar* _tmp70_;
	GtkEntry* _tmp71_ = NULL;
	GtkEntry* _tmp72_;
	GraniteBox* _tmp73_;
	gchar* _tmp74_;
	GtkToggleButton* _tmp75_ = NULL;
	GtkToggleButton* _tmp76_;
	GraniteBox* linked_vbox = NULL;
	GraniteBox* _tmp77_;
	GraniteBox* _tmp78_;
	GraniteBox* _tmp79_;
	GraniteBox* _tmp80_;
	GraniteBox* _tmp81_;
	GraniteBox* _tmp82_;
	GraniteBox* _tmp83_;
	GraniteBox* vertical_imagebuttons = NULL;
	GraniteBox* _tmp84_;
	GraniteBox* _tmp85_;
	gchar* _tmp86_;
	GtkButton* _tmp87_ = NULL;
	GtkButton* _tmp88_;
	GraniteBox* _tmp89_;
	gchar* _tmp90_;
	GtkButton* _tmp91_ = NULL;
	GtkButton* _tmp92_;
	GraniteBox* _tmp93_;
	gchar* _tmp94_;
	GtkButton* _tmp95_ = NULL;
	GtkButton* _tmp96_;
	GraniteBox* _tmp97_;
	gchar* _tmp98_;
	GtkButton* _tmp99_ = NULL;
	GtkButton* _tmp100_;
	GraniteBox* linked_hbox = NULL;
	GraniteBox* _tmp101_;
	GraniteBox* _tmp102_;
	GraniteBox* _tmp103_;
	GraniteBox* _tmp104_;
	GraniteBox* _tmp105_;
	GraniteBox* linked_box = NULL;
	GraniteBox* _tmp106_;
	GraniteBox* _tmp107_;
	GraniteHeaderLabel* _tmp108_;
	GraniteBox* _tmp109_;
	GraniteBox* _tmp110_;
	GraniteBox* vbox = NULL;
	GraniteBox* _tmp111_ = NULL;
	GraniteBox* _tmp112_;
	GraniteBox* _tmp113_;
	GraniteBox* _tmp114_;
	GraniteBox* _tmp115_;
	GraniteBox* _tmp116_;
	GraniteBox* _tmp117_;
	GraniteBox* _tmp118_;
	parent_class = G_OBJECT_CLASS (box_view_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_BOX_VIEW, BoxView);
	demo_page_set_title ((DemoPage*) self, "Granite.Box");
	_tmp0_ = g_strdup ("child_spacing = SINGLE");
	_tmp1_ = granite_header_label_new ("Single Spaced");
	granite_header_label_set_secondary_text (_tmp1_, _tmp0_);
	_g_free0 (_tmp0_);
	g_object_ref_sink (_tmp1_);
	single_header = _tmp1_;
	_tmp2_ = granite_box_new (GTK_ORIENTATION_HORIZONTAL, GRANITE_BOX_SPACING_SINGLE);
	g_object_ref_sink (_tmp2_);
	single_box = _tmp2_;
	_tmp3_ = single_box;
	_tmp4_ = (GtkImage*) gtk_image_new_from_icon_name ("package-x-generic");
	gtk_image_set_icon_size (_tmp4_, GTK_ICON_SIZE_LARGE);
	g_object_ref_sink (_tmp4_);
	_tmp5_ = _tmp4_;
	gtk_box_append ((GtkBox*) _tmp3_, (GtkWidget*) _tmp5_);
	_g_object_unref0 (_tmp5_);
	_tmp6_ = single_box;
	_tmp7_ = (GtkImage*) gtk_image_new_from_icon_name ("package-x-generic");
	gtk_image_set_icon_size (_tmp7_, GTK_ICON_SIZE_LARGE);
	g_object_ref_sink (_tmp7_);
	_tmp8_ = _tmp7_;
	gtk_box_append ((GtkBox*) _tmp6_, (GtkWidget*) _tmp8_);
	_g_object_unref0 (_tmp8_);
	_tmp9_ = granite_box_new (GTK_ORIENTATION_VERTICAL, GRANITE_BOX_SPACING_SINGLE);
	g_object_ref_sink (_tmp9_);
	single_container = _tmp9_;
	_tmp10_ = single_container;
	_tmp11_ = single_header;
	gtk_box_append ((GtkBox*) _tmp10_, (GtkWidget*) _tmp11_);
	_tmp12_ = single_container;
	_tmp13_ = single_box;
	gtk_box_append ((GtkBox*) _tmp12_, (GtkWidget*) _tmp13_);
	_tmp14_ = g_strdup ("child_spacing = DOUBLE");
	_tmp15_ = granite_header_label_new ("Double Spaced");
	granite_header_label_set_secondary_text (_tmp15_, _tmp14_);
	_g_free0 (_tmp14_);
	g_object_ref_sink (_tmp15_);
	double_header = _tmp15_;
	_tmp16_ = granite_box_new (GTK_ORIENTATION_HORIZONTAL, GRANITE_BOX_SPACING_DOUBLE);
	g_object_ref_sink (_tmp16_);
	double_box = _tmp16_;
	_tmp17_ = double_box;
	_tmp18_ = (GtkImage*) gtk_image_new_from_icon_name ("package-x-generic");
	gtk_image_set_icon_size (_tmp18_, GTK_ICON_SIZE_LARGE);
	g_object_ref_sink (_tmp18_);
	_tmp19_ = _tmp18_;
	gtk_box_append ((GtkBox*) _tmp17_, (GtkWidget*) _tmp19_);
	_g_object_unref0 (_tmp19_);
	_tmp20_ = double_box;
	_tmp21_ = (GtkImage*) gtk_image_new_from_icon_name ("package-x-generic");
	gtk_image_set_icon_size (_tmp21_, GTK_ICON_SIZE_LARGE);
	g_object_ref_sink (_tmp21_);
	_tmp22_ = _tmp21_;
	gtk_box_append ((GtkBox*) _tmp20_, (GtkWidget*) _tmp22_);
	_g_object_unref0 (_tmp22_);
	_tmp23_ = granite_box_new (GTK_ORIENTATION_VERTICAL, GRANITE_BOX_SPACING_SINGLE);
	g_object_ref_sink (_tmp23_);
	double_container = _tmp23_;
	_tmp24_ = double_container;
	_tmp25_ = double_header;
	gtk_box_append ((GtkBox*) _tmp24_, (GtkWidget*) _tmp25_);
	_tmp26_ = double_container;
	_tmp27_ = double_box;
	gtk_box_append ((GtkBox*) _tmp26_, (GtkWidget*) _tmp27_);
	_tmp28_ = g_strdup ("child_spacing = LINKED");
	_tmp29_ = granite_header_label_new ("Linked");
	granite_header_label_set_secondary_text (_tmp29_, _tmp28_);
	_g_free0 (_tmp28_);
	g_object_ref_sink (_tmp29_);
	linked_header = _tmp29_;
	_tmp30_ = g_strdup ("view-column-symbolic");
	_tmp31_ = (GtkToggleButton*) gtk_toggle_button_new ();
	gtk_toggle_button_set_active (_tmp31_, TRUE);
	gtk_button_set_icon_name ((GtkButton*) _tmp31_, _tmp30_);
	_g_free0 (_tmp30_);
	g_object_ref_sink (_tmp31_);
	column_button = _tmp31_;
	_tmp32_ = granite_box_new (GTK_ORIENTATION_HORIZONTAL, GRANITE_BOX_SPACING_LINKED);
	g_object_ref_sink (_tmp32_);
	linked_image_buttons = _tmp32_;
	_tmp33_ = linked_image_buttons;
	_tmp34_ = column_button;
	gtk_box_append ((GtkBox*) _tmp33_, (GtkWidget*) _tmp34_);
	_tmp35_ = linked_image_buttons;
	_tmp36_ = column_button;
	_tmp37_ = _g_object_ref0 (_tmp36_);
	_tmp38_ = g_strdup ("view-grid-symbolic");
	_tmp39_ = (GtkToggleButton*) gtk_toggle_button_new ();
	gtk_toggle_button_set_group (_tmp39_, _tmp37_);
	_g_object_unref0 (_tmp37_);
	gtk_button_set_icon_name ((GtkButton*) _tmp39_, _tmp38_);
	_g_free0 (_tmp38_);
	g_object_ref_sink (_tmp39_);
	_tmp40_ = _tmp39_;
	gtk_box_append ((GtkBox*) _tmp35_, (GtkWidget*) _tmp40_);
	_g_object_unref0 (_tmp40_);
	_tmp41_ = linked_image_buttons;
	_tmp42_ = column_button;
	_tmp43_ = _g_object_ref0 (_tmp42_);
	_tmp44_ = g_strdup ("view-list-symbolic");
	_tmp45_ = (GtkToggleButton*) gtk_toggle_button_new ();
	gtk_toggle_button_set_group (_tmp45_, _tmp43_);
	_g_object_unref0 (_tmp43_);
	gtk_button_set_icon_name ((GtkButton*) _tmp45_, _tmp44_);
	_g_free0 (_tmp44_);
	g_object_ref_sink (_tmp45_);
	_tmp46_ = _tmp45_;
	gtk_box_append ((GtkBox*) _tmp41_, (GtkWidget*) _tmp46_);
	_g_object_unref0 (_tmp46_);
	_tmp47_ = granite_box_new (GTK_ORIENTATION_HORIZONTAL, GRANITE_BOX_SPACING_LINKED);
	g_object_ref_sink (_tmp47_);
	linked_text_buttons = _tmp47_;
	_tmp48_ = linked_text_buttons;
	_tmp49_ = (GtkButton*) gtk_button_new_with_label ("Button");
	gtk_widget_set_hexpand ((GtkWidget*) _tmp49_, TRUE);
	g_object_ref_sink (_tmp49_);
	_tmp50_ = _tmp49_;
	gtk_box_append ((GtkBox*) _tmp48_, (GtkWidget*) _tmp50_);
	_g_object_unref0 (_tmp50_);
	_tmp51_ = linked_text_buttons;
	_tmp52_ = (GtkButton*) gtk_button_new_with_label ("Button");
	gtk_widget_set_hexpand ((GtkWidget*) _tmp52_, TRUE);
	g_object_ref_sink (_tmp52_);
	_tmp53_ = _tmp52_;
	gtk_box_append ((GtkBox*) _tmp51_, (GtkWidget*) _tmp53_);
	_g_object_unref0 (_tmp53_);
	_tmp54_ = granite_box_new (GTK_ORIENTATION_HORIZONTAL, GRANITE_BOX_SPACING_SINGLE);
	g_object_ref_sink (_tmp54_);
	linked_buttons_box = _tmp54_;
	_tmp55_ = linked_buttons_box;
	_tmp56_ = linked_image_buttons;
	gtk_box_append ((GtkBox*) _tmp55_, (GtkWidget*) _tmp56_);
	_tmp57_ = linked_buttons_box;
	_tmp58_ = linked_text_buttons;
	gtk_box_append ((GtkBox*) _tmp57_, (GtkWidget*) _tmp58_);
	_tmp59_ = granite_box_new (GTK_ORIENTATION_HORIZONTAL, GRANITE_BOX_SPACING_LINKED);
	g_object_ref_sink (_tmp59_);
	linked_entries_box = _tmp59_;
	_tmp60_ = linked_entries_box;
	_tmp61_ = g_strdup ("Entry");
	_tmp62_ = (GtkEntry*) gtk_entry_new ();
	gtk_widget_set_hexpand ((GtkWidget*) _tmp62_, TRUE);
	gtk_entry_set_placeholder_text (_tmp62_, _tmp61_);
	_g_free0 (_tmp61_);
	g_object_ref_sink (_tmp62_);
	_tmp63_ = _tmp62_;
	gtk_box_append ((GtkBox*) _tmp60_, (GtkWidget*) _tmp63_);
	_g_object_unref0 (_tmp63_);
	_tmp64_ = linked_entries_box;
	_tmp65_ = g_strdup ("Entry");
	_tmp66_ = (GtkEntry*) gtk_entry_new ();
	gtk_widget_set_hexpand ((GtkWidget*) _tmp66_, TRUE);
	gtk_entry_set_placeholder_text (_tmp66_, _tmp65_);
	_g_free0 (_tmp65_);
	g_object_ref_sink (_tmp66_);
	_tmp67_ = _tmp66_;
	gtk_box_append ((GtkBox*) _tmp64_, (GtkWidget*) _tmp67_);
	_g_object_unref0 (_tmp67_);
	_tmp68_ = granite_box_new (GTK_ORIENTATION_HORIZONTAL, GRANITE_BOX_SPACING_LINKED);
	g_object_ref_sink (_tmp68_);
	linked_entry_imagebutton_box = _tmp68_;
	_tmp69_ = linked_entry_imagebutton_box;
	_tmp70_ = g_strdup ("Entry");
	_tmp71_ = (GtkEntry*) gtk_entry_new ();
	gtk_widget_set_hexpand ((GtkWidget*) _tmp71_, TRUE);
	gtk_entry_set_placeholder_text (_tmp71_, _tmp70_);
	_g_free0 (_tmp70_);
	g_object_ref_sink (_tmp71_);
	_tmp72_ = _tmp71_;
	gtk_box_append ((GtkBox*) _tmp69_, (GtkWidget*) _tmp72_);
	_g_object_unref0 (_tmp72_);
	_tmp73_ = linked_entry_imagebutton_box;
	_tmp74_ = g_strdup ("view-more-symbolic");
	_tmp75_ = (GtkToggleButton*) gtk_toggle_button_new ();
	gtk_button_set_icon_name ((GtkButton*) _tmp75_, _tmp74_);
	_g_free0 (_tmp74_);
	g_object_ref_sink (_tmp75_);
	_tmp76_ = _tmp75_;
	gtk_box_append ((GtkBox*) _tmp73_, (GtkWidget*) _tmp76_);
	_g_object_unref0 (_tmp76_);
	_tmp77_ = granite_box_new (GTK_ORIENTATION_VERTICAL, GRANITE_BOX_SPACING_SINGLE);
	g_object_ref_sink (_tmp77_);
	linked_vbox = _tmp77_;
	_tmp78_ = linked_vbox;
	_tmp79_ = linked_buttons_box;
	gtk_box_append ((GtkBox*) _tmp78_, (GtkWidget*) _tmp79_);
	_tmp80_ = linked_vbox;
	_tmp81_ = linked_entries_box;
	gtk_box_append ((GtkBox*) _tmp80_, (GtkWidget*) _tmp81_);
	_tmp82_ = linked_vbox;
	_tmp83_ = linked_entry_imagebutton_box;
	gtk_box_append ((GtkBox*) _tmp82_, (GtkWidget*) _tmp83_);
	_tmp84_ = granite_box_new (GTK_ORIENTATION_VERTICAL, GRANITE_BOX_SPACING_LINKED);
	g_object_ref_sink (_tmp84_);
	vertical_imagebuttons = _tmp84_;
	_tmp85_ = vertical_imagebuttons;
	_tmp86_ = g_strdup ("edit-cut");
	_tmp87_ = (GtkButton*) gtk_button_new ();
	gtk_button_set_icon_name (_tmp87_, _tmp86_);
	_g_free0 (_tmp86_);
	g_object_ref_sink (_tmp87_);
	_tmp88_ = _tmp87_;
	gtk_box_append ((GtkBox*) _tmp85_, (GtkWidget*) _tmp88_);
	_g_object_unref0 (_tmp88_);
	_tmp89_ = vertical_imagebuttons;
	_tmp90_ = g_strdup ("edit-copy");
	_tmp91_ = (GtkButton*) gtk_button_new ();
	gtk_button_set_icon_name (_tmp91_, _tmp90_);
	_g_free0 (_tmp90_);
	g_object_ref_sink (_tmp91_);
	_tmp92_ = _tmp91_;
	gtk_box_append ((GtkBox*) _tmp89_, (GtkWidget*) _tmp92_);
	_g_object_unref0 (_tmp92_);
	_tmp93_ = vertical_imagebuttons;
	_tmp94_ = g_strdup ("edit-paste");
	_tmp95_ = (GtkButton*) gtk_button_new ();
	gtk_button_set_icon_name (_tmp95_, _tmp94_);
	_g_free0 (_tmp94_);
	g_object_ref_sink (_tmp95_);
	_tmp96_ = _tmp95_;
	gtk_box_append ((GtkBox*) _tmp93_, (GtkWidget*) _tmp96_);
	_g_object_unref0 (_tmp96_);
	_tmp97_ = vertical_imagebuttons;
	_tmp98_ = g_strdup ("edit-delete");
	_tmp99_ = (GtkButton*) gtk_button_new ();
	gtk_button_set_icon_name (_tmp99_, _tmp98_);
	_g_free0 (_tmp98_);
	g_object_ref_sink (_tmp99_);
	_tmp100_ = _tmp99_;
	gtk_box_append ((GtkBox*) _tmp97_, (GtkWidget*) _tmp100_);
	_g_object_unref0 (_tmp100_);
	_tmp101_ = granite_box_new (GTK_ORIENTATION_HORIZONTAL, GRANITE_BOX_SPACING_SINGLE);
	g_object_ref_sink (_tmp101_);
	linked_hbox = _tmp101_;
	_tmp102_ = linked_hbox;
	_tmp103_ = linked_vbox;
	gtk_box_append ((GtkBox*) _tmp102_, (GtkWidget*) _tmp103_);
	_tmp104_ = linked_hbox;
	_tmp105_ = vertical_imagebuttons;
	gtk_box_append ((GtkBox*) _tmp104_, (GtkWidget*) _tmp105_);
	_tmp106_ = granite_box_new (GTK_ORIENTATION_VERTICAL, GRANITE_BOX_SPACING_SINGLE);
	g_object_ref_sink (_tmp106_);
	linked_box = _tmp106_;
	_tmp107_ = linked_box;
	_tmp108_ = linked_header;
	gtk_box_append ((GtkBox*) _tmp107_, (GtkWidget*) _tmp108_);
	_tmp109_ = linked_box;
	_tmp110_ = linked_hbox;
	gtk_box_append ((GtkBox*) _tmp109_, (GtkWidget*) _tmp110_);
	_tmp111_ = granite_box_new (GTK_ORIENTATION_VERTICAL, GRANITE_BOX_SPACING_DOUBLE);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp111_, 12);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp111_, 12);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp111_, 12);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp111_, 12);
	g_object_ref_sink (_tmp111_);
	vbox = _tmp111_;
	_tmp112_ = vbox;
	_tmp113_ = single_container;
	gtk_box_append ((GtkBox*) _tmp112_, (GtkWidget*) _tmp113_);
	_tmp114_ = vbox;
	_tmp115_ = double_container;
	gtk_box_append ((GtkBox*) _tmp114_, (GtkWidget*) _tmp115_);
	_tmp116_ = vbox;
	_tmp117_ = linked_box;
	gtk_box_append ((GtkBox*) _tmp116_, (GtkWidget*) _tmp117_);
	_tmp118_ = vbox;
	demo_page_set_child ((DemoPage*) self, (GtkWidget*) _tmp118_);
	_g_object_unref0 (vbox);
	_g_object_unref0 (linked_box);
	_g_object_unref0 (linked_hbox);
	_g_object_unref0 (vertical_imagebuttons);
	_g_object_unref0 (linked_vbox);
	_g_object_unref0 (linked_entry_imagebutton_box);
	_g_object_unref0 (linked_entries_box);
	_g_object_unref0 (linked_buttons_box);
	_g_object_unref0 (linked_text_buttons);
	_g_object_unref0 (linked_image_buttons);
	_g_object_unref0 (column_button);
	_g_object_unref0 (linked_header);
	_g_object_unref0 (double_container);
	_g_object_unref0 (double_box);
	_g_object_unref0 (double_header);
	_g_object_unref0 (single_container);
	_g_object_unref0 (single_box);
	_g_object_unref0 (single_header);
	return obj;
}

static void
box_view_class_init (BoxViewClass * klass,
                     gpointer klass_data)
{
	box_view_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->constructor = box_view_constructor;
}

static void
box_view_instance_init (BoxView * self,
                        gpointer klass)
{
}

static GType
box_view_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (BoxViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) box_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxView), 0, (GInstanceInitFunc) box_view_instance_init, NULL };
	GType box_view_type_id;
	box_view_type_id = g_type_register_static (TYPE_DEMO_PAGE, "BoxView", &g_define_type_info, 0);
	return box_view_type_id;
}

GType
box_view_get_type (void)
{
	static volatile gsize box_view_type_id__once = 0;
	if (g_once_init_enter (&box_view_type_id__once)) {
		GType box_view_type_id;
		box_view_type_id = box_view_get_type_once ();
		g_once_init_leave (&box_view_type_id__once, box_view_type_id);
	}
	return box_view_type_id__once;
}

