/* GraniteDemo.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from GraniteDemo.vala, do not modify */

/*
 * Copyright 2011-2021 elementary, Inc. (https://elementary.io)
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */

#include <gtk/gtk.h>
#include <glib-object.h>
#include <gio/gio.h>
#include "granite-7.h"
#include <glib.h>
#include <stdlib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GRANITE_TYPE_DEMO (granite_demo_get_type ())
#define GRANITE_DEMO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_DEMO, GraniteDemo))
#define GRANITE_DEMO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_DEMO, GraniteDemoClass))
#define GRANITE_IS_DEMO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_DEMO))
#define GRANITE_IS_DEMO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_DEMO))
#define GRANITE_DEMO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_DEMO, GraniteDemoClass))

typedef struct _GraniteDemo GraniteDemo;
typedef struct _GraniteDemoClass GraniteDemoClass;
typedef struct _GraniteDemoPrivate GraniteDemoPrivate;
enum  {
	GRANITE_DEMO_0_PROPERTY,
	GRANITE_DEMO_NUM_PROPERTIES
};
static GParamSpec* granite_demo_properties[GRANITE_DEMO_NUM_PROPERTIES];
typedef struct _Block1Data Block1Data;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_DEMO_PAGE (demo_page_get_type ())
#define DEMO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DEMO_PAGE, DemoPage))
#define DEMO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DEMO_PAGE, DemoPageClass))
#define IS_DEMO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DEMO_PAGE))
#define IS_DEMO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DEMO_PAGE))
#define DEMO_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DEMO_PAGE, DemoPageClass))

typedef struct _DemoPage DemoPage;
typedef struct _DemoPageClass DemoPageClass;

#define TYPE_BOX_VIEW (box_view_get_type ())
#define BOX_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BOX_VIEW, BoxView))
#define BOX_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BOX_VIEW, BoxViewClass))
#define IS_BOX_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BOX_VIEW))
#define IS_BOX_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BOX_VIEW))
#define BOX_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BOX_VIEW, BoxViewClass))

typedef struct _BoxView BoxView;
typedef struct _BoxViewClass BoxViewClass;

#define TYPE_LISTS_VIEW (lists_view_get_type ())
#define LISTS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LISTS_VIEW, ListsView))
#define LISTS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LISTS_VIEW, ListsViewClass))
#define IS_LISTS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LISTS_VIEW))
#define IS_LISTS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LISTS_VIEW))
#define LISTS_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LISTS_VIEW, ListsViewClass))

typedef struct _ListsView ListsView;
typedef struct _ListsViewClass ListsViewClass;

#define TYPE_ACCEL_LABEL_VIEW (accel_label_view_get_type ())
#define ACCEL_LABEL_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ACCEL_LABEL_VIEW, AccelLabelView))
#define ACCEL_LABEL_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ACCEL_LABEL_VIEW, AccelLabelViewClass))
#define IS_ACCEL_LABEL_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ACCEL_LABEL_VIEW))
#define IS_ACCEL_LABEL_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ACCEL_LABEL_VIEW))
#define ACCEL_LABEL_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ACCEL_LABEL_VIEW, AccelLabelViewClass))

typedef struct _AccelLabelView AccelLabelView;
typedef struct _AccelLabelViewClass AccelLabelViewClass;

#define TYPE_CSS_VIEW (css_view_get_type ())
#define CSS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CSS_VIEW, CSSView))
#define CSS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CSS_VIEW, CSSViewClass))
#define IS_CSS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CSS_VIEW))
#define IS_CSS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CSS_VIEW))
#define CSS_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CSS_VIEW, CSSViewClass))

typedef struct _CSSView CSSView;
typedef struct _CSSViewClass CSSViewClass;

#define TYPE_DATE_TIME_PICKER_VIEW (date_time_picker_view_get_type ())
#define DATE_TIME_PICKER_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATE_TIME_PICKER_VIEW, DateTimePickerView))
#define DATE_TIME_PICKER_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATE_TIME_PICKER_VIEW, DateTimePickerViewClass))
#define IS_DATE_TIME_PICKER_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATE_TIME_PICKER_VIEW))
#define IS_DATE_TIME_PICKER_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATE_TIME_PICKER_VIEW))
#define DATE_TIME_PICKER_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATE_TIME_PICKER_VIEW, DateTimePickerViewClass))

typedef struct _DateTimePickerView DateTimePickerView;
typedef struct _DateTimePickerViewClass DateTimePickerViewClass;

#define TYPE_FORM_VIEW (form_view_get_type ())
#define FORM_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FORM_VIEW, FormView))
#define FORM_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FORM_VIEW, FormViewClass))
#define IS_FORM_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FORM_VIEW))
#define IS_FORM_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FORM_VIEW))
#define FORM_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FORM_VIEW, FormViewClass))

typedef struct _FormView FormView;
typedef struct _FormViewClass FormViewClass;

#define TYPE_HYPER_TEXT_VIEW_GRID (hyper_text_view_grid_get_type ())
#define HYPER_TEXT_VIEW_GRID(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_HYPER_TEXT_VIEW_GRID, HyperTextViewGrid))
#define HYPER_TEXT_VIEW_GRID_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_HYPER_TEXT_VIEW_GRID, HyperTextViewGridClass))
#define IS_HYPER_TEXT_VIEW_GRID(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_HYPER_TEXT_VIEW_GRID))
#define IS_HYPER_TEXT_VIEW_GRID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_HYPER_TEXT_VIEW_GRID))
#define HYPER_TEXT_VIEW_GRID_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_HYPER_TEXT_VIEW_GRID, HyperTextViewGridClass))

typedef struct _HyperTextViewGrid HyperTextViewGrid;
typedef struct _HyperTextViewGridClass HyperTextViewGridClass;

#define TYPE_CONTROLS_VIEW (controls_view_get_type ())
#define CONTROLS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONTROLS_VIEW, ControlsView))
#define CONTROLS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONTROLS_VIEW, ControlsViewClass))
#define IS_CONTROLS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONTROLS_VIEW))
#define IS_CONTROLS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONTROLS_VIEW))
#define CONTROLS_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONTROLS_VIEW, ControlsViewClass))

typedef struct _ControlsView ControlsView;
typedef struct _ControlsViewClass ControlsViewClass;

#define TYPE_MAPS_VIEW (maps_view_get_type ())
#define MAPS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MAPS_VIEW, MapsView))
#define MAPS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MAPS_VIEW, MapsViewClass))
#define IS_MAPS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MAPS_VIEW))
#define IS_MAPS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MAPS_VIEW))
#define MAPS_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MAPS_VIEW, MapsViewClass))

typedef struct _MapsView MapsView;
typedef struct _MapsViewClass MapsViewClass;

#define TYPE_OVERLAY_BAR_VIEW (overlay_bar_view_get_type ())
#define OVERLAY_BAR_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OVERLAY_BAR_VIEW, OverlayBarView))
#define OVERLAY_BAR_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OVERLAY_BAR_VIEW, OverlayBarViewClass))
#define IS_OVERLAY_BAR_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OVERLAY_BAR_VIEW))
#define IS_OVERLAY_BAR_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OVERLAY_BAR_VIEW))
#define OVERLAY_BAR_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OVERLAY_BAR_VIEW, OverlayBarViewClass))

typedef struct _OverlayBarView OverlayBarView;
typedef struct _OverlayBarViewClass OverlayBarViewClass;

#define TYPE_TOAST_VIEW (toast_view_get_type ())
#define TOAST_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TOAST_VIEW, ToastView))
#define TOAST_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TOAST_VIEW, ToastViewClass))
#define IS_TOAST_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TOAST_VIEW))
#define IS_TOAST_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TOAST_VIEW))
#define TOAST_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TOAST_VIEW, ToastViewClass))

typedef struct _ToastView ToastView;
typedef struct _ToastViewClass ToastViewClass;

#define TYPE_SETTINGS_URIS_VIEW (settings_uris_view_get_type ())
#define SETTINGS_URIS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SETTINGS_URIS_VIEW, SettingsUrisView))
#define SETTINGS_URIS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SETTINGS_URIS_VIEW, SettingsUrisViewClass))
#define IS_SETTINGS_URIS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SETTINGS_URIS_VIEW))
#define IS_SETTINGS_URIS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SETTINGS_URIS_VIEW))
#define SETTINGS_URIS_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SETTINGS_URIS_VIEW, SettingsUrisViewClass))

typedef struct _SettingsUrisView SettingsUrisView;
typedef struct _SettingsUrisViewClass SettingsUrisViewClass;

#define TYPE_UTILS_VIEW (utils_view_get_type ())
#define UTILS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_UTILS_VIEW, UtilsView))
#define UTILS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_UTILS_VIEW, UtilsViewClass))
#define IS_UTILS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_UTILS_VIEW))
#define IS_UTILS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_UTILS_VIEW))
#define UTILS_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_UTILS_VIEW, UtilsViewClass))

typedef struct _UtilsView UtilsView;
typedef struct _UtilsViewClass UtilsViewClass;

#define TYPE_VIDEO_VIEW (video_view_get_type ())
#define VIDEO_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO_VIEW, VideoView))
#define VIDEO_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO_VIEW, VideoViewClass))
#define IS_VIDEO_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO_VIEW))
#define IS_VIDEO_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO_VIEW))
#define VIDEO_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO_VIEW, VideoViewClass))

typedef struct _VideoView VideoView;
typedef struct _VideoViewClass VideoViewClass;

#define TYPE_WELCOME_VIEW (welcome_view_get_type ())
#define WELCOME_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_WELCOME_VIEW, WelcomeView))
#define WELCOME_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_WELCOME_VIEW, WelcomeViewClass))
#define IS_WELCOME_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_WELCOME_VIEW))
#define IS_WELCOME_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_WELCOME_VIEW))
#define WELCOME_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_WELCOME_VIEW, WelcomeViewClass))

typedef struct _WelcomeView WelcomeView;
typedef struct _WelcomeViewClass WelcomeViewClass;

#define TYPE_DIALOGS_VIEW (dialogs_view_get_type ())
#define DIALOGS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DIALOGS_VIEW, DialogsView))
#define DIALOGS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DIALOGS_VIEW, DialogsViewClass))
#define IS_DIALOGS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DIALOGS_VIEW))
#define IS_DIALOGS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DIALOGS_VIEW))
#define DIALOGS_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DIALOGS_VIEW, DialogsViewClass))

typedef struct _DialogsView DialogsView;
typedef struct _DialogsViewClass DialogsViewClass;

#define TYPE_APPLICATION_VIEW (application_view_get_type ())
#define APPLICATION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APPLICATION_VIEW, ApplicationView))
#define APPLICATION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APPLICATION_VIEW, ApplicationViewClass))
#define IS_APPLICATION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APPLICATION_VIEW))
#define IS_APPLICATION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APPLICATION_VIEW))
#define APPLICATION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APPLICATION_VIEW, ApplicationViewClass))

typedef struct _ApplicationView ApplicationView;
typedef struct _ApplicationViewClass ApplicationViewClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))

struct _GraniteDemo {
	GtkApplication parent_instance;
	GraniteDemoPrivate * priv;
};

struct _GraniteDemoClass {
	GtkApplicationClass parent_class;
};

struct _Block1Data {
	int _ref_count_;
	GraniteDemo* self;
	GraniteStyleManager* style_manager;
	GSimpleAction* style_action;
};

static gpointer granite_demo_parent_class = NULL;

VALA_EXTERN GType granite_demo_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteDemo, g_object_unref)
static void granite_demo_real_startup (GApplication* base);
static void granite_demo_real_activate (GApplication* base);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
VALA_EXTERN GType demo_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DemoPage, g_object_unref)
VALA_EXTERN GType box_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BoxView, g_object_unref)
VALA_EXTERN BoxView* box_view_new (void);
VALA_EXTERN BoxView* box_view_construct (GType object_type);
VALA_EXTERN GType lists_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ListsView, g_object_unref)
VALA_EXTERN ListsView* lists_view_new (void);
VALA_EXTERN ListsView* lists_view_construct (GType object_type);
VALA_EXTERN GType accel_label_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (AccelLabelView, g_object_unref)
VALA_EXTERN AccelLabelView* accel_label_view_new (void);
VALA_EXTERN AccelLabelView* accel_label_view_construct (GType object_type);
VALA_EXTERN GType css_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CSSView, g_object_unref)
VALA_EXTERN CSSView* css_view_new (GtkWindow* window);
VALA_EXTERN CSSView* css_view_construct (GType object_type,
                             GtkWindow* window);
VALA_EXTERN GType date_time_picker_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DateTimePickerView, g_object_unref)
VALA_EXTERN DateTimePickerView* date_time_picker_view_new (void);
VALA_EXTERN DateTimePickerView* date_time_picker_view_construct (GType object_type);
VALA_EXTERN GType form_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (FormView, g_object_unref)
VALA_EXTERN FormView* form_view_new (void);
VALA_EXTERN FormView* form_view_construct (GType object_type);
VALA_EXTERN GType hyper_text_view_grid_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (HyperTextViewGrid, g_object_unref)
VALA_EXTERN HyperTextViewGrid* hyper_text_view_grid_new (void);
VALA_EXTERN HyperTextViewGrid* hyper_text_view_grid_construct (GType object_type);
VALA_EXTERN GType controls_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ControlsView, g_object_unref)
VALA_EXTERN ControlsView* controls_view_new (void);
VALA_EXTERN ControlsView* controls_view_construct (GType object_type);
VALA_EXTERN GType maps_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MapsView, g_object_unref)
VALA_EXTERN MapsView* maps_view_new (void);
VALA_EXTERN MapsView* maps_view_construct (GType object_type);
VALA_EXTERN GType overlay_bar_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OverlayBarView, g_object_unref)
VALA_EXTERN OverlayBarView* overlay_bar_view_new (void);
VALA_EXTERN OverlayBarView* overlay_bar_view_construct (GType object_type);
VALA_EXTERN GType toast_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ToastView, g_object_unref)
VALA_EXTERN ToastView* toast_view_new (void);
VALA_EXTERN ToastView* toast_view_construct (GType object_type);
VALA_EXTERN GType settings_uris_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SettingsUrisView, g_object_unref)
VALA_EXTERN SettingsUrisView* settings_uris_view_new (void);
VALA_EXTERN SettingsUrisView* settings_uris_view_construct (GType object_type);
VALA_EXTERN GType utils_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (UtilsView, g_object_unref)
VALA_EXTERN UtilsView* utils_view_new (void);
VALA_EXTERN UtilsView* utils_view_construct (GType object_type);
VALA_EXTERN GType video_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (VideoView, g_object_unref)
VALA_EXTERN VideoView* video_view_new (void);
VALA_EXTERN VideoView* video_view_construct (GType object_type);
VALA_EXTERN GType welcome_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WelcomeView, g_object_unref)
VALA_EXTERN WelcomeView* welcome_view_new (void);
VALA_EXTERN WelcomeView* welcome_view_construct (GType object_type);
VALA_EXTERN GType dialogs_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsView, g_object_unref)
VALA_EXTERN DialogsView* dialogs_view_new (GtkWindow* window);
VALA_EXTERN DialogsView* dialogs_view_construct (GType object_type,
                                     GtkWindow* window);
VALA_EXTERN GType application_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ApplicationView, g_object_unref)
VALA_EXTERN ApplicationView* application_view_new (void);
VALA_EXTERN ApplicationView* application_view_construct (GType object_type);
VALA_EXTERN const gchar* demo_page_get_title (DemoPage* self);
static void __lambda28_ (Block1Data* _data1_,
                  GVariant* parameter);
static void ___lambda28__g_simple_action_activate (GSimpleAction* _sender,
                                            GVariant* parameter,
                                            gpointer self);
static void __lambda29_ (Block1Data* _data1_);
static void ___lambda29__g_object_notify (GObject* _sender,
                                   GParamSpec* pspec,
                                   gpointer self);
static gint granite_demo_main (gchar** args,
                        gint args_length1);
VALA_EXTERN GraniteDemo* granite_demo_new (void);
VALA_EXTERN GraniteDemo* granite_demo_construct (GType object_type);
static GObject * granite_demo_constructor (GType type,
                                    guint n_construct_properties,
                                    GObjectConstructParam * construct_properties);
static GType granite_demo_get_type_once (void);

static void
granite_demo_real_startup (GApplication* base)
{
	GraniteDemo * self;
	self = (GraniteDemo*) base;
	granite_init ();
	G_APPLICATION_CLASS (granite_demo_parent_class)->startup ((GApplication*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_get_type (), GtkApplication));
}

static Block1Data*
block1_data_ref (Block1Data* _data1_)
{
	g_atomic_int_inc (&_data1_->_ref_count_);
	return _data1_;
}

static void
block1_data_unref (void * _userdata_)
{
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
		GraniteDemo* self;
		self = _data1_->self;
		_g_object_unref0 (_data1_->style_action);
		_g_object_unref0 (_data1_->style_manager);
		_g_object_unref0 (self);
		g_slice_free (Block1Data, _data1_);
	}
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
__lambda28_ (Block1Data* _data1_,
             GVariant* parameter)
{
	GraniteDemo* self;
	self = _data1_->self;
	granite_style_manager_set_color_scheme (_data1_->style_manager, (GraniteSettingsColorScheme) g_variant_get_uint32 (parameter));
}

static void
___lambda28__g_simple_action_activate (GSimpleAction* _sender,
                                       GVariant* parameter,
                                       gpointer self)
{
	__lambda28_ (self, parameter);
}

static void
__lambda29_ (Block1Data* _data1_)
{
	GraniteDemo* self;
	GraniteSettingsColorScheme _tmp0_;
	GraniteSettingsColorScheme _tmp1_;
	GVariant* _tmp2_;
	GVariant* _tmp3_;
	self = _data1_->self;
	_tmp0_ = granite_style_manager_get_color_scheme (_data1_->style_manager);
	_tmp1_ = _tmp0_;
	_tmp2_ = g_variant_new_uint32 ((guint32) _tmp1_);
	g_variant_ref_sink (_tmp2_);
	_tmp3_ = _tmp2_;
	g_simple_action_set_state (_data1_->style_action, _tmp3_);
	_g_variant_unref0 (_tmp3_);
}

static void
___lambda29__g_object_notify (GObject* _sender,
                              GParamSpec* pspec,
                              gpointer self)
{
	__lambda29_ (self);
}

static void
granite_demo_real_activate (GApplication* base)
{
	GraniteDemo * self;
	Block1Data* _data1_;
	GtkWindow* window = NULL;
	GtkWindow* _tmp0_;
	BoxView* box_view = NULL;
	BoxView* _tmp1_;
	ListsView* lists_view = NULL;
	ListsView* _tmp2_;
	AccelLabelView* accel_label_view = NULL;
	AccelLabelView* _tmp3_;
	CSSView* css_view = NULL;
	CSSView* _tmp4_;
	DateTimePickerView* date_time_picker_view = NULL;
	DateTimePickerView* _tmp5_;
	FormView* form_view = NULL;
	FormView* _tmp6_;
	HyperTextViewGrid* hypertext_view = NULL;
	HyperTextViewGrid* _tmp7_;
	ControlsView* controls_view = NULL;
	ControlsView* _tmp8_;
	MapsView* maps_view = NULL;
	MapsView* _tmp9_;
	OverlayBarView* overlaybar_view = NULL;
	OverlayBarView* _tmp10_;
	ToastView* toast_view = NULL;
	ToastView* _tmp11_;
	SettingsUrisView* settings_uris_view = NULL;
	SettingsUrisView* _tmp12_;
	UtilsView* utils_view = NULL;
	UtilsView* _tmp13_;
	VideoView* video_view = NULL;
	VideoView* _tmp14_;
	WelcomeView* placeholder = NULL;
	WelcomeView* _tmp15_;
	DialogsView* dialogs_view = NULL;
	DialogsView* _tmp16_;
	ApplicationView* application_view = NULL;
	ApplicationView* _tmp17_;
	GtkStack* main_stack = NULL;
	GtkStack* _tmp18_ = NULL;
	const gchar* _tmp19_;
	const gchar* _tmp20_;
	GtkHeaderBar* start_header = NULL;
	GtkLabel* _tmp21_;
	GtkHeaderBar* _tmp22_ = NULL;
	GtkWindowControls* _tmp23_;
	GtkWindowControls* _tmp24_;
	GtkStackSidebar* stack_sidebar = NULL;
	GtkStack* _tmp25_;
	GtkStackSidebar* _tmp26_ = NULL;
	GtkToggleButton* dont_button = NULL;
	gchar* _tmp27_;
	GVariant* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	GtkToggleButton* _tmp31_ = NULL;
	GtkToggleButton* force_light = NULL;
	gchar* _tmp32_;
	GVariant* _tmp33_;
	GtkToggleButton* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	GtkToggleButton* _tmp37_ = NULL;
	GtkToggleButton* force_dark = NULL;
	gchar* _tmp38_;
	GVariant* _tmp39_;
	GtkToggleButton* _tmp40_;
	gchar* _tmp41_;
	gchar* _tmp42_;
	GtkToggleButton* _tmp43_ = NULL;
	GraniteBox* style_box = NULL;
	GraniteBox* _tmp44_ = NULL;
	GraniteToolBox* start_box = NULL;
	GtkWidget* _tmp45_;
	GraniteToolBox* _tmp46_ = NULL;
	GtkPaned* paned = NULL;
	GtkWidget* _tmp47_;
	GtkWidget* _tmp48_;
	GtkPaned* _tmp49_ = NULL;
	GtkGrid* _tmp50_ = NULL;
	GtkGrid* _tmp51_;
	GraniteStyleManager* _tmp52_;
	GraniteStyleManager* _tmp53_;
	const GVariantType* _tmp54_;
	GraniteSettingsColorScheme _tmp55_;
	GraniteSettingsColorScheme _tmp56_;
	GVariant* _tmp57_;
	GVariant* _tmp58_;
	GSimpleAction* _tmp59_;
	GSimpleAction* _tmp60_;
	self = (GraniteDemo*) base;
	_data1_ = g_slice_new0 (Block1Data);
	_data1_->_ref_count_ = 1;
	_data1_->self = g_object_ref (self);
	_tmp0_ = (GtkWindow*) gtk_window_new ();
	g_object_ref_sink (_tmp0_);
	window = _tmp0_;
	_tmp1_ = box_view_new ();
	g_object_ref_sink (_tmp1_);
	box_view = _tmp1_;
	_tmp2_ = lists_view_new ();
	g_object_ref_sink (_tmp2_);
	lists_view = _tmp2_;
	_tmp3_ = accel_label_view_new ();
	g_object_ref_sink (_tmp3_);
	accel_label_view = _tmp3_;
	_tmp4_ = css_view_new (window);
	g_object_ref_sink (_tmp4_);
	css_view = _tmp4_;
	_tmp5_ = date_time_picker_view_new ();
	g_object_ref_sink (_tmp5_);
	date_time_picker_view = _tmp5_;
	_tmp6_ = form_view_new ();
	g_object_ref_sink (_tmp6_);
	form_view = _tmp6_;
	_tmp7_ = hyper_text_view_grid_new ();
	g_object_ref_sink (_tmp7_);
	hypertext_view = _tmp7_;
	_tmp8_ = controls_view_new ();
	g_object_ref_sink (_tmp8_);
	controls_view = _tmp8_;
	_tmp9_ = maps_view_new ();
	g_object_ref_sink (_tmp9_);
	maps_view = _tmp9_;
	_tmp10_ = overlay_bar_view_new ();
	g_object_ref_sink (_tmp10_);
	overlaybar_view = _tmp10_;
	_tmp11_ = toast_view_new ();
	g_object_ref_sink (_tmp11_);
	toast_view = _tmp11_;
	_tmp12_ = settings_uris_view_new ();
	g_object_ref_sink (_tmp12_);
	settings_uris_view = _tmp12_;
	_tmp13_ = utils_view_new ();
	g_object_ref_sink (_tmp13_);
	utils_view = _tmp13_;
	_tmp14_ = video_view_new ();
	g_object_ref_sink (_tmp14_);
	video_view = _tmp14_;
	_tmp15_ = welcome_view_new ();
	g_object_ref_sink (_tmp15_);
	placeholder = _tmp15_;
	_tmp16_ = dialogs_view_new (window);
	g_object_ref_sink (_tmp16_);
	dialogs_view = _tmp16_;
	_tmp17_ = application_view_new ();
	g_object_ref_sink (_tmp17_);
	application_view = _tmp17_;
	_tmp18_ = (GtkStack*) gtk_stack_new ();
	gtk_stack_set_vhomogeneous (_tmp18_, FALSE);
	g_object_ref_sink (_tmp18_);
	main_stack = _tmp18_;
	gtk_stack_add_titled (main_stack, (GtkWidget*) placeholder, "placeholder", "Placeholder");
	gtk_stack_add_titled (main_stack, (GtkWidget*) box_view, "box", "Box");
	gtk_stack_add_titled (main_stack, (GtkWidget*) lists_view, "lists", "Lists & Grids");
	gtk_stack_add_titled (main_stack, (GtkWidget*) accel_label_view, "accel_label", "AccelLabel");
	gtk_stack_add_titled (main_stack, (GtkWidget*) css_view, "css", "Style Classes");
	gtk_stack_add_titled (main_stack, (GtkWidget*) date_time_picker_view, "pickers", "Date & Time");
	gtk_stack_add_titled (main_stack, (GtkWidget*) form_view, "formview", "Forms");
	gtk_stack_add_titled (main_stack, (GtkWidget*) hypertext_view, "hypertextview", "HyperTextView");
	gtk_stack_add_titled (main_stack, (GtkWidget*) controls_view, "controls", "Controls");
	gtk_stack_add_titled (main_stack, (GtkWidget*) maps_view, "maps", "Maps");
	_tmp19_ = demo_page_get_title ((DemoPage*) video_view);
	_tmp20_ = _tmp19_;
	gtk_stack_add_titled (main_stack, (GtkWidget*) video_view, "video", _tmp20_);
	gtk_stack_add_titled (main_stack, (GtkWidget*) overlaybar_view, "overlaybar", "OverlayBar");
	gtk_stack_add_titled (main_stack, (GtkWidget*) settings_uris_view, "settings_uris", "Settings URIs");
	gtk_stack_add_titled (main_stack, (GtkWidget*) toast_view, "toasts", "Toast");
	gtk_stack_add_titled (main_stack, (GtkWidget*) utils_view, "utils", "Utils");
	gtk_stack_add_titled (main_stack, (GtkWidget*) dialogs_view, "dialogs", "Dialogs");
	gtk_stack_add_titled (main_stack, (GtkWidget*) application_view, "application", "Application");
	_tmp21_ = (GtkLabel*) gtk_label_new ("");
	g_object_ref_sink (_tmp21_);
	_tmp22_ = (GtkHeaderBar*) gtk_header_bar_new ();
	gtk_header_bar_set_show_title_buttons (_tmp22_, FALSE);
	gtk_header_bar_set_title_widget (_tmp22_, (GtkWidget*) _tmp21_);
	_g_object_unref0 (_tmp21_);
	g_object_ref_sink (_tmp22_);
	start_header = _tmp22_;
	gtk_widget_add_css_class ((GtkWidget*) start_header, GRANITE_STYLE_CLASS_FLAT);
	_tmp23_ = (GtkWindowControls*) gtk_window_controls_new (GTK_PACK_START);
	g_object_ref_sink (_tmp23_);
	_tmp24_ = _tmp23_;
	gtk_header_bar_pack_start (start_header, (GtkWidget*) _tmp24_);
	_g_object_unref0 (_tmp24_);
	_tmp25_ = _g_object_ref0 (main_stack);
	_tmp26_ = (GtkStackSidebar*) gtk_stack_sidebar_new ();
	gtk_stack_sidebar_set_stack (_tmp26_, _tmp25_);
	_g_object_unref0 (_tmp25_);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp26_, TRUE);
	g_object_ref_sink (_tmp26_);
	stack_sidebar = _tmp26_;
	_tmp27_ = g_strdup ("app.color-scheme");
	_tmp28_ = g_variant_new_uint32 ((guint32) GRANITE_SETTINGS_COLOR_SCHEME_NO_PREFERENCE);
	g_variant_ref_sink (_tmp28_);
	_tmp29_ = g_strdup ("preferences-system-symbolic");
	_tmp30_ = g_strdup ("Follow system setting");
	_tmp31_ = (GtkToggleButton*) gtk_toggle_button_new ();
	gtk_actionable_set_action_name ((GtkActionable*) _tmp31_, _tmp27_);
	_g_free0 (_tmp27_);
	g_object_set ((GtkActionable*) _tmp31_, "action-target", _tmp28_, NULL);
	_g_variant_unref0 (_tmp28_);
	gtk_button_set_icon_name ((GtkButton*) _tmp31_, _tmp29_);
	_g_free0 (_tmp29_);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp31_, _tmp30_);
	_g_free0 (_tmp30_);
	g_object_ref_sink (_tmp31_);
	dont_button = _tmp31_;
	_tmp32_ = g_strdup ("app.color-scheme");
	_tmp33_ = g_variant_new_uint32 ((guint32) GRANITE_SETTINGS_COLOR_SCHEME_LIGHT);
	g_variant_ref_sink (_tmp33_);
	_tmp34_ = _g_object_ref0 (dont_button);
	_tmp35_ = g_strdup ("display-brightness-symbolic");
	_tmp36_ = g_strdup ("Light");
	_tmp37_ = (GtkToggleButton*) gtk_toggle_button_new ();
	gtk_actionable_set_action_name ((GtkActionable*) _tmp37_, _tmp32_);
	_g_free0 (_tmp32_);
	g_object_set ((GtkActionable*) _tmp37_, "action-target", _tmp33_, NULL);
	_g_variant_unref0 (_tmp33_);
	gtk_toggle_button_set_group (_tmp37_, _tmp34_);
	_g_object_unref0 (_tmp34_);
	gtk_button_set_icon_name ((GtkButton*) _tmp37_, _tmp35_);
	_g_free0 (_tmp35_);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp37_, _tmp36_);
	_g_free0 (_tmp36_);
	g_object_ref_sink (_tmp37_);
	force_light = _tmp37_;
	_tmp38_ = g_strdup ("app.color-scheme");
	_tmp39_ = g_variant_new_uint32 ((guint32) GRANITE_SETTINGS_COLOR_SCHEME_DARK);
	g_variant_ref_sink (_tmp39_);
	_tmp40_ = _g_object_ref0 (force_light);
	_tmp41_ = g_strdup ("weather-clear-night-symbolic");
	_tmp42_ = g_strdup ("Dark");
	_tmp43_ = (GtkToggleButton*) gtk_toggle_button_new ();
	gtk_actionable_set_action_name ((GtkActionable*) _tmp43_, _tmp38_);
	_g_free0 (_tmp38_);
	g_object_set ((GtkActionable*) _tmp43_, "action-target", _tmp39_, NULL);
	_g_variant_unref0 (_tmp39_);
	gtk_toggle_button_set_group (_tmp43_, _tmp40_);
	_g_object_unref0 (_tmp40_);
	gtk_button_set_icon_name ((GtkButton*) _tmp43_, _tmp41_);
	_g_free0 (_tmp41_);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp43_, _tmp42_);
	_g_free0 (_tmp42_);
	g_object_ref_sink (_tmp43_);
	force_dark = _tmp43_;
	_tmp44_ = granite_box_new (GTK_ORIENTATION_HORIZONTAL, GRANITE_BOX_SPACING_LINKED);
	gtk_box_set_homogeneous ((GtkBox*) _tmp44_, TRUE);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp44_, 6);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp44_, 6);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp44_, 6);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp44_, 6);
	g_object_ref_sink (_tmp44_);
	style_box = _tmp44_;
	gtk_box_append ((GtkBox*) style_box, (GtkWidget*) force_light);
	gtk_box_append ((GtkBox*) style_box, (GtkWidget*) dont_button);
	gtk_box_append ((GtkBox*) style_box, (GtkWidget*) force_dark);
	_tmp45_ = _g_object_ref0 ((GtkWidget*) stack_sidebar);
	_tmp46_ = granite_tool_box_new ();
	granite_tool_box_set_content (_tmp46_, _tmp45_);
	_g_object_unref0 (_tmp45_);
	g_object_ref_sink (_tmp46_);
	start_box = _tmp46_;
	granite_tool_box_add_top_bar (start_box, (GtkWidget*) start_header);
	granite_tool_box_add_bottom_bar (start_box, (GtkWidget*) style_box);
	gtk_widget_add_css_class ((GtkWidget*) start_box, GRANITE_STYLE_CLASS_SIDEBAR);
	_tmp47_ = _g_object_ref0 ((GtkWidget*) start_box);
	_tmp48_ = _g_object_ref0 ((GtkWidget*) main_stack);
	_tmp49_ = (GtkPaned*) gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
	gtk_paned_set_start_child (_tmp49_, _tmp47_);
	_g_object_unref0 (_tmp47_);
	gtk_paned_set_end_child (_tmp49_, _tmp48_);
	_g_object_unref0 (_tmp48_);
	gtk_paned_set_resize_start_child (_tmp49_, FALSE);
	gtk_paned_set_shrink_end_child (_tmp49_, FALSE);
	gtk_paned_set_shrink_start_child (_tmp49_, FALSE);
	g_object_ref_sink (_tmp49_);
	paned = _tmp49_;
	gtk_window_set_child (window, (GtkWidget*) paned);
	gtk_window_set_default_size (window, 900, 600);
	gtk_widget_set_size_request ((GtkWidget*) window, 300, 200);
	_tmp50_ = (GtkGrid*) gtk_grid_new ();
	gtk_widget_set_visible ((GtkWidget*) _tmp50_, FALSE);
	g_object_ref_sink (_tmp50_);
	_tmp51_ = _tmp50_;
	gtk_window_set_titlebar (window, (GtkWidget*) _tmp51_);
	_g_object_unref0 (_tmp51_);
	gtk_window_set_title (window, "Granite Demo");
	gtk_application_add_window ((GtkApplication*) self, window);
	gtk_widget_show ((GtkWidget*) window);
	_tmp52_ = granite_style_manager_get_default ();
	_tmp53_ = _g_object_ref0 (_tmp52_);
	_data1_->style_manager = _tmp53_;
	_tmp54_ = G_VARIANT_TYPE_UINT32;
	_tmp55_ = granite_style_manager_get_color_scheme (_data1_->style_manager);
	_tmp56_ = _tmp55_;
	_tmp57_ = g_variant_new_uint32 ((guint32) _tmp56_);
	g_variant_ref_sink (_tmp57_);
	_tmp58_ = _tmp57_;
	_tmp59_ = g_simple_action_new_stateful ("color-scheme", _tmp54_, _tmp58_);
	_tmp60_ = _tmp59_;
	_g_variant_unref0 (_tmp58_);
	_data1_->style_action = _tmp60_;
	g_signal_connect_data (_data1_->style_action, "activate", (GCallback) ___lambda28__g_simple_action_activate, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
	g_signal_connect_data ((GObject*) _data1_->style_manager, "notify::color-scheme", (GCallback) ___lambda29__g_object_notify, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
	g_action_map_add_action ((GActionMap*) self, (GAction*) _data1_->style_action);
	_g_object_unref0 (paned);
	_g_object_unref0 (start_box);
	_g_object_unref0 (style_box);
	_g_object_unref0 (force_dark);
	_g_object_unref0 (force_light);
	_g_object_unref0 (dont_button);
	_g_object_unref0 (stack_sidebar);
	_g_object_unref0 (start_header);
	_g_object_unref0 (main_stack);
	_g_object_unref0 (application_view);
	_g_object_unref0 (dialogs_view);
	_g_object_unref0 (placeholder);
	_g_object_unref0 (video_view);
	_g_object_unref0 (utils_view);
	_g_object_unref0 (settings_uris_view);
	_g_object_unref0 (toast_view);
	_g_object_unref0 (overlaybar_view);
	_g_object_unref0 (maps_view);
	_g_object_unref0 (controls_view);
	_g_object_unref0 (hypertext_view);
	_g_object_unref0 (form_view);
	_g_object_unref0 (date_time_picker_view);
	_g_object_unref0 (css_view);
	_g_object_unref0 (accel_label_view);
	_g_object_unref0 (lists_view);
	_g_object_unref0 (box_view);
	_g_object_unref0 (window);
	block1_data_unref (_data1_);
	_data1_ = NULL;
}

static gint
granite_demo_main (gchar** args,
                   gint args_length1)
{
	GraniteDemo* application = NULL;
	GraniteDemo* _tmp0_;
	gint result;
	_tmp0_ = granite_demo_new ();
	application = _tmp0_;
	result = g_application_run ((GApplication*) application, (gint) args_length1, args);
	_g_object_unref0 (application);
	return result;
}

int
main (int argc,
      char ** argv)
{
	return granite_demo_main (argv, argc);
}

GraniteDemo*
granite_demo_construct (GType object_type)
{
	GraniteDemo * self = NULL;
	self = (GraniteDemo*) g_object_new (object_type, NULL);
	return self;
}

GraniteDemo*
granite_demo_new (void)
{
	return granite_demo_construct (GRANITE_TYPE_DEMO);
}

static GObject *
granite_demo_constructor (GType type,
                          guint n_construct_properties,
                          GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GraniteDemo * self;
	parent_class = G_OBJECT_CLASS (granite_demo_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GRANITE_TYPE_DEMO, GraniteDemo);
	g_application_set_application_id ((GApplication*) self, "io.elementary.granite.demo");
	g_application_set_flags ((GApplication*) self, G_APPLICATION_FLAGS_NONE);
	return obj;
}

static void
granite_demo_class_init (GraniteDemoClass * klass,
                         gpointer klass_data)
{
	granite_demo_parent_class = g_type_class_peek_parent (klass);
	((GApplicationClass *) klass)->startup = (void (*) (GApplication*)) granite_demo_real_startup;
	((GApplicationClass *) klass)->activate = (void (*) (GApplication*)) granite_demo_real_activate;
	G_OBJECT_CLASS (klass)->constructor = granite_demo_constructor;
}

static void
granite_demo_instance_init (GraniteDemo * self,
                            gpointer klass)
{
}

static GType
granite_demo_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GraniteDemoClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) granite_demo_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GraniteDemo), 0, (GInstanceInitFunc) granite_demo_instance_init, NULL };
	GType granite_demo_type_id;
	granite_demo_type_id = g_type_register_static (gtk_application_get_type (), "GraniteDemo", &g_define_type_info, 0);
	return granite_demo_type_id;
}

GType
granite_demo_get_type (void)
{
	static volatile gsize granite_demo_type_id__once = 0;
	if (g_once_init_enter (&granite_demo_type_id__once)) {
		GType granite_demo_type_id;
		granite_demo_type_id = granite_demo_get_type_once ();
		g_once_init_leave (&granite_demo_type_id__once, granite_demo_type_id);
	}
	return granite_demo_type_id__once;
}

